# 重定义森林火灾模拟

在前面的例子中，我们定义了一个 `BurnableForest`，实现了一个循序渐进的生长和燃烧过程。

假设我们现在想要定义一个立即燃烧的过程（每次着火之后燃烧到不能燃烧为止，之后再生长，而不是每次只燃烧周围的一圈树木），由于燃烧过程不同，我们需要从 `BurnableForest` 中派生出两个新的子类 `SlowBurnForest`（原来的燃烧过程） 和 `InsantBurnForest`，为此

*   将 `BurnableForest` 中的 `burn_trees()` 方法改写，不做任何操作，直接 `pass`（因为在 `advance_one_step()` 中调用了它，所以不能直接去掉）
*   在两个子类中定义新的 `burn_trees()` 方法。

In [1]:

```py
import numpy as np
from scipy.ndimage.measurements import label

class Forest(object):
    """ Forest can grow trees which eventually die."""
    def __init__(self, size=(150,150), p_sapling=0.0025):
        self.size = size
        self.trees = np.zeros(self.size, dtype=bool)
        self.p_sapling = p_sapling

    def __repr__(self):
        my_repr = "{}(size={})".format(self.__class__.__name__, self.size)
        return my_repr

    def __str__(self):
        return self.__class__.__name__

    @property
    def num_cells(self):
        """Number of cells available for growing trees"""
        return np.prod(self.size)

    @property
    def tree_fraction(self):
        """
 Fraction of trees
 """
        num_trees = self.trees.sum()
        return float(num_trees) / self.num_cells

    def _rand_bool(self, p):
        """
 Random boolean distributed according to p, less than p will be True
 """
        return np.random.uniform(size=self.trees.shape) < p

    def grow_trees(self):
        """
 Growing trees.
 """
        growth_sites = self._rand_bool(self.p_sapling)
        self.trees[growth_sites] = True    

    def advance_one_step(self):
        """
 Advance one step
 """
        self.grow_trees()

class BurnableForest(Forest):
    """
 Burnable forest support fires
 """    
    def __init__(self, p_lightning=5.0e-6, **kwargs):
        super(BurnableForest, self).__init__(**kwargs)
        self.p_lightning = p_lightning        
        self.fires = np.zeros((self.size), dtype=bool)

    def advance_one_step(self):
        """
 Advance one step
 """
        super(BurnableForest, self).advance_one_step()
        self.start_fires()
        self.burn_trees()

    @property
    def fire_fraction(self):
        """
 Fraction of fires
 """
        num_fires = self.fires.sum()
        return float(num_fires) / self.num_cells

    def start_fires(self):
        """
 Start of fire.
 """
        lightning_strikes = (self._rand_bool(self.p_lightning) & 
            self.trees)
        self.fires[lightning_strikes] = True

    def burn_trees(self):    
        pass

class SlowBurnForest(BurnableForest):
    def burn_trees(self):
        """
 Burn trees.
 """
        fires = np.zeros((self.size[0] + 2, self.size[1] + 2), dtype=bool)
        fires[1:-1, 1:-1] = self.fires
        north = fires[:-2, 1:-1]
        south = fires[2:, 1:-1]
        east = fires[1:-1, :-2]
        west = fires[1:-1, 2:]
        new_fires = (north | south | east | west) & self.trees
        self.trees[self.fires] = False
        self.fires = new_fires

class InstantBurnForest(BurnableForest):
    def burn_trees(self):
        # 起火点
        strikes = self.fires
        # 找到连通区域
        groves, num_groves = label(self.trees)
        fires = set(groves[strikes])
        self.fires.fill(False)
        # 将与着火点相连的区域都烧掉
        for fire in fires:
            self.fires[groves == fire] = True
        self.trees[self.fires] = False
        self.fires.fill(False)

```

测试：

In [2]:

```py
forest = Forest()
sb_forest = SlowBurnForest()
ib_forest = InstantBurnForest()

forests = [forest, sb_forest, ib_forest]

tree_history = []

for i in xrange(1500):
    for fst in forests:
        fst.advance_one_step()
    tree_history.append(tuple(fst.tree_fraction for fst in forests))

```

显示结果：

In [3]:

```py
import matplotlib.pyplot as plt
%matplotlib inline

plt.figure(figsize=(10,6))

plt.plot(tree_history)
plt.legend([f.__str__() for f in forests])

plt.show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAloAAAFwCAYAAABghNUnAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)