# 生成数组的函数

## arange

`arange` 类似于**Python**中的 `range` 函数，只不过返回的不是列表，而是数组：

```py
arange(start, stop=None, step=1, dtype=None) 
```

产生一个在区间 `[start, stop)` 之间，以 `step` 为间隔的数组，如果只输入一个参数，则默认从 `0` 开始，并以这个值为结束：

In [1]:

```py
import numpy as np
np.arange(4)

```

Out[1]:

```py
array([0, 1, 2, 3])
```

与 `range` 不同， `arange` 允许非整数值输入，产生一个非整型的数组：

In [2]:

```py
np.arange(0, 2 * np.pi, np.pi / 4)

```

Out[2]:

```py
array([ 0\.        ,  0.78539816,  1.57079633,  2.35619449,  3.14159265,
        3.92699082,  4.71238898,  5.49778714])
```

数组的类型默认由参数 `start, stop, step` 来确定，也可以指定：

In [3]:

```py
np.arange(0, 2 * np.pi, np.pi / 4, dtype=np.float32)

```

Out[3]:

```py
array([ 0\.        ,  0.78539819,  1.57079637,  2.3561945 ,  3.14159274,
        3.92699099,  4.71238899,  5.49778748], dtype=float32)
```

由于存在精度问题，使用浮点数可能出现问题：

In [4]:

```py
np.arange(1.5, 2.1, 0.3)

```

Out[4]:

```py
array([ 1.5,  1.8,  2.1])
```

`stop` 的值 `2.1` 出现在了数组中，所以使用浮点数的时候需要注意。

## linspace

```py
linspace(start, stop, N) 
```

产生 `N` 个等距分布在 `[start, stop]`间的元素组成的数组，包括 `start, stop`。

In [5]:

```py
np.linspace(0, 1, 5)

```

Out[5]:

```py
array([ 0\.  ,  0.25,  0.5 ,  0.75,  1\.  ])
```

## logspace

```py
logspace(start, stop, N) 
```

产生 N 个对数等距分布的数组，默认以10为底：

In [6]:

```py
np.logspace(0, 1, 5)

```

Out[6]:

```py
array([  1\.        ,   1.77827941,   3.16227766,   5.62341325,  10\.        ])
```

产生的值为$\left[10^0, 10^{0.25},10^{0.5},10^{0.75},10^1\right]$。

## meshgrid

有时候需要在二维平面中生成一个网格，这时候可以使用 `meshgrid` 来完成这样的工作：

In [7]:

```py
x_ticks = np.linspace(-1, 1, 5)
y_ticks = np.linspace(-1, 1, 5)

x, y = np.meshgrid(x_ticks, y_ticks)

```

这里产生的 `x, y`如下：

In [8]:

```py
x

```

Out[8]:

```py
array([[-1\. , -0.5,  0\. ,  0.5,  1\. ],
       [-1\. , -0.5,  0\. ,  0.5,  1\. ],
       [-1\. , -0.5,  0\. ,  0.5,  1\. ],
       [-1\. , -0.5,  0\. ,  0.5,  1\. ],
       [-1\. , -0.5,  0\. ,  0.5,  1\. ]])
```

In [9]:

```py
y

```

Out[9]:

```py
array([[-1\. , -1\. , -1\. , -1\. , -1\. ],
       [-0.5, -0.5, -0.5, -0.5, -0.5],
       [ 0\. ,  0\. ,  0\. ,  0\. ,  0\. ],
       [ 0.5,  0.5,  0.5,  0.5,  0.5],
       [ 1\. ,  1\. ,  1\. ,  1\. ,  1\. ]])
```

`x` 对应网格的第一维，`y` 对应网格的第二维。

图例：

In [10]:

```py
%matplotlib inline
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D
from matplotlib import cm

def f(x, y):
    # sinc 函数
    r = np.sqrt(x ** 2 + y ** 2)
    result = np.sin(r) / r
    result[r == 0] = 1.0
    return result

x_ticks = np.linspace(-10, 10, 51)
y_ticks = np.linspace(-10, 10, 51)

x, y = np.meshgrid(x_ticks, y_ticks)

z = f(x, y)

fig = plt.figure()
ax = fig.add_subplot(111, projection='3d')
ax.plot_surface(x, y, z,
                rstride=1, cstride=1,
                cmap=cm.YlGnBu_r)
ax.set_xlabel('x')
ax.set_ylabel('y')
ax.set_zlabel('z')

```

```py
c:\Miniconda\lib\site-packages\IPython\kernel\__main__.py:9: RuntimeWarning: invalid value encountered in divide

```

Out[10]:

```py
<matplotlib.text.Text at 0x9ac1630>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAV0AAADtCAYAAAAcNaZ2AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

事实上，`x, y` 中有很多冗余的元素，这里提供了一个 `sparse` 的选项：

In [11]:

```py
x_ticks = np.linspace(-1, 1, 5)
y_ticks = np.linspace(-1, 1, 5)

x, y = np.meshgrid(x_ticks, y_ticks, sparse=True)

```

In [12]:

```py
x

```

Out[12]:

```py
array([[-1\. , -0.5,  0\. ,  0.5,  1\. ]])
```

In [13]:

```py
y

```

Out[13]:

```py
array([[-1\. ],
       [-0.5],
       [ 0\. ],
       [ 0.5],
       [ 1\. ]])
```

在这个选项下，`x, y` 变成了单一的行向量和列向量。

但这并不影响结果：

In [14]:

```py
x_ticks = np.linspace(-10, 10, 51)
y_ticks = np.linspace(-10, 10, 51)

x, y = np.meshgrid(x_ticks, y_ticks, sparse=True)

z = f(x, y)

fig = plt.figure()
ax = fig.add_subplot(111, projection='3d')
ax.plot_surface(x, y, z,
                rstride=1, cstride=1,
                cmap=cm.YlGnBu_r)
ax.set_xlabel('x')
ax.set_ylabel('y')
ax.set_zlabel('z')

```

```py
c:\Miniconda\lib\site-packages\IPython\kernel\__main__.py:9: RuntimeWarning: invalid value encountered in divide

```

Out[14]:

```py
<matplotlib.text.Text at 0xba147f0>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAV0AAADtCAYAAAAcNaZ2AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz
AAALEgAACxIB0t1+/AAAIABJREFUeJzsnXl8VNXZx7/3zr5mXwgBEkjY91VAAbeCS9W62/pqxa1U
pVZpsbVatW+t+ta31rrUt+7FXbFqsaioKCqyySJbWANZIPsymX3u3PeP4Q43wySZJDMhgfl9Pnw+
Iblzzrlnzv3d5zzneX6PIMsySSSRRBJJ9AzE4z2AJJJIIomTCUnSTSKJJJLoQSRJN4kkkkiiB5Ek
3SSSSCKJHkSSdJNIIokkehBJ0k0iiSSS6EFoO/h7Mp4siSSSSKLzENr6Q9LSTSKJJJLoQSRJN4kk
kkiiB5Ek3SSSSCKJHkSSdJNIIokkehBJ0k0iiSSS6EEkSTeJJJJIogeRJN0kkkgiiR5EknSTSCKJ
JHoQSdJNIokkkuhBJEk3iSSSSKIHkSTdJJJIIokeRJJ0k0giiSR6EEnSTaLbkCQJv99Pst5eEkl0
jI5UxpJIIipkWUaWZfx+Pz6fj0AggCCEhJU0Gg06nQ6NRoMoioiiGP5bEkmc7EiSbhKdgppsnU4n
oiii1WoRBAFRFPF6vQQCASRJavU5URTRaDThf0kyTuJkhdDBljC5X0wCaE22wWAQAJfLRTAYRJIk
ZFkOE6ggCOh0ujCxRrahRpKMkzhB0eYCTpJuEu1ClmWCwSCBQIBgMIggCASDQbxeLx6PB41Gg8lk
Clu2Pp8vTMDBYDD8s0KmCrGqSVV9nYIkGSfRx5Ek3SQ6h7bI1uPx4PP50Ov1QIgcdTodgUAg7F4Q
BCH8d6WdyH+yLIeJVP1PIVXFKk6ScRJ9FG0uyKRPN4lWkGUZSZIIBAKtLFav14vP58NgMJCSkoIo
irjd7mNIUWlDgSAIYYKMvEZNworbIhoZC4LQioyVw7tIMtZqtWEi1mg0rT6XRBK9BUnSTQKITray
LONyufD7/a3Itj0on+sIiSBjtWtDQaRVnCTjJI43kqR7kqMjsjUajZjN5g7JNl6INxkrB30+n68V
6arJWO1nTpJxEolGknRPUrTlRnC73QQCAYxGIxaLpUMS6qmEiO6SsXKPyuejRV0ASTJOIuFIku5J
BlmWw3G0bZGt1WqNiWR6AxHFSsaK+0GxeDuyjCOh9KHVaqN+LokkYkWSdE8SKGQbCASAEFlJkoTH
40GSpE6RbV9AJBnLshwmTUmSwmSsRGfA0ciISEJWCFxxU6iRJOMkOosk6Z7giCRbCGkluN1ugsFg
Qsi2N2swCIKAVtt62SuhaQoRK1oSSqhcW6FtbZGx8pkkGScRDUnSPUGhkK3L5UKWZQwGA4FAAI/H
QzAYxGQyodfru0UC0SIV+iKpKGQYeViYJOMkEoEk6Z5giLRsIx9+o9HYbbKNxIlKGD1FxpIkodPp
oooEnahzezIjSbonCJSHWe1GCAQCeL1eACwWCzqdLiEPcTRNhRMZ8SZjj8eDKIph37K6n2jZdz0V
vpdEYpAk3T4O5TBIfeLu9/vxeDwA6HQ6gHBabrwhSRIOh4NgMNiKDJS04JPJWusqGSu7EzWxKoh8
kSr9RLoolPjjJHo/kqTbR9EW2brdbkRRxGQyodPp8Pl8+P3+uPathF8pacBmszlspfn9/lakEi15
4WQjiI7I2OVyhaNJOrKMFUSSsTLPajKOJi6UxPFHknT7GNQJAAp8Pl94i2qxWML6tvGGQraKFa3X
6wkEAmFyV5IQZFnGZDKFP6NYd5ECOu0J3pwMUO8C1H52ZQ4j5ywWxbZo2YVqMk6KBB1/JEm3DyCa
li0cJVuNRhP22UYiVi2EjvpXk63ZbEar1Yat2vYQLXmhq77PkwXtWcaxpkJ3RMZA+LokGfcskqTb
i9EW2SpatlqtFqvVekzcaTz7V9wIoiiGyVYtVt4VQu+q7zNa4sLJRBDx0KVoi4zVUCzjpHxmYpAk
3V6ISC1bBWqytdlsMZNtZ4kxkmxjcVnE44GMp4XXVwgiHlEfiSDjQCAQvl4JaUuScXyQJN1ehGjC
4bIs4/V68Xq96HQ67Hb7MQ9Xe+jMA9EVsu0JxINUgsFgp+atp5GIOY7HvAGtIlMUMlYjScadQ5J0
ewHaklf0eDxdJtvI9jv6e1fINh7+4u4gFlJR5lURYldC2U5WfzF0jowVn72yNjqyjNVIknF0JEn3
OELx1/r9/lZZSwrZ6vX6bpEttG9BJcqyPd6JEmpSUQ4XXS5XODkkeXgXHdHI2O/3EwgE0Ov1XXZT
RKvycTKTcZJ0jwPUlq3P58Pr9WK1WnG5XOH6Y7FUaehO//EkW/XneuuDo/h5uyJ2k8jU3GjljnoT
1CFnbVnGkaFtQJtkrD4cPlnJOEm6PYhobgQInSA3NTXFXBKnM1C7AHqrz/Z44mQ8vIsXYgkHjDU2
uyMyjkz46MtknCTdHkBHJXGAhFu2Xq+3FdlGi+ntLI63TzeRiFdEQKK+055CZy3xRIgEKcZC5Fgi
Y4z7Sv27JOkmENGqNKjJ1mg0YjQaaWlpScjDqVgOCunGi2yj9dPbowPihVjJ2OfzJf3FKiSSjD0e
D3q9HlEU2bx5M3v27OH6668/TnfaMZKkmwBEq9IQWRJHqT/WUUZXV/tXuxEA7HZ7QvqRZRmHw4Ek
SeEHS7EATyaC6WrmndrF1BvnKtE+53iQsdrvXFFRQV1dXcLGGw8kSTeOiEa2SpWGtuqPxXOL3pbP
tqGhIS7tq/tRxHVkWcZoNIbvQTkcbOshOZmKPcZCKIrLyev19tq5Oh59d4aMIRTSdvnllyOKoczJ
vLw8Ro0axahRo1op7M2fP59ly5aRnZ3N999/f0y/r7zyCo888giyLGOz2Xj66acZO3ZsfO+tgwf+
xHTYxRnRyFap0qDUHzMYDFEXryzLNDQ0kJ6e3q3+1WSrKIyp209LS4tLKJhSjQLAYDDgcrlIS0sL
H34oFr3FYgl/Ri3eovzr6QMpt9uNTqdLWMp0VyFJEl6vF7PZfIyL4njNlRqKtkci3FLxgCzLOJ1O
zGYze/bs4eWXX+bw4cMAbNu2jX/+859MmDAhfP2qVauwWq1cc801UUl39erVjBw5kpSUFJYvX859
993Ht99+25WhtfnF9K4V2McQTTi8q/XHurKNi2bZRj4c8XooFcs2GDxa6keWZdxud7uf60x0gGK1
RJ5S98ZtdyIQz3TeeM1Xbw9pUyCKIkOHDsVsNjN//nzmzp0b9brTTjuN0tLSNtuZPn16+Odp06ZR
Xl4e76EmSbcriEa2Xa0/1pUFHQvZxgvRyFYZc3fcIl31gaq33sd72x0PxEJqnT28A455aZ2oL67I
+XM4HKSmpsal7eeee45zzz03Lm2pkSTdTkDxwakPvwKBQNja62r9McWv29HnFN+fWjs3FrKNtX01
FDdCey+ReIeMxeLHUyeVnOwxs919ccVCxr3d0o0cX3NzMykpKd1u9/PPP+f555/n66+/7nZbkUiS
bgzoiGwVH2p3MrraI6+ukm1XoNxXR77onoSajNU+2Y623Wpr70SNJ45Ed6MBesvhXVfR1NREWlpa
t9rYsmULN954I8uXL+92W9GQJN02oCxSt9vdagGq6491l2xjGUM8yDYWi1Qh20AggMlkitkX3da4
ewJtbbvVRKwmF+VQ6GTYdkeiIzJWDjojX1zqCIveSMbRLN3uuBcOHjzIxRdfzJIlSygqKorHEI9B
knQjoE5HDAaD4e1KtPpj8Vp8kaSoJtv2qkLEA90h22i+3d7wQEbLBHO5XOFUUnVq6vF2URzv7XtH
B51KWGBvTYOOnD+/39/us3LVVVfxxRdfUFtby4ABA7j//vvDWaE333wzDzzwAA0NDSxYsAAIFXZd
u3ZtXMecJN0jUMdNKocRChwOR6u413gvLnWGjZps41UVIpqlq0RZKJlx3bFs+wKiuScg9siAk63I
o7KLAFq5mHpz1Imyxtvr87XXXmu3jWeffZZnn302ruOKxElPupFkq3xh6ppgJpMJg8GQ0DH4fD6c
TmdcyTYaIslWyYw7WdFeZIA6tvhkLKgZzU3UE4d3nR1jtAPe3oyTlnTbIluPx9Oq/phChIkag9fr
DVsKiSJbJTPO4/EkyTZGCEJsMpBqIZYTtYZbLCFt3U3l7WoIoJp0+8ph6UlHuooFEymvqCZbdf2x
eIdFKWNQuxG0Wi0GgyEhhCtJEpIk4XQ6MRqNCZGOVB6oE4Vk2kJnEj3a8n8q5KL+7Ik6Zz0dAujx
eDAajYm6nbjhpCHdtsjW7Xa3WxInnqTbls+2paUlLu2roRyCKOm5ZrM57i4SteCN2i8NoXlNpPh3
b0JHyQuRIt9qK0/5f28k30SNqashgNHIWPkbhMLF4hGjm2ic8KTbVbKNbKO7Y2jvgCyexK4mW0UU
3el0xvXhUWfEAWGdBeVviktGOfVW3CcnW7hWLP5P9fpUiOhkeVlFItbMO/WaUv6+evVqampqsFqt
PT3sTqNvKyy3A0Wcxev1tiqY53a7aWpqQpZl7HY7Vqu1XcLtzoKX5VC9s8bGRvx+P1arNWrp9HiQ
bjAYxOVy0dTUBIRE0c1mcyuLoLtQXh5NTU1hfV6FJCJPjnU6HQaDAZPJhMViwWw2h8PsFJEXp9OJ
0+kMvyTUYVwnKtQWnl6vR6vVotPpsFgsGI1GtFpt+GXldrtxOp24XC48Hk+rOeoJ9BbrWyFj9Zqy
Wq2YzebwfK5bt46//vWvvP766+Tn5zNv3jy++OKLVu3Mnz+fnJwcxowZ02ZfCxcupLi4mHHjxrFx
48aE3M8JZ+kqZBspHK482J2tP9YVwlLIye12H+MjjjeUoH+lkGUiKlCoSQA4JnSuo/npji80XuVZ
eiuRK2s0VisvKY5+FMr9arVa7rzzTsaOHcvmzZu57rrr2Lp1K/n5+a2uv+6667jtttu45pprorb3
4YcfsmfPHnbv3s2aNWtYsGBBVxXG2sUJQ7oK2arlFdVk29X6Y50h3a6SbVeIPZJs23ORdNXSVeZU
kXLsKCmks5ZRLOFaJ4PoTXvoTohWd1N6e4ul2x7UY1RSgAsKCigoKDjm2o4Uxt5//32uvfZaIKQw
1tjYSFVVFTk5OXEdc58n3Whkq2y1/X5/t4s9xkJY3bVslTHHgmAwGPYPx+KP7iraUxdTQ/ldPP3S
HYVrdXTiHRkhEDnWvo54RFGcKP7iSNLtTgpwRUUFAwYMCP8/Pz+f8vLyJOkq6IhsjUZj2KfZHbRH
iD3pRlD8w10l21gJUS140xmJykQj1hPvtrbf6siKExWddVFA+4ebvd3Sjfw+m5ubGTRoUFzbTMT9
9znSVci2paUFjUaDXq8/piROPAP/o1lw8Sbb9qzE7pKt0n5HkCQJl8sVF8GbngyBinX7rcxjb7P4
1CFPiUJXXRTKdcrveisBK+Nqbm7ulipY//79KSsrC/+/vLyc/v37d3t8kehzpKtsLZVtk3Kimyj9
ADUhJsqy7Qlib4vUT0QNhmjbb5fLFbbao4UenYzhbB0lLijuG0X0pje+sNR9d1dL94ILLuCJJ57g
yiuv5NtvvyU1NTXurgXog6QrimKruNvuWmUdQXlI3W531Iy1eCGRxB6N1NXxvN3ZHSQiYy9R6KrF
dzLFzarJWDFsDAZDh/7i4yF0E0m6Hfl0O1IYO/fcc/nwww8pKirCYrHwwgsvJGTcfY501cIwoigm
NO1PsaQVkk+Uz1YhLsWNoNFo4t6XQozRkicSvb3tzTje4Wy9+YWlHltb/uK2tIuPR0hbR1q6HSmM
ATzxxBPxHFJU9DnS1el0pKSktBKKiTciCVAURWw2W8L6Ura5SgJFvIldIXWXy5XQeN4TCbGk9sYr
nK03W84djU25XzUidw+J0i6OtHRbWloS9pzGE32OdNVfUrythMhDK5vNhiAIOByOuPaj9KWk0ir3
k4gFo5C63+/vMJ63KxCEULl5ZZumZKf1tAW3YcMGSkpK+PGPf5zQfjpyUXQ1nO1EQk/tHiJJV5bl
hCkCxhN9jnQVxJN0o5GtYm3GOy1VTbaiKIZTaeNN7GrfsCiK6HS6uOelKyF7gUAgXJJd2X0oL5NE
+kQ9Hg+PPfYYr7/+CocOVREIBPjZz37GL3/5S+6///649BELuhPOptZg6G1kHO/Iiu4mw7RHxr3Z
TROJPke68QzGb49s1f0plkx3Hor2UmnjSewK2ap9w8pCjhfUEQ+CIGAymcIEIghCOFJAOfRMxMGL
JEkUFAykf/8cMjLsuN0u3nr7r1x+2e089dSTbNy4kaVLlyYsbjoWxHJwp6wLn8/X66IDegodJcNE
aherY68hFJmiKOj1hbnqk0499elqV6CEwTQ2NiJJEjabrU1fane/RMWybW5uxu12YzKZsNvtrdJp
4/UCUcRofD5fK3GdeO0KgsEgTqeT5uZmRFEkNTW13ewvxcJWC99YLJZw6FZ3hG9GjBhBbm4mj/7v
YrZt282rrz3KjBkT2bHzQ2bOnMjatd+Snp7OJ5980u37jifUFrHyYlKiRwwGQyt1NrXgjSLcpMQc
9wSOp/UdOU/KHEXOUzAY5Mknn2TAgAHs27ePm2++mSeeeILvv//+mDaXL1/O8OHDKS4u5uGHHz7m
77W1tcybN4/x48czevRoXnzxxcTcWwdfYK+02ZWIgs6WW460bE0mU0w+oIaGhk4fPEVatu3pFsiy
TENDA2lpaZ1e5Eo/LpcLUTxaNFMNn8+H1+vtss84UudBsWwhdHih0+mOsXSVByPWe1Bvw9VWYDSr
+IknnuCBB+5HFAUCAQm9XsesWVN45dU/YzQaGDH8HOrrG3E4XOh0WqqqqsPRGr3N59fRXEWbl54K
Z3O73eh0uuO6W2gPXq8XQRDQ6/Xs37+f2267jcsuu4ytW7cyefJkbrjhhvC1kiQxbNgwVqxYQf/+
/ZkyZQqvvfYaI0aMCF9z33334fV6+dOf/kRtbS3Dhg2jqqqqq/ff5hfRO2czBnTGeutuVldn+4qV
bNXtdxaR/ailE7sz/sg+upsNFws64+tzu93cc8/v6Ncvi18u+jGPP/Y6v7zzal547n1GDD+H02ZN
QRDh/WV/5YfnLiQjM41zzz2Hf/3rvbiPuyfQXnRAW66byEOp7oSz9ebtutrnLIoieXl53HrrrVGv
Xbt2LUVFRRQcEcK58soree+991qRbr9+/diyZQsQCj/LyMhIyAunT5Ju5IllWwsjXqQRC2kp6cmx
iMS010cs16vFaNoj264iMkGjK/MWjy1wNF/fwIEDsVhMvPzqA4wdV8zddz3JJZeeyYKfX8Ydtz/K
i8+/z2tvPsSMmeOZeeoE9u+vZMuWzTQ0NJCbm9vtMcUbXSG2jqID2qtU0dlwtt4M9dx1lBgRTcxm
zZo1ra658cYbOeOMM8jLy8PhcPDmm28mZNx90qcLRxdetIc70mcbi1h5R2iPRPx+Pw6HA6fTGU44
UJetjhcCgQDNzc2t+omF2GO1dCP9wjabDZvN1qHIe2TbiXqYFy9eHD5MmXbKaJ556h2KiweSnZ0O
wNhxxWg0Iv/397cBePSxOyk7eIiiooFceeUVYTI6UaHsGBQfqNlsxmKxtNptKYZBLOLofcHSVZNu
eynAsdzHgw8+yPjx46msrGTTpk3ccsstCQkX7dOWbuQDn6jtcFukFav8YXf6gKPKX4oYTbwJvb3I
it6Cmpoann76abRaDXPPmYFGo+Htt1ZwyWVnhq958/WPOe+CGXzwr6/55uvNzJg5jquvOY9PPvqW
w4cPsG3bNoqLi49LttTxQqwxs9HC2ZRr+oJV3BHpRorZlJWVHSNy/s0333D33XcDMGTIEAoLCykp
KWHy5MlxHWufJF0F6nCuRPoeIxecWv7QaDTGhQSjka46NKs7GhMdEbrL5eq2qyLRD+XYsaESKzk5
6fzoktPxen3s3VPOeeefBoDH4+WbrzezesM/MJkM3HbLQ6zf+CqXXHoWr/zzQ3w+PxdeeAEHDhzs
MBTpZEhkiCWcDUKHVfHOJIsX1JZuRynAkydPZvfu3ZSWlpKXl8cbb7xxTFrw8OHDWbFiBTNnzqSq
qoqSkhIGDx4c93H3WfeCAqUGWbzcCNGgkFYgEMDhcIRP7FNSUjAajXFfeJIk0dLSQnNzMxqNhtTU
1Lj3o76XzrgqjgcaGxtBCPLSa3dz+HAdr7/yEXlZc5GkIH/9y6s4nW6++HwDKalWiorz+d/HF1JZ
Wc2Sl5ex4OY/YjBqycvPoKWlhQ8//DCmUCRF40MJZUtUyFZv2sJHhmkBYRdFbwtng86Rrlar5Ykn
nmDu3LmMHDmSK664ghEjRvDMM8/wzDPPAPDb3/6W9evXM27cOM466yweeeQR0tPT4z7uPhky5vf7
ww+DVqvFYrEkNBTI4XCE3/6J2N5DaNEYDIZwCqnBYMBoNMYlIygYDIbD6yKlHLtL5i6XC0EQ0Ol0
SJKEIAhxDzU6//zz2bzlO06dNYYvPtvEKaeOxGgyUHagCkeTG583wNBhg9DqBN55/08APPW3d7hr
0dP0z8/kL0/dwk3XPsq4CUP44rPN4eKdHSFagH5bGgJdtYpbWlriqv8cL8hyqKpze2M7nuFskeN7
+OGHmTlzJuecc07c+ugm2rzZPmnpKnG6Op0OvV6fMMJVLE4l8yoRFiccXbxOpxNoXck3XlAWqZLY
kJKSgslkitu9qAkpnggGg3zzzdfk5KTxyfJ1/Nf1c1my9F4OH6rn7HOmsHrr08y7YCpfrdrE+Rec
Gv7cdTecj6gRuGHBecw+YxyyLDN85CAsViPfffddTH1HWn7qBI9YrOJEzEdPo731EbljUB/cdVTV
OF5WsdrS7Y6Wbk+iT5Ku4t9Ul/6OJyK390pp7HiTrRJloVheyqKNJ9kqiQ0K4k3oyiGM8kA5nc6w
nzQeW86XXnoJk9nArpIyTGYDk6YNA6CyvJbxk4oBuH3xZUiSxP/9/V9hX+RnKzZgMRv58INv0Wg0
XPVfZ7J29Q6Q4ayzz+rWPSv+UCXbrjNRAj29Be8quur2aC8T0WAwhJNoIjMRO/uiihxfR+6F3oQ+
SboK4pXeqiCaL1XJvoq3Hy8ypC3epK4mdIWI4knoimXu8/kAsFqt4QdM2VZ2J81Xwf3334uj2cW4
yUPx+QKMm1hEMBikrqaJcROGALD5uz1k5aRSWVHLa0tCab9vv/kZE6cNZ/PGvVRW1PGTa89i546D
XHz5LOQjD308EYtVHI1sIHG7hN6ERISzqZEk3R5CvEhXkqTw1luj0Ryz9Y5XP0qURWNjI4FAoNXB
X7z7aGpqCguvWyyW8N/i0b7aOjcajcfoSCgPWCxbzvYOqTZu3Eh9fRMWq4nf/nE+oiiQPyCLb7/e
jslsIDs3lAK+Ye0u8vKz+PX917J40VM0NDhYvuxbbvv1FQwclMsbr3zGiFGDyM1NQxQFDAYdd9xx
R7fnIhaoreJo8wFE3YIfj4MpNXrigK8z7huXy9VqvSgFaZX56W4l4J5EnyTdeJGhWsBFEIQw2UZa
g93tR5104Pf7Y0o66EofPp+vTcGbeLQfGSkS6wFQW1tOdYiaJElh94RCPHPnzkVv0HHHPVfz+cfr
GTm6AEEQWP7vNYweVxhuf/VXW5l0ygiuuOZsMrNTuezC36I36Jh8ygiuuek8Xvi//yDLMj+98RxW
rdxCRmYKS5b8s9tz0lWoyQaIugWPxy6hryIW943yQvr000+ZPHkyNTU1PPbYYyxbtoyKiopj2uxI
7AZg5cqVTJgwgdGjRzNnzpyE3V+fJF0FXSVDhWybmprCZNuRn7Or2gUK2Xq9XiwWS5tleLqjj+D3
+8MqZm310Z321WSuKLJFxnd2hdjbC91SSF6v1zJx6nDWf7ON6aeNBmD96p1MP3VUuO+tm/fzg/On
A/C3F3/Fdxt2UTCkHwBX3zCPpiYnGzfs4bKrZlNeVsPEyUMxGPRs376902NOJNrbgrd1MHUyhLLB
sVaxEh1z2mmn8eyzz2I2m6mvr+fxxx9n0aJFrT4rSRK33nory5cvZ/v27bz22mvs2LGj1TWNjY3c
csstfPDBB2zdupW33347YffSJ5MjumrpdrU+WGcXX1cyvLpCivFKbGgLinoZtC2oE+8HUyGeX/zi
FwB4PD6GjS6g/EA1E2//EQAV5TVMmDwUgEMVdfj9ASZODR2wjRhdSHqGnZTUkGC7KIqMmVDEy899
xIUXz0TUiHz6yQYkKcitt93KZ59+FtfxdwaxEFt7GWXtCX+fLMU0DQYD48aNQ6vV8j//8z9R7zMW
sZtXX32VSy65JJyllpmZmbAx91lLtz3thUgEg0FcLlfYD9nZE/zOaBeorc5o2rkdfT4WqBMblHpn
HSU2dIbUlfadTidGoxG73d4l8Z7uQBEbKRiSh1arobHewfvvfs3EodfjdHr453MfUV/XzKYNu0lL
t4W/S5fTQ11dE99+tRWPJ3TId8fdP2bpm19ywzX/w9DRg8nOy0TUiKxft77PajEIghA1XEuJtOmu
Vdzb3RfRXlhtrc9oYjeRLojdu3dTX1/P6aefzuTJk/nnPxPnfuqzpAtHy6O3BTXZyrJMSkpKl07w
YyERtehNV4mqIyjRFQ6HA61WG/eMOHX7SsZdIhJBOoLit9TqNEydOZrXX/wIURTYf6COeVf+AJ8v
wP4DtUwfs4Dn/v4h+YOOqod9v2kPKak2rDYzH32wGoCpM0ahN+owW038/vHbOVRWzaU/DQXR33ff
fT16b4lEpC80FuH4yAgB9TrvzdaxmnR9Pl84gy4aYrkPv9/Pd999x4cffshHH33EH/7wB3bv3h23
8arRp0m3rVCuSLJVDn26Gi7VkXZBPBTG2usjsmJDVxIbOmrf5XK1aj9WMo932B7Aj34UciNkZIWi
Ex787XPkDurH3959CIvNzMCifJ7/5K/M/9VP2LCmhKLhR4VLNq0rITM3gzMvPI3nn/oAALfLi9Ph
RqPTMWhIfyw2M/Yj7ofHHnusV0QLJBLtWcXRUnuVjEXFddHb5yQeYjcDBgzgBz/4ASaTiYyMDGbN
msXmzZsyyjejAAAgAElEQVQTMt4+S7pqQlAWRWRsqkK23Y0SaEuMxuFwxM0qjNaHLMvdcot0BPV8
KTuBrrYfCAR46qmnuezKn/D444+zatUqmpubuzSuL7/8EnuaDUdTC2+89DGWFBujJw8HYPt3JRSP
ComQXHr9DxG1Iu+/+QU1VQ0AfPvVVkZPHsaNv76anVtLObDvEJ99vB6LzUx1ZS2BQIA555zCd6u3
YUsJhdI1NDR0aAEmAsfzsKotq1jtu1cOgtuKmz2eZBwp62i329u8Vi124/P5eOONN7jgggtaXXPh
hRfy1VdfIUkSLpeLNWvWMHLkyISMvc+SLhz16yoHZIkWvlEOL5QECq1Wm5DUYHXyhPrl0V2yVb+c
lKgKJV64O+1v3bqVgQVF/O7e+1hbYeaxF5Zx8aVXUlA4hMuvvJq33347Zr0Dr9eL2Wriml9cgcvp
YcKsiVhTrBSNDIWIHdhbwdDRIdJ1Olx43D4GDC3g7tufAmDT+l2cft4MrHYzBUMHsOT55bz9ymdM
Pn0yKRkpLHvzc+acO509Ow5w+nmhiIebbrqpXQswMkb0REnxjQYlQkCj0aDVatsUvHG5XLhcroSK
AbWHSNLtrtjN8OHDmTdvHmPHjmXatGnceOONCSPdPhm9AK0tw+bm5oSXkwFwOp34/f5ORT50pg8l
Y8ntdocr+cZLNEaZL6X8uyAIbRbj7AyeeOIJ/vinhzEMOgtTwx4atryDIIoY0grInvkLvt2zgo9u
/Bl6vY75113HzxfczKBBg9ps76c//Slej4/Na7aSlpXGXf/4PTfNuIaCoaGDkKa6ZgYNDW0N95cc
xJZi5d4X7uPGU6/j9Zc+xuPyMunUsQDMX3QV/33bX/B6fDyz4kns6Sm8/9onPP32H3E0tTByXBGf
fvAN33z7Tat56kjyUBElihS+6W55nN4ENanFMic9LZGpJveO3AsA55xzzjFiODfffHOr/y9atOiY
cLNEoM9aul6vl8bGRmRZxmw2J8SyhaP+TgWJEqMJBALhLW578bzd6UOxTEwmU1za//szz3DfAw/i
drtxH96ELq0IQdRgH3wGAVcd5f9ZTNOOf5MyeA45sx/gzc/2Mnb8ZH4w9zxKSkqitrls2TJSM1L4
9rMNTJs3E4CWRgeFQwcC4GhqCf9cuusgtjQ79jQ7l916JXff/hQpqkiG2fNOQavTYk2x0r+wP6fO
m86+XeXoDTrGTR3Jzu/34vP6kfyhuW8LXU3x7S1b8UQgck6Oh0SmWuzmeGSjPfPMM0yYMIEJEyZQ
WFjIGWecEdPn+izpiqIYJo54EqCCyMM4pVR2vMlWCTHzer3he4qs5tsdKL5nRZWts1EVbWHBLbdw
xx2LyDntNwyc+2c0OhtNO95Ho7dgK5jFgLP/hAAIWgOOA1/jOPAVrrpS9LYc9jpymX362Zx3/gWt
FL8UF0RDbSNanY7Bo4ZwsKQ0pIORmcKhsiqCkkR2XiiGctfW/WTlZwNw6YLLSE23k52X1Wqcg0cU
YLSYARgxcTg+j49tG3fxgx+dxvqvvmfslGEEgzK33HJLp+egoxTfjlKelbja3ojuCN7EIgYUmX2o
vKBiJeJI98LxUBi7+eab2bhxI+vWrWPAgAHceeedMX2uz5KuXq8PJxwkQowm8jAu3v1ExsJaraHT
9Hg9hOqIB61Wi1arjVvyxD//+U/eeOs9TBnFVK78I7Vb38JVs5OMkZdhy5tE+ae/58Cyhejt+RTM
fZys8dfTtHs5nrp92Aadgb3ofKwjruarr75h3rk/ZNGvFlNfX8/cuXMxW01IgZAu78Chg9j81Ub6
F/ZDEATWrfyOfgNzw/dQsmUPxWOKw+NKz81k784D+Lz+8O9Kd5VRXVGN3+dHo9Uwec4kXn3mPWae
OZmaw/Wc+cMZGE0GXn/9tWPusyvoTMqz1+sN/9xZ0ulL6IzGQqzKY2rSPd5iNwsXLuTMM8/kvPPO
i+n6PuvTVRBPoRjFnxrNPxzPWFiXy3VMvbN4bUEVKUev19vK9xyP7Zwsyzz77LMs/MWdZE2Yj23A
dFoqN1C9/u8IogatLZ+UIfPwtdTgqt2Bt7GUht3/xpA2GFmWSB08l/ptr+Mo/Qyfs4asUVdiyp7I
O5+8xwsvjsTvdaE36Enrl0VzTT0Digfy3j+WUnQkWuH7dTspGlkQHs/BvRX8eNG14f9XlVej0WpZ
8d4qzr38DOqqG2hqcGCymdn0zRamzJnErPNm8tyDL5CTl4nVbuG9V1YQDAbRG9uO84wHopVS9/v9
+P3+sHsiWp0ytZ+4J63inhK86ar/XD3G40m6L774ImVlZTz11FMxf6bPWrpqJ393QnrUqlyKGE00
/3B3yT3RUQ/xDP+K1rbX62XNmjX85rf3YB8wg5pNz1O17kkad76DJWsE6cUXULX2r5R99huc1dsZ
MPM+csYvoHnfpxxe8xipBWeRXvwjBs5+hICrAYIB3E0HEfU2/P4AEgYAfF4fY885E4vdislq5lBp
BcPGhiQc9+86SLESudDiwtnsZPjkUCqns9mJu8XF1EvO5aXHQ3nzW9buwJ6eQv7IoXz5768AmDx7
InXVDfzzyaU4HS4OlFaBIOBxeXnssce6PVedgUKkbW3F4VgFsuNVGqenEKv/HKC2tpYxY8awcuVK
Xn31Vd5++2127959zLzEInYDsG7dOrRaLUuXLo1prBs2bODRRx/tdPZanyVdBV3VulWHTUWqckVD
d8V1Okps6I4gTSzhX11tX/E5l5eXc+55F6DJmEzm6GvJn3kvrurt+FpqsObPIaVgLrkTf4HfWYOo
0eBp3I85aww6kx29MZPG/Suo3vwPGvZ/DIJAv3G34asr4eCnv6C5fDUEQ1J99uwMgsEg+UWhaIXm
uiZ2bdnLoqvv58DuMras2U5TfTMHdpVhSbGGyelASSlmu5W5P/8vqitr2PZdCd+t/p7MwoHMueZi
vvrPNwSDQWypNgpHFPD4H15kyhUXotXrGXF66MCup7PT2kplVUgnlqyyrvpEuzK24wm1r1iZh4yM
DN59913y8vIwmUwsWbKEyy67rNXnYhG7Ua5bvHgx8+bNi3kOn3zySRoaGjj99NOZMGECN910U0yf
67Puha5auurDDUEQsFgsMR1cdZa0FMvT6/WG9RFisTpjXexdvY9Yoa54rNVquW7+TYjmQTSXrULy
NmHMGAVBP2mDzqZq09NYsifgadhF6oDZ6CwDqN32MvW73iIoBRg0478JuOup2vp3fO71pA++AHPG
SIxT76F01Z2ADLILUaNh6qXns2/DFsaMG8qGz9fhanGxdk0J+RPG4Zdkdu0+xKVTb2DK7AnYUm3h
8ZbuLMWSloJWr6dg4liWPPku+0oOMumS8xg+YyIAOzfuYuSk4VjtVgxWC2fc9BO+WbKUoTMm8/3H
XxJsJ4LheEPJKlNDvQ1vyz2hDtnqTSTaHSjPoUajoaioCJ/Px3333RdVpCYWsRuAv/3tb1x66aWs
W7cu5nE8//zzXRp/n7d0OyNG4/P5WonRdCZSoDP9dCWxoTMPhHII53K5Yr6PzogDOZ3OVpl2l19x
FTv2HCJn3G0MmHYvvuZyarctIbXwh6QP+REDpv4OV/UWJJ8Lc+Zk7P1mkD1yPgGvA+QAzppN6Cx5
yEE/5pQhNOz/gMqNf+HwlicxmHPpP24xwYCEzmQgb3gxzZVVtDS18D+3PIjP62f+my9w+i9/huT3
c91r/+D0RQtZ+8VG9CZDeNx7tu4lY2B/AC66awFffbyW8v0VTD4/FMaTXTiQL/+9iqb6Jrau3YYU
kNCbTOQUF1JTWh5u58EHH4z5ezjeiDVSoCsC6b3N0o2EemwtLS1tRi/EInZTUVHBe++9x4IFC45p
OxE4KUhXEaNRSKorYVMd9RO5zW/LN9ydPtSpx7Gqi8UKdcqxIAhh/YWXXnqZb1ZvoKWxgqrvn0Fj
SEMOuDHaBtGw731qd72Jq74EkEnNm0Xlxv+lesdL1Ox8mcyC88kachW1Ja9xYNUdIBroN+o2Bk66
F8lTj7thN8aU4dSX/it0f/4AucMG42pqYuXST8mbMhV7bjaCIFC+aSumFDsanY7R555FRlERFXvL
WfdZyDLZvWU3BeNDGruZA/LIHNAPk8WEJTWUHjrj8vNY+f4qPl26Elt2JnJQ5uDm7QyfNY3d324g
p6gAoF2fX7yRCGLryCcaTSC9N6X3xoLIeVN2Y9EQy/zefvvtPPTQQ+HnL9H332dJV+1eaE+Mprm5
uZUYTVdJqq1+FAs6FqHyrvYRGf7VlUO49savVIRQLHPlAG7p0qXc/stFZI9ayIBJ9+B3Hqb0i9vR
6Oz0H3sn/cf8Esfhb6nd9QYZhZeSUXgJ/cctwlG1nqDkx5AyDFv2VNIHXYgkeZC8DTSUf4Qg6gl4
G0nJnkHzoS9xN4V8bKJGE6pf5vIw/pqrMWekk14QSoSo2LKN1P554XE3VlQyaNZp/HnhIzTWNlK5
t5wRMyeH/z7yjBn4fEd9nJN/eAZOh5NXH3+dkT88lwGTxrNu6YcUnTKJ+vLDjJgzHVF7NM31RDuo
UqzijkRvlPRe5f+9cS7UpNvRuGIRu9mwYQNXXnklhYWFvPPOO/z85z/n/fffj//Aj6DPki60ramr
bL/VFmF3JQqj9aPWzjWbzXFPbIhmfcarbLr6ZRGtIkR5eTk/W3AbPp+Pun1vozWmY0wZCgh4XYep
2/8eemt/RMBg7kfd/reoK30fZ+0mREFDWu5sKrf8hcqtT1JX+i9yh1xLbtF8mipXUrrmLkSNDb0p
H1PqRDgyr1mFA3jvwcfR2exMnn8tDftLyS4ORS7U7N5LdlFIfyEYkGipa+C0OxZiH1TA76+9FxmZ
fkOPlvCpLNlPwC9Rtn0PEDpwzRiYh8ftZcqPL6V49gz2b/ie/qOG4ne7yRzUH50h5K4YM2YM11xz
Da+88go7duzA5XL1qUq+saIt0RuTyRS+JloZpd44F209E7GI3ezbt4/9+/ezf/9+Lr30Up5++ulj
rokn+uxBmgI1GUqSFJalUxIO4i1EA60rNphMprht8dXbm/ZihrvatnLgqIxfSaGOTJqor6/nzLPm
YsqYTXrxJKpK/sGB1b9C8nsZOOZXBIM+Du9+lqZDKzFa8ug/8k7czXs4vPsfSAEvmYMuxWgZgLNp
L66G7wGBw/tehmAAQWdC0Bvx++qo3r8k3KfWbEZnMLB39XdkjQoJjbhqa8goCPnjGisOUTA1dCDW
dOgwOoMBo83K+X95mCU/ugKTzdrqfit27sGUkc66Dz5j4KhQAsWQyWOoLa9Cq9czaMokPv3zEyAI
9B85lIptu5D8oQiKyspKKg9X88F/PgY5CNLRZAsEAb1Ox/nnn8/06dOZM2cOxcXFJ8xBlfoe1Os6
UmdBcUUo7oyerFQRaem215da7EaSJK6//vqw2A0cq7/QE+jTpKtWGVPKgSs54InwlcmyjMPhOCax
IZ7w+Xz4fL64C95AaIG2tLTg9/sxm81RXxaBQIDLLr+KgwdKMVq8mDOmklF4ORVbH0MQBRoqPyZ7
yLWYbINxNu7A7TjAvg13E5QcCBodaERqD74FAiBq0Kb2J9BchSBqQKNDa03HPHg6zVv+jcaYTqCl
FmQZo91G6XffozEayRwaIklfi5O0AaHDMXeTg/SBoW1h3YEydEdSe/VmMwWnz2bvJ5/h83jRGw14
XW4ctQ3M/M1drH/yCX706xsRRZHSzSX43G7cTc2k9MvBYLWw47NvGDFnBt/9+2MGjh9J6cZtBP1+
dJmFBBoqSJ1yBd7qPbhK14EUQNAa8UkSS5cuPRrPqTUcIecAOTnZLFq0iKuuugqbzdbu+uhLh1Xq
RAZlN6cYCEpKszp7TE3CajKOB9Tz1tLSEq523RZiEbtR8MILL8RljO2hT7sXFElHIO7bbzWULVYg
EEiYnKPiO/P5fHEXvFHCiRQyT01NjfrCkGWZSy65nO0ltRSOexC9KY/SDb+nYutfyOh/Dmn9LsBR
t5G9axfiqNtIUPIg6PQEpWYEbaiYJLKExpaFdegsRI2egKMG5CDpM+eTPfdONNYsmjd/ALJA5rm/
AVnGlJmJv6UFg82KKTOL9MJBoTE7naQdIVq/y0X6EQKuP1iOMfXoabXk84MgsGbpcgAO7dqP0WZh
8FlnIAUkSjfvwOfxUrFzD8aUFA6sC+k9FM6YxsZ/f8KQUybSdLiGkbOno9Pr0JvN+Kt3gyzh2L4C
d9kWtPZcBl7/Elln3oYgCJgGTkCXmgcICIKIIGhAEKiqquJXd91N/sBBpGTmYk9JJSsri4ULF+L1
envVlrwtxPoyiDXlOZExxR1p6fZG9GnSdTqd4Z/jLUYDxyY2iKIYd1JXH/ZpNJpW2UjdhTpLDUCn
07U5flmW+fWv7+KTFStobthPY+0avK465KAXOeintmIZ9RVLQaNBMKcjaPQgCICIechMLEWnIgA6
ey5BdxOCRo9hwHhErQFj3mjqv34Bd9kWfLUHMOVPwDJ4Ooff+BUak4niiy/F2+Jk8E+uI+BsIXXQ
QBr2lyJqtZhS7LibmvF7fdj75QBQvXsfqfn9w2Ov27uf9HET+fjvS5D8ASp27sGQmoooiqQVD2Xt
e59SumkHRpuNjNHj2L0ylJ02ZOY0Kkv2kltciByUMaXYkINB/F4vgs5E/4seRtRbQJaQmqsoe/ln
VH/yFzSWdNJOuZqUiZcgaPVknbWQ9NPmI+iMiKYUBGQQRITQxOL1ennxxRfJyu1PamYu9pQULr74
YkpKSvpEtEBnEak+Fk2TN5rOQqzRE71Jd6Er6NPuBZvNFt7WJEL0Rp3YoLgW4gW1/1lxVahfIt2B
WjdXo9Fgt9vDFkdb1//XNdew9N1lBIMaBI1EQ/Xy0OLWGZEDPowDxqKzZdOy6wvwOUGjpf8lDxFw
1lLz+dPI3hYMuSPo98Pf4674nqqP/wySn4xTb8RWPBt3xRaqPvkzshQgfdo16KyZtOz+HAFo2F2C
PiWVQRdeyq7nnyF14ED2fraSlLxQGfWyjVuwZqQjHvFr1+zZT+Gc2eHxN5VXcNqv7mbNXXfw3X8+
p3TLTlIKQ+nCo6+6glUPPIDBbMSUl8/gCy5gzX33IssyAyeNx9XQiM/lJiUni/cefByf24PGoEfy
uhEMdvwNZeSevRhjznAOf/wn/I5qtMZUKt++C0HUIGiNtOz4HL+jFlFvJv+qxwi4Gql8cxH2Mecg
iCJNmz9ElrwgS8iyCIKGFStWsGLFCkCDKMJpp53KCy+8gN1uP+5VfBMVytaezoK6orGisxDpoojm
xz1eCmPdQZ8m3VjCxjqD9g6w4ilIo2itRvM/d7cPddl0dZZaNL3YlpYWLrnkEr744ovQLzR6IICM
LpSWK0mYi09D1Btx7FyJh20gB8k+YyGuA+upfOcuNLYsgh4nmTNvoGHDG5S9dhvWYaeD5Mc+9AfU
rfo/JFcD+vRBIAcx542lcukisn9wF8gyQb+fw+vXkzZ6HM7ygwiigDE1hZqdu0gvDImdV36/nfRB
RwPcmyoP02/cGADcDY3IgQC2QYUUXnIl//nbS2gNOoovvQKA/GlTETQavn5zGcOvnU/OxEnIcpCa
3fvIHjqElLx+vPDz39J4uBrZaMGUmom7shxRq6HszYUYMgow9RtFwNOMp7qEfnPvxZhVROXyPyAI
ItbCGTj2rcLfcAAQOPD89SAICKJIoLmagKsRORig/+WPgiBS+c5dmAZNRtDoce5bA0EJWaPji1Xf
MHhw6EWRm5vLO++8Q2FhYUJ9o8cbyktFsYwVqP3EajJW7l/5vbKL62uWbp92L8SLdNWJDW2J3sSj
D/VWP5r/uTsPU7Sy6Wo3hTJ+SZK46KKLMBpNZGZmhghXo0M0WEJnX+ZUkGW0thxMA8bi2reagNuB
aE5Ha7QjiFocOz8lY87PSZv6YwLNhxGNFiyF08m/9DH0Kf1p2vA2qWMvIWPyT8g9czGNG9+l6uNH
SBt3BTmz7yR19EUcXvb70LwEg0heLynFw6nbuAFbXh6CINB48CAajYaN73xAyaer0Og0SH4/Ppcb
r9NF7qhQGmfDgYPojmT8Dbn0CjweL7UHKhh46szwvacPG07A56Pw3HMBMOf2Y+/X3wIweMY0Knfs
pvj23xF0uxhw2dVojUYEQQR/C77afRx49QbK3vklupR89BmD8TUfxltTQua0+diK5hBw1ZMy8jwK
f/IytsGnoTFYSBtzEZKzCe/hEkStnorXf0nlW78GwFe9H/fBzRDwYhowFnPRdBBEREsGoimFw9W1
zJw1h7y8PEaPHk11dXXU0K1ExdAeb3eHkvLcnntCkiQuvPBCbrvtNl599VV+85vf8MYbb0TdjXYk
ePPKK68wbtw4xo4dy8yZM9myZUtC769Pk66C7ojFdDaxobP9qJMPlPptbaUFd+U+gsFgTGXTlyxZ
QnZ2NhaLheXLlwMyaPSIRhuCIKKx5aJNH4jsaUFjsCL7nKRN+wlZc+/Ac2A9squO7LN+Tf7FjxJw
NlD28k3Ur3mF9Ak/Rm/vT9lbC5G8TgIt1WhMqTRtWYq7aiem3FGYc4YBAt6qbaEDz5HnhfoXBORg
EFGrw1ZYSGPJDtIKCqjbvZeG/aXsW72Ob175F8119ZRv2cFTP/wJa195G4PVgnjkO2ooPYjuyEGK
KIrkzDgNrUGPOSM9fO+Dzz4TUadDZwpFPOTNPI1dn38JhFwXskZH5ozZiFodghDK2JL8fgSNhsIL
/k7GuP8Cv4dA82EOvjafivcXozWlEXDW0lK+CcnVQOroC5HlIM4Dq8mc+lNSx1xI0OfEOngGBT95
npQxP0RjtJFz1q8xF0xF9ruxDjsTyePGtftrBEEm6Gok6PeEokCOhPfV1NQwauwEsnNyufjii8Ou
qI4yy7pLnL3NmlbHFAuCgNFoZMWKFdx6663MnTsXk8nEG2+8cUwx1FgEbwYPHsyXX37Jli1buOee
e2IWrukqTlrS7WxiQ1uJGG0hUsUs1rTgzrSvJE60VTa9paWFwYMHYzQaWfDzW4/8VgSNHkEXutaQ
O4z0U68j0FSBv2YvurSB5F/5BNaiWRx697dU/+d/sAyciq1oDoeW3UvAVU/2nIUEvQ4EUYO1YDr9
zvwN1ryxVLzzSyR3E/nnPkL62Eup+vQh6je9ibuqhPwzH8Bbu5fqLx+jZf8qALQmExqDAVkOYhtU
iLPsIJ7GRv614DYCAYniex5j9GNL0JqsDL7zv0k/5wrWvPIWgiiGxWlq9+zFnHs0Uy1zzHhkBOr3
7An/rrmsAlmG2m1bARhy4UXU7iulYss26koPIAf8eGuqSB07kYZN69BZ7YhGM7IkIcsSnrpdmNIL
KDj/afpNXwRBCb01l6qVf6F65f8iiDqqVvyR8veO1NcSNbQc3IC/qYL0yT8m6HPj2PkJGTNvwpAz
HOfer0gZdxFZs34GsoQhu5hB17+KffQ5iBodmbNvDh1Mag2IRlsoHE2jY/Xqb0lLzyAjI4OdO3e2
mVnWnUOqvgDFpyuKIoFAgNNPP517772XpUuX0r9//1bXqgVvdDpdWPBGjenTp4f9wtOmTaO8vJxE
ok+TblfcC+poAWUb3pnkhlj6UQjd4/FgsViw2+0xhX/Fqi7WVtqugk2bNmEyW8jMzKTyUBWIGgSD
FQQNHPEJmgdPJ+f83+Gt3kP9Vy+gseaQf/lfkSUv5W/chil/PII2tM0WNDoyT5lPxriLqfrPf1P5
73uxFZyKfdA0Kj/8LZLfjXnQ9BA5BEPxqvah55A26iKatv0b++AzMaTkk3f6vbirdlDzzd8BCPr9
6AcWEfT5Mefm4WuopWrrNnKu+jlIAYy5oQdIcjsx5uaTd9GP0RcMxedys/rpZwGo3b2XlKKh4Xtv
2r+XYDDIjn8dTeM8vHEzaHSUH/FdG9PSMKaksOz3D2IeMhJLYTGVy98jY+oMmku2kzZxKpoj2WlV
a57CXbEe25B5CIKAo+xrTBmDyZ2+iP5z7kNAJmv8T7HkTkVyN6I1plL3zT+oXvkXZMlP2dsLKX3l
epChftWTlC25jqDfg7PkUw6+fB3++jL8DeUcePE6HDs/BUFD7Tcv49r/LYhatPbckOUb8KJN6w+C
hqAscOrsOdjtdh588MEOhW+UNRmrLm9vjh+OHGtHPt1YBG/UeO655zj3iBsqUejTpKsgFnnHaGIx
nU1u6OjajvyqsbTfFql3lLYLobe60WjilFNOCWXWiho09mwIBpH9LgSNFuvQ08g+dzHeql0c/uAB
gn4v6dOuJeisoWHdq/T/0cMY0gdwePmDGDOK6H/ugzgPrKFuzYtYh52NqDcj+z3Yh84jfdINmDKL
qVy2mKpVj5M+8lJMaQUcWnFPSPXfWY2o0dNSupKArwWdJQt7wazweIN+P7ax0zFmZ9NYsgNPQwN5
P70T08AiRKMJjcmMr6EeORBAnxGqfSY1NpB53lVsffd9dn3yKY1lZWSOGx9us6FkJykTZ7Dv408I
eEMVB+p27yLnvMso/2JleH5TiofRfKiKgT+9lbSpp1G/bjWpYyfiq6slffK0UHIH4Dq0ESngxdIv
lA3nPvwdtsIfAFC/7XWseeOx9p+CxpiOqNGRf+aD9J9zPwIwcO4jDDj7IUSNlsxJ15F1ykIQRNJG
XkTGlBsBgZTh88iasQBRELAVzSbr1JsRghKm/AmkT7mKgKMGjTkVY/5YJEctICNodSiP7kMPPYTd
buf+++8/Zi3FossbLcW3L1jEsYaMdeb5/vzzz3n++ecTLnrUp0lXmdD2hMzjWbGhLVJU+ujIr9rV
9hUyV7tC1JZzaWkpRqORWbNmgSACApqUfhCUCTrrEbQ6TP1Hk33OYjyHd1O17CECzVVYB01FkINI
Hgd5Fz2Cr2Yv5W/9AlfFNkwZQ/DW7kY0WOl39j049qykbOntaPUW0oadT9XKPyEF3GSecgtBnxtB
hrcRA6oAACAASURBVNSieWRNuQ1kgUOf3ENz6dfkzbgHU8YwDn1+H353A417PgZNaOzGAYPx11Ri
7pfHd3+4B1kKkjrjLJwl32PICoWLNe/YhC4tA+GIJR9ocWAfPYX+Nyzm8z/9Ga+jhczRY8Nz4Sjd
T+YZF6AxWzm4ahWOikoA+l3yU/wuF44DBwDImTARQW/AXFBMytgpeKqrMGbnojFbkNweAi0taFPS
AAj6vdRtfpG6Hf86QsATQmWRandiKzgr1O/eZaQMOQtBEKnb+iqW3FHorDk4Sr9EZ07HOnA6vqYy
RI2elOHnEXDXA5A29hL8jmpAJn3K1fgay5GDAWzDTsd58DuC7iYMOcVIXhey5MWQU4yhX+gQUdCb
QxEnWiOPPvoodrs9nN7a3hprr4KvUiJHkqSoCmTHG5FWeEekG4vgDcCWLVu48cYbef/990lLS4vv
oCPQp0lXQTSyirViQ3f6iewj3plqajI3GAzHuEL8fj9Wq5Xhw0cSMs0ENLYsELUEW2pBI6K155I9
bzGSq5Hq/zxM0FmLzpqJIGowZA+n3w/upnnLv2ja+m9M/ccguRrR2XLIPeN3WPLGceg/d6Oz5mLM
KkbyubAPOY+0ERdjyhxK1af30VTyIaJGi6AxULPpRUStgdwZv8LbcACdORu9JZvMsTciCHoqPvkt
OlMuot4AgoB1zFQ8Zfto+H4LkhREa09F1OpwH9iNaUABAM7d2zH2O/qQSK4WDP0GkH7KGVgnzkLU
aVG+Eb/Lhb/FgW3kOOxTZ7Pt7aXUbN+Ozp6GKIoYcvIoXxU6QDu0bi2yFMBTeRBLYTFywI9j3y7S
Jkyhfv03GDKz0NnsIAhoTVkEmutpLHmfYMBL5Rf3cfjrhwkGJUS9Bb+zFk9TJbaBc0IhgdVbsQ0J
WcPOg19iH3Y+giDQvGsZqSMvQA76aPr+LXSpA6j6+inqNywBBMre/DmNm5Yi+91Uf/ZXvJXfY8od
RrCpikD9QSyF0yEo463cjtaShiz5QQ4iiEfX268W/wa73d4pMW61e8JoNKLT6dBqtZhMpmMUyGIp
GtmT6Mi9EIvgzcGDB7n44otZsmQJRUVFiR7yiUe60UKz4lUrTC1IE62P7pKt0r6azNtK2509ezY2
m51AIAAaDaIpJUS2rgaQJQS9iayzfoHelk718ocJNFcjaPTIsox1yCxyzlxE/foluKt3kjXrVhzb
l+PY9w15p/+OoLeZuu9eJmPqTeisORx89xa89QfIHHUFtVteQnI3kjlpAXJQpv77d8gefyv9Jv8S
x8GvcVZuwFm5Fo3eis9xGFftdkSNnoxRVxMMePF76gl63IgmC+bCYQQaqhE0GoxjTsWQG/K9eQ4d
xDwopC7mOrgP08DQz+5DZSEStIUOPVInzgBRw9533wFCVq7WYkXU6sm77Hoa9u5lz8efoOsXajdt
5tkc/GwFQb+fms2b0KRk0LhxDYJGg234GA795z0yJk/HsbuE9CnTkbxeNEYTAU8VOaMXIAoa+o35
BZb0KXga9iNq9Bz66k8c/PgO5GCAQ1/9kfJPfoXkbcGx9yMqVz6Az1lHy95POPjhHfgc1dRuXELp
W/PxexwIAR+BhgOIWgMZ467GkFaEwZ5L4ZUvY8oswpI/nn7z7ifobcFWfCqmglPwN5Yh6s3oswaH
fL1yEEN2MYLRDhpd6HcInHnWXLKysqLGZ3cEJTkhWopvewLpPVG/LdLSVXZ/bUEteDNy5EiuuOKK
sOCNsit44IEHaGhoYMGCBUyYMIGpU6cmZOzhMSW09QRDfZCmVMGNpzJXNCgnw4nqQ5Ikmpqa2izx
s23bNiZNmgSEDrhkQQApgOxzhRIatGZSJ16M7G6g5uPHQg+hoAVBwJQ7gpTR53Po4wdJGXkeuWf/
hsMf/TcyYMoeibt2DwFXPf1mLabiswfQpxWis+Xgrt2DOXssKYVn4W8+wKGvHqTfrHuRfE5AwO+s
wp4/k6yRP6F6w/8RDEr0G/0zAp5qqr97ivw5j9C8fzl6Uw5e55GTYSmAPjefQIuDtAtvxr1jDZZB
IStDcjRiPEKUvtpqMk6ZA0Dz1o3oM7LD37u7vBTBkkrJkhcpOOdcmkv3o7GGCFlrtmLIG0Tl2nUM
+OltAOTMu4RDbz3Pwc8/RWMyY500h/o1X9Lv/MtJnXwq1R+9S8GPr8fXWE/auEnUfPkZQb8ftHoa
yr5Ao7NgThuOyT6Y+tL3yR9/FzpTJgdWL8aWNwudKYvaPW9hShuOVpuNq2YtxtQhmNLH4qj8Gmu/
yaQNv4KaTU9jyhxG+qgrKf90MWnDf4gl/xTqNr1M5ik/w9tYhuvwNoy5Izjwxs0E/W68JYegZCUa
cxrm7CJaDm5CZ8vCmDEAx/71yHIQZPmI1S+DHMDrk0lLS2PBggVx8VOqkxnU6CiZQZ1dBnDo0CG+
/PJLGhoaqK6pYfXqNTQ1O9EbDNRWV+Hx+cnPz8dg0OFxu7jwh+cxYsQIRo8eTd6ROG41OjKoOhK8
efbZZ3n22We7MzWdwglh6Spv1/aq+XYHyiFWIBDoclWIjtpX4i1lWW4zlnfIkCFMmhQS6ha0utD2
UpEdFDWYC6diG3E6jWtfp3nnSkS9BX1KLlqjhX7z7sVbs5umLf+i37x7adq2jOrP/xdRZwIE0kZe
Qvbk66hZ938IWjPZU26mbv1zOA6sIWfiLTgPbcBVvY300f8FgkjZisXoTZnkjrqBuh2vEPA0YMs/
FY3BjiAIWDJGY887HXNqMZVf/x5XzXayi28M6TUIIrIk0bD609D9zvkRgbrDGPOP6OV6XGGXQqDF
geHIz869OzHmDQrPh/vAHswjpqLN6Mf25/9B4+5dGHKPuiJyLvgJAOmnhEr2aIxG9BmZbHn6aXR5
/8/ee4fZdVb3/p9319PPmXNm5kyRRmXUuyXLluWCLTcM2IDtAAGMaQmYJIR7SUi4+eWShAv4hgAX
MLYx5GIbAgEMOLZx71WyLMnqbdSmt9Pb7vv3xz4jjeUmjPM8Mb/feh4/Hp2zz67v+93rXeu7vquX
lg3vpda3B880Sa5Ygzk5hpJMoaXSWPkcTq1CqLsHbJPC0TtJdJ6NEILC4EPokSxquBWzOoRjV0nN
vIhoZiWe06B98bWk5/0R+Batiz9Eas7bca0Kqd53oqgRzPIg8VkXYBSOYtXzxOa8jdyOn+JadYpb
f8Lw/X+PrEXQtDiebZJZcw2dF/9PhKyQvfTvcFwP324gtCi1ge2AQI1lUCIpcKxA9UxSEc24/003
3UQikXjFTrmvNh5/1wTzKxUz+L7PM888w+23385nPvMXzOldRLaji2XLV/Gp6/6c/33z3dz844d5
buMmJvS1HCrEGRjsx209iwPjgo3PPMnBccG3f/oUf/yha7hgw4U4jvOScuC3or2lPV3f9ymXy8cH
STwef/0f/Y42vaxWURRkWX5T5Ran7z8cDmOa5svAfGRkhDlz5gBSIKSiaPi+h1B1QKAms4hwkvrR
FxCyilB1Eosuprz3QWKLL8Uc2MLYQ1+j/cIvMPbgV2k8+DXAx7XqtJ/xGbzGJOPPfYvut3+DRP4Q
Y098BTU5AyEUJFkn3LqM1kVXMb71Jnou+hci2ZWUjjxGvHsDsewaGvntjL7wDVLz3otnlpGVKOP7
/432hR+ibdHHOPLM51H0DKP7voekh/F9kCMRcg/+CqUli5BkvEYVvasHzzJxG3VC2YAuNh2AGwNH
iS1dc/y+GENHSL3zfFIXXEn/1/4EPZUidf6JeF0o24UIRzCGj6Glg6aFydXnMHbvL+j6wOVorZ3I
4SjlvdtJrlyLUFSK2zajJlMcvPEbCEXBmhxDqBq+bRJtC5adjcnNxDsCFkbh2D3E21YgyTq5I3ej
R9tRI20UBx5HViPo8R5Kxx5G1mJoiVnk9vyMUGomQlYZ3/gthKwycP9f49kmkdYlhFuXYu3/Nd0X
/iOVo0+jhA4Ral/E8ANfAqEwfOcXgpfazNVY1Ul8zyNzzscp73oApz5EfME51Ad34DYq4DeBU9bA
tZorJNhw4aWcvf4MZsyYwQUXXEA2m/29QmO+7zM4OMi+ffvYsmULDzz4KJO5PP1H+xCSSuvMM8mP
7kHRY3Ss/ypDG7+CrkYwTJfG5B6EpDK5/XZ81wHfI7/7DoQkI2kx6iMv4rs28xYs4q47f40syy8L
mfxXpbe9mr2lQXcKaD3Pe1klyu9r07vhTgmVG4bxpr1dp+9/SgpvKkQy3c4//3w2btxIUNQgg2vj
ew5CSEhaFKFFsPJD4PcjZJXk6iup7X0YY+hFMmf/CblnfkB03nkgq4zc+yWQZPB94rPOJdQyh9yW
HzLjkusxJvcx9uRXaF/3WYqHHsU2qsw+73qGnr+eyZ3/l7YVn6A2/iKDj/9PXKNIqutt5A78jFjr
SjLzP0j/pv/J2Is30zbrasKJXgZ2/Qux9rV4Tg0hqdhGHnwbEMiZLpzcECga2owgXus1auidPdQO
7UGJxpF0HauQC+hiLQFgWoVJ9M6gfY/vedi5cSKL1qAkM4Tmr6K+exOzVp55/N7VjxwEz2fikXtI
LAsAJ33ORYw/+BsiS9cCoHbNpbjlWVKrziC5fDX7vvnlQCoyliZ2+iXUngv6t0l6mLE93yfcsgij
Nk4mPgvf9zDLfbQuuCY43uQLxLsCIZ7ayBMkZpwH+FSGHkdLzqJ4+D4qg0/juRbHHvpr8CGSWYKe
mE2p/0Gyaz/LxIs/INqxFKElKB64FyHJDN79V0hqhNY1H6G05z8Idy1DaZlFbdOPkENx8s/ciu8F
K55K37MISUFICpIewXUM4KVj9tFHHuDRRx5CCBk9FML3XMKRGKefvobZs3uo1yqsWLGClpYWKpUK
mUwG3/fp7+8/XpSzbdsOJibz5PMFhoaOIUkKLa3zyI0fJNa6nFj2ciTlJjILPohtlnCMpxCSoP/x
L+B5DoQ9zPIWwpn5xGacw8TO24nNOBMplKZ86D4kLY4a60AYE7zrHRdx4w3fQdM0bNs+DrKO4/yn
hBD/s+0tDbrA8Zs+leD6fd96J6t/ndx94vcFXc/zqNfrr7r/6efxEnFmKQBcJAUha8jhBE5lEmHV
grLIjkXo2fmUtv6KUPcK7MIA+Wf/FWSF6oFHEUoYPdWDZ1VpXXsdI098lUjnacRmrGH0ya/SecE/
MnD/5+m//wtE0ouoF/poFPvIrryOwU1fIT7jHBKzLmF0y3eJtq4lPeu9WLUBRnfeQNdpf0UoMZvq
xC702Gz06Exaey5nfM/38ZFItV+I5zsUR+4HRQ0SfYqKnGxH61mINdYPCJREC7XHf4ue7caulMg9
/TBquvU4Xcyt16bFekcRqoqSzADQ+r6/oP+fthzn1wJUDuxE7ZhLcfNTeJaJpOk0jh5EqBr13c+T
WLuB5LqLyd9zK7M/8TkicxZS3LqR9s/cwOh3Pk1o7ioqz90FnoNvW7jCpzyyCSGpjOz4Dp4bvCDz
h39J4dg9mLUxpLHnqI1tolEZwazdR+7gbxCShu9a2MV+PNemc+mnMaqD1Cefp2vNXzK0+XqSPeeC
kKhP7EJLdHPsPz6NpIZpXfEhCnt/SWLBZTiNElZ5FMco47tPEM4uRk12Uz74KC1nfJDaoeewJvrQ
2ufhuxbWxLFgZSTJQSiq6fE2RyK+72E0PISQcDyTZ18Y4+GHH0VVIzz4+DGqxQOYRpFM+1LMRoFq
eZiW7BlYZoNacSdts96H5zXw/X5mLPsipYnNeN4+kMKM7L4Z8Bjf/SOEJBNumY8a7aYy/DTdZ/4t
pf7HsYefwTVLTOy4Fd9zqAw+jxCgp+agxdopH3uGiy+5lBu+83+OU9ggiOFu2rSJ8fHxt5zCGPyB
xHTfjBjPFBhOp5idTP/6fZdgr1e2O8VeeNe73hUA7lSiUNHBs0FSUVPd+FYDt5ZHyAqyFkLrWkoj
109xx73g+zSOvYBbLyCH0+C6tK37c/Bs4gsuBSFR3n83rSs/yMTzN5JcdCWe79P/wF/j+y4gke59
D+2L3s/k7ltRw21k5r2bsa03Mrbt+0STS2nkd+DaNdrmfxSjdIyxPT+int9Hqu1sxg5+H89zSHZs
QFYTeG6Dls6LKE88C0B05Qa8ahFt5jJ820DrnI2xfxtaWwdOuUDxmQep9e1h259eycC//yt2Mc/+
r/0ttSMH8Rp19GwQajCG+5FCJ15KTnECIcuM3nmiBVDt4B4iqy9EhCIUtwUCN8VtG/GRKW9+HIDE
uouwSwXM8RHG7rsDz7JQWjpQs3MwB/YgfB81EwC9Ywyiqjrpzncwa/mXCccXEEksIpY+D892UbUW
9PBCPFdC1VvonP9pEm3nEIn3MGvVV1BD7SQ71hJtXUl9YiPxGRfgOSZG6Ri+UBl45Av4roOEjKJH
SC+5CiFr2LUclb6HKO76NdEZa4jMOB0kBTXVQ+XQkwgEheduw84fIzpzJU5hEDs3gFAUJC2MP/Um
mhprYvq0d/F9G9cuUS/uBN/C8wyKkzsw6jlkNUW94VGtDKOG2rAdmXp5D7Iaozy5mdzwPUiSSv+O
6ykOP4CshGgUdoNvk13wUaLpZaihNLHsWVRHNyIkhaFN/0xt9Hli7SsACUnW6F7/RdRQEt9zwW1Q
H93Ou99zJXf88ueEw+HjcWJFURBCcODAAb797W/zwAMP0NPTwxVXXMHTTz/9snn3emI3AJ/97GeZ
P38+K1euZNu2bac0n38fe8uD7qkUSLyWTad/+b7/mhSzN6LxcCplu1N26NAhOjs7mzqrBA0bhYTv
OseB1ymPghTEdmU9gmPUMQd3IFybUPsChKwQnbUWLdmJrOnEZ51J8cUfkzntGnIv/F/Sq6+lPr4b
zzHRU7MYfPjvcBoFPLtB26KPkpn7DsZ33kys8xy0WBdj279HuHU5rlVDliN0LbqOWMsixvZ+D0VL
kplzJdWxLbR0XEp6xuVIcpTxvh/hWmWsxgS+51McewLPqyO0MCIUxbdNWt/7BTyzhtY5G/PYXjzT
YN/nP4g5MUby/I/Q87d3onXOJ7JsA0bZYtf/+HQgmdiMp5sj/UixE/xMa+gwUryN0rZnsXJj+I6D
NTZEZOk56PNPZ+LhuwJN5D0vkrzwGmq7NuE7DpKioba0cfim/41nO8ipLNUtDxBZsp7GnucIzTsN
pvFgzUaOaCooxrCNYRLtbyPRug5Bg1THxWS63wFelVT7+UTi8zGr+4i1rg9+Wz1KtH09VmMSq5FD
CbUw9PxX8V2L+sjzeK5B6+I/JjX33bi2iRbvYmLrvyKpEWQ9qHhLLHkPtWMbwXMo73sALdVNas0H
QAoAtjG6H8+1EaqOEo7jOSY4FkKNBOLq0CwHV4L/v2Sw2oCP61o4VpVoeg2hSDeN8l5UvR1VS1DJ
PYesxIgmF2A1BtAj3bT1fCAo+mg/g1kr/wnXqaNFOin0/5Z6aT9WY4KJfbcjyWFa530ARYsSaV2K
JzSs2ii+5zD0zP/CtWskZ5+HaxksXNDLD39w8ys6PYqicM011/D1r3+dT37ykzz66KN85CMfob29
/SWXcypiN/feey99fX0cPHiQW265heuuu+4UZ/Ybt7c86E7Z7wqI0wVpHMd5TfWvN3KMUynbnW7X
XXcdy5cvb/6reQ6S1tyZGywTtQhCVlEjSXzPwbUMlGgKJRQjOnc95kQfevsCGuP7kZRwwIstDaEm
u6gcuJdwxwomnvsuanImuV2/oJ47FPB2s2fQNv8qcgf+jWTPpSBpTO79MW1LP0m90MfAc18m1rIC
16lSK+2lddYfY9ZGKQ49TmXsaYQQ1IpbEUKmfc61VAu7GNl/I3q0m9bZf0xu8D8COpvvYex9LihN
dm18x0ZJZzEO78atVUhfeB1yKIbeFfRIc8t5Qj1LyP7xP5FY/34QgkNf/xs8x6Z+9CBa9kRNvXF0
H3pnL2rbLEbv+hmNoWNIegglmSF18bVU9myjdmgfvuMQO/NyhKpTPxhI+IUXrKK8cwuxM95DdPHZ
1Lc9SmjRGTj5EcLLz8UzqgFIAUghZCVKo3IQz3MIxXpxrCKWUSSaWoHjVLEaOWLp1VjGZPB5elXQ
3sgPlvKjO7+L7zlM7L4VqzZJ69z30b7o0/iuTbzzDHL7fwq+y/AzX8f3bHou/DpOfQwkhZEH/x4l
1kpm9bWAj1OZoLj154SzCxB6As82CM9cBULGLucIdy1FiaYALwgxIBNQyprjKhjZJw9eECq1/GZq
pb0gZAQ2jeox8G0ULUOtfBjPbeB7DuMDP8d1GlQmt3J4y1/hex6KEsJqjJHqOJfuZZ8FIaPFuskd
ugPXaVCb3ENjYgfxjrW0zL8ShIwSzWJM7CERFtz327vQm/oXJ8+r6QLmLS0tzJs3j6uvvpoFCxa8
ZNtTEbu56667uPbaa4FA7KZYLDI2NvaKc/TNsrc86P6uojdTYFgulzFNk1gsRjweP6WA/Kkew7bt
l5TtvpbgTaFQIBKJntQQzwMECB8kFYSMbxsoya4ASOslor3rgknjWLiORbXvKZAkGoMv4pt1GmN7
scrjNCb7qI/swSyNUBvaGlx/YZBY2wo0LUbnqs9SHXueUMsS1FCa8d3/SnbZp6iMPU956FnARyDI
zr2W1u53MnHoNoQcon3uh8kd/TWOWaJr0V9jGZMUxx5DC7WTaj8Xsz5GS9d7CcfnMzWpfdvEKY6h
dc2ncWgLSkuW3B034JZypC/8M2JLzsczq6iZIITgGZXjfzsTRwnPOwtjaJDD//K3NI4eQJ+9+Pgd
swb60HuW0PLOPyP3+L1Udm9BRJuc3UwncqyFgdu+g5xoDUj/2TlUtgQCOJElaxCqRmLdVYTnn4Ez
OYjWNQ9cFymSwK0W0LqbE9oLmCaliceJp09DCJni6MNEEr3ISoTiyMOE4z0oaoLc0G/RIlkqExuZ
OPxveE6dsd03YRt50l3vomv+ZwGXRNfZFI7+hlBqNuM7f4hZHSOSWUYoPoPEzLMZ23ITjlEhlJiB
kDVCrYvIbfsxSiSDjxwkFcujOKVh5FCC+tEXwPcItc+hMbQL16zhuy5yJI1Q5KCK7SXj/eQx7YFv
AQpCyCh6K6ZRRJKjpNrfhmPlcO0SyfZzEJKO71q09VxFtGUNkqTRtfDPceygzVO9sIPh3TcGkpmN
STzXoHPZdYRTC/A9GyO/n/yBO1D0BBLgmkV+9rOfvGqV2fT5Vy6XXzOmeypiN6+0zf+vMnaKdiqA
OB0Mw+Hw79z88fWOMSWqU6vVXlK2+2p2880309nZiee91OMQSvMN77kEAicaciiGU+gn1NaLHIpT
O/A0IHAa5ePJNSWSQdJjyNEMSrQNSY0Qal2IUDQSvZchSTIt865ACJ9QelEgQTjyHC0zz2N85w20
Lf0Tarld2I0cWiRL4cg9tM18P+FYD6N9PyCZ3YCsxhk/fDu+G4hFS3IYRY3R2vN+CsP3YdaHKE8+
h1Ai5Ad/PnVnTly0JBOauQRzYA9uOUf1+YfwPQ+9Yy5ONWAryMm2oN23WUNpgq49OYjeOZ+uj32X
+tHDGINHCC8IhG5838eeGCQ0fy2hmYuRE60M3/EjlLae44cNLz+P6v5daDMWARA78woqLzwWhBy2
PInvgTWwB33GYnyrgT0xQKj3NBo7n0RJtiFp4YCiJykc2f4ljOoxzMYw+aFfUSttx3VtcgO/oJLb
hNmY4MiLf0u1sA3bLFAaewLXNWmb/RFaZ30EAaQ7LyY/fA+J9tXYRoF66SBG8Qj13EGiqV7aFn0E
ozxAdeh5jPwB0gvfg4cEvkfl0CPBiifZjW9XkfUoTqOCHGvFc0yErOC7NmZ+EKFoCFkh3L0E16gE
Hrvv4XvOtIEt8cpQ4OC5DezGcJBss/KUJp7FsStIcohGeR9G7RiSrFEYuZdK7nl8z2Zo7zew6kMk
287E80ANtdC17PM4VgkhKYzsugmjuJ9Exxpcz0ENtRBuXY5v5vj+zTeybt26V50zcMLRKhaLrwm6
b1Q58D+bgvb/CdB9NTB8swRpppftKoryuoI39XqdbEcHn/vc5046gASSGvAVZa3JWLCQJAXPsQCB
OXkEzzZAktGz85DDSSQhQIBTmwAEvl3Hd23USAqreIxY91oqxx4h2ft2CgfvJL3o/eQP/prMog9R
Gd1IqHU1nutQGniMaGYZY7tuwXdsVC2BUTtMW8+HqFf6qJf20j7nY1TzOxg78itaZlyJY5Upjj3e
TCitZGj/t1G0JK1zP4ZtFhk7dGtwbbICioqkhtCyczGO7QQge/5/A9dGSXViHNuBnGhFCAl77HCT
pRFwr916CTU9A0mL0PGBr4Gi0jgU7MMpjIMko2UCbm9yw0fwGjVCvSfUxxIXfhgkidDCgFIWXrIe
z7YxDu+htuM51FQXtb1PI2QFvWc51WfvJLx0PcbhnYSXno1bLeBPCb74TRqWnKBWGcBzDDwfatUh
PNcknFpNOHMWQkDXor8inFqNpqeItaykNPYQybYz8JEwqodolI8xsOXLSEKnZ8WXkCSZWOe5DG/7
JkJIRFpX4ftglvsxJveSnL0hCB3ZFsb4XvT2xXiOgZAk3GoO37VQkp34novv2oSyi5AjGRqDO4+z
GISsIYQcNBd9+Sg/6d8y4OF7FkJS8H2bULwXPTIPyyiSbFtPKnsJjt0glT2XzvmfRUg64XgvRmMC
xyrgmEWGdlyPkHVSXReDLwi3LKRRHsRzGtiNHJXBpzhr3Vr+6I/+6BXnzJRNDy9UKpXXFKc5FbGb
k7cZHBx8mSbvm21vedB9rfDC7wqGp3Ks6cc4lRY8J9u+fftIp9OUiqWXfynJAUvB98BzkWQVOZ7F
tWrNWnsF3zHRs/NQ0jMwBnfj2QauUcG3TXzHwbPquEYZ16piFo6BrFEd3Ei4dRGVY48RbV9Otf8h
Yh2rKBy8g/ScSxnf+X20+CxKg49jFA8iKzG0cBftcz5KJbcZz7No7b6c8WM/xjImgKA2PxRfvDsh
eQAAIABJREFUQHrm1ZTGHsE2c6jhYEALNYMkh0nNuBqrdij4TFLQM/PwzDpC1XGrRdJrr8G1qsjR
NEKSMYb3obYGSz3z2A6UVPbEvTbraE0WgVvNISSV/J23YI0PYg0dQQqfKIyJLDkHFO0l7AbfqIGk
4BSDeJ0kSSiZbkZ//A2kUIzk6VfS2Pcsvu8TWbyexsGthOavwStPElqwFrcyiZJoDWLTeETSq0l0
Xoos60RSi2jpeR+yEiWSnE+8/Vzs6mGiLcsQkopR2kYssw7P8zDrg/hCY3DPV3BdC0VNo+kp0t2X
YlaP4VhlJg78O3Zjks5ln8GuHEMA1aFNhNLzqAw/j+97yHoMPA9jdAe+5wYgKkAoIezCIFrrbPTO
JTQGXsQuDAbdmTsWICkqcigejLVmdSC+FyRnpROSkSdsyiOW8H0PNZSlUdpHvbwDcCmNP01++LeA
R2HkUUYOfheBwLWLWPUBUu1vI5m9CBCo4Q6KQw+B72CUjuIYeTLzriLReSa98xbyi5//7FXnzfHn
OA10X8/TPRWxmyuuuILbb78dgI0bN5JKpchms6+0uzfN3vKgO2XTAXGK/lUqlRBCvCkKY9OP8UaS
cBAIJK9atYrgtk+B9xSNRwHXCrwPST2ePHNreeRwEnO8DyWaITb3DIzhPTi5AYSiImkR0CIIRQt+
0xQ8kWQdoeh4Vh2QqI/txjFKVEdexCgPUR3biVEeINd3D65dp5HfTzSxAFmO0DnvT6kVd+H7Hqn2
9Ywf/iGJtnORpDCjfbcQz16MqmcoDPycULyXWHolY4e+T37oHsLpdZjl/TSKu5H1QANXCqfxHZP4
nLch6WEm7/omwveI9KzGGN2L1hqU9toTR9A6gmIJc/ggWvtsAJxyDt91kBPNIonJfpRohlDnckZ/
8A+YAweRoyc8HnsyiMlVnrzj+Gfm0V0IRaP2wn3HP4uu3IA5eIhwzxoi88/BM+s4uUHCvQHYStEW
pFgLTn4Ez6wHoQkpyPy7dh3f93GMIfTEyuA8G8fQk6uCDtXGEOHkalynjtWYRJLjjB++Bc9tUMu/
gG2VaOnYQLr7vdhmiXBiAeNHfhqAo55FUSPUC/sx62MkO89CSBpG4TCeXSOUWYBnlpFCSYSsg2vj
2fUm3cpG1iJY44ewxg8iZAU10Ua4ZyXm2EF818UxgkIi37ERUlPv2XOaL5SANhgwG6QT4xMHfAfb
LCCEjKyE0cJdCElCkkMk2i5AURNIskas9Swcqwy+TzW/meLog8hKGLs+CkLQvuDjCBEwcyYP/JzK
yHP84JYbCYVCrzl/TnaqKpXKayqMnYrYzTve8Q7mzp3LvHnz+NSnPsWNN974mufwZthbHnSne7rT
O4S+Hj3r97GpJNxUT7XXS8LVajVSqRb+7M8+2/zkxOAJVKFohhYCwBXCR4m24tkmanomnm0iJBWn
lqM2sAOh6KixNELRcY0y2I1m/JeggEJW8ewavmMiaWHwffRYFjXSDkIilJiH55gk2s9FSCqdvZ/E
922S2YtxnQbVwoukOy9i8uhtJDsuw/UsBvd/E8cqgpCR5AiJ7isxqkeoFXcSTa8P4nVylEh6NbGO
iyiP3sdk380B8DcKqPEurMJRvEYFt1IAQI5msHJHjwOtWy2gNeOwdm4AtSPojmsc2YrSDDsAWGOH
URMdtF/yVzi5MQoP/hQ1O/v4PbVG+pDDKZzCGObA/mAfB7cRal+IW5rAngiWk5FVG0CSiS69OPB8
E1nq+zeipLJIkST17Y+gpDsp/PpbCFmhvuuJIEYqyRilHRjlffgI1EgPZvUwruugR2dTL27FdS2s
+hHGD96E7zsUR+6mUT1GrHU9rXM/je87RNNryQ/djZAU+nd9Hc81mbn4b3GdIq5jUBy4n3jbKuql
I8GYEUHSrDGxF19IuEY5iM2KZl5CVprP3kDICpKio3csCuQm+18Ez0OJtSKEQE1kgwIVPXYizCDE
ib99lyChOx3oZPAthKQG19cYRQt3o2pJSuOP4HkmqpaiPPEUQgmT6rwExzUJRWcSbVmFY1fB9xjb
fwtC0snMeS+6HuPmm2/i9NNPf+1JN82mC5i/XnHEZZddxv79++nr6+OLX/wiEIjdTBe8ueGGG+jr
62P79u2sXr36lM/jjdpbHnThhMrRlCjNf4bojeM4VKtVAHRdf92ealN23333kclkMIzGNFK6T8BO
kAPvRATJDfyA1iOHM3hWFfCx8/2oiXYSK96F59iE2nsJz1yFXS8FCTY9ilD0Jh2IYLK47nEOpmdW
8H0XxyziWBXCqflY9UGSHeswKntJtK4hP3wX6Y4NTPb/hLZZ11Aae4xoyxoQKhPHfookRzDrw8Q6
30Gi8xLKI/cgSRrJzssoDd/DxJHbUEKd+G6NRn4renwhkdRSfLcatO8RgnDnMuqjgbcZ716HmuoO
5AHr+eOermfWjhcieLUTzAVzYC9q6wmhG2usDy07H0lWad/w3/FNA6174fHvzYG9aIkuQm0LqTzx
SwCMQy8SnXMmSrKL2taHgu0Ob0eoIayh3QBEetdR3x3o7YYXrKNwz81YgwdAidB22scQcgjfdfAd
E4DKyG/xXYv84ZspDv4K37MY3fvPVEYeRJJ06qW9OE6dWPuFJGd9GIFHLHMW5fHH0MMdNEp7aJT3
ISsR9MgMYqmFWPVBbKtMKDIThIJRHcGuj5LquaS5+lGCl8+UZ+oHimJTyTDftfE9FzXdA3oMY2Qf
bnUCIavEF1+IU51Ez8zBqReQ9Xjg9Qq5ubpqJtgk+eUc3uPjVsHzLPBdJFnHrA1gNsYQQkHV4lhm
EYFAwqM4+hB4NkZ1gEpuM/HMSuJtZwVjH5/coV+yfMUirr766lMSSD+54nSKMvZWs7c86E7pLkzV
Yf+ujIRT2f/0rhDAKSXhPM/jG9/4Ju9971UEg6wZO4OmZzIFvEESTCg6khLEm53aOGqyGz09iyku
Znn7fyCpIYyxPhpHX0BSQ7jVHJ5tNoFbNGNyBPG56ea7TRlGaBT3E4r3YFaOBFRNBLZVAqHh+1Av
7SSeOY2xQz9AC3dQL+4BZKLp1dQnHkGPL0OPzaI48FP02LzghedUiXS+m2jHZdRzz2LV+jHqQezU
92yEoqNnenFrEyTmXIxTz6G3Bd6tb9VRMz14joVn1VGayTDPqqG2BqBrjR9Fa597/HLswjDhGcGS
PtQZsBEa+547/r3Zv4dQ5xLS666lvvsZ7Mlh3PIk0blnkVz6TqpbHwgqBHc8jqxEqe59BID4qndh
TRzFbVRQkm3gOsy48J8QeEhqBN+zCLcuDbzBJihpmfXI8eXg+4Q73k505vtACBI970dvWYsQEE4t
pzb+FKH4bISkYJR3Y9QGKIzciyRrZOd/Dscax/NcRg/fTrxlJZKaQgBWbRAhyRSOPYCsJRDCx2+C
XqCj0XzB+l6QkIwkUVLdWJNH8GqTCEkQnrGS+Lz1lPc8hBxOYoz3BfS92mTzGTlMOQFT+YQTHN4p
mwo5OMHY9b0AfIVACJlwYjGWVQcELV3vwheRoNio/XxkJYzve9SLeymPP004MQdFS9E9YyZ3/OLn
ryiQfiqNNE/F0/2vaG950JVlmUgk8qaIiE+3VyvbPZXKt0OHDtE7bxH/z9//A00WOuCdVH5JoCng
NXVQXQvfdwm1LQHAzB/DKgyQWnEVAKHsAkKdS4Iy0UgKOZoOGk7KCuEZy5v7bgK5Z7/CpBH4TgPf
dWiUjmJUh5C1NJXJzSSzGyiMPkg8s57y5HOY9QHMxji1yiHCqeW4ToFIZj2SHKEy/Gti2cuwrTLj
B7+LoqeQtRSN0d+gRmYSaTub8sjduMYwxyey61AdeAHfc0nNvwyrNobeNg/PauDZBkpLJ9WdD4Hv
k7v7/zD2iy/jmw2c0kQA6pUcWjPB5tZL+K6N1hqAsF0cAkXHPLYL4+jOgLM60U9kzjq0VDdKLEP+
l/+CFIojKSGi887Ft02s/j0YfVtpW/dpnNIYTmUCJRRHjqSo7XyM0lM/w7dtPKtKtHsNpcOPEsrM
A78p0O37TUJ/L54xiB6biRbtwco/Tyg+G0mJYRaeJ5peie9ZWPXD2EaOkb3/gusaJDrfiaLGibet
pzByL65dw6wPBUv/8ExqhReJtaxESFrAXPE9nMbkiRXN1HOeAkpJQU1kcSo53NIIQkgokSTxJZfg
GWXK+x4D38UzKghFI9K5DFmPEW7rRVZDyFoESYs2X9xesF8xfSXnBR41ClOeqhASspJA1VI0Srvx
3RqeWyM/9BtsYwRJUiiOPYbve6Q7L8P3XSRJx3dquMYod/7ml6TT6ZcJpMNLG2lO71QxNTchWH3+
Lj0I/6vYWx50IfA832gZ8Ml2ctnuyWXBr0VNsyyLj3/84yxfvpKRkdEmBp7ICL/kpdCMzwlZRVJj
zc8kjIndxGefi5AU1EQH5T334Ls2jeE9NAa2Eus9CyUUxykNE5+3HiUcxxja1fx5s9rola8MmMpY
y0FipnwY3/fJD/0Wz3XIj9yHpIQxG5Mkui4HzyKUXIGipSkP/ZpE13swa/3UJp/F9z18z0WKzCPS
+U48p0F99L7gepuKV0JWUcOt+J5DY2gbkhJGCSXxrDJauofG8E4QEkP/+mnyT9yKkHWkios/ngMh
M/GL/8XQdz6GZ1RR01N83X4k7UTS0pw8iqLHic86l9xd38bJDSJkBS3RAUBqxZWYh7ejxIISUUmS
0NNzyN/1XYSsEm5fhBxtpXbgGQBCXcsoPHgLSjhDtGsNhX13E+tZj5U7RHz2eViVYWQ1AgjwXWoD
v8KuDyJHF+GaJez6IJ4IUx55ELsxTr2wi8m+G4PSXK0VRUsSy5yOGunCMnLUClup5TYTis1Di/UC
PrnBO1HUGEZjMFCTk3UCIJy2Qmo+ZyE3n6nn4NRywXtO1Qn3nIbWvoDyrvuxCsPo7fOR9Rh6uodo
1zLMyQOEu5ZjFvpRk12BqI/nIsnaiXAX3kuAV0gKUwm1YExLuHY+YLQICTWURlICxoga7kRIoeZ4
88mP3Ifve+iRDoz6GP/8z199SQXZazXSnOpUMdWR4r777uP888+nWq3ywx/+kBdeeOFl6nzTLZ/P
c/HFF7NgwQIuueQSisXiy7YZGBjgggsuYOnSpSxbtozvfOc7r7q/39f+IEAXTr1a7NXs1cp2T07C
vdJxfN/nxhtvZPacXn7+izuRQ90EKk5WU2NEgFCCpbakISnhIC7nu0EizbMCQPY91HiW2tCW45PI
9zy63vFllHACNdmFVctj5vuRtAjGyF7sah4f0DsXBV0klIDAH5StTj93QeCteMevIRztQdMSqFoL
keRCZCVEKLEMRUtiV/cTaz2D8tCviHVcjmWM0yjvRYv2UC9sRQrNIJy9CDO/Cbt2jEjX5QEgjz1y
4r64DkqkE/CR1QR6ak7AabUaCC1CftOPEZJCqmsDemwWiZ7zyK7+U7R4J5HscmZf+j3iHevB8yg+
8SM8s46V60eLnshYO7nDaLEsmVXXQL1M4f5bXvJ9fP7bEFoYtQnCAKlVV2KPHkaNB6GM+Oxzj4cY
oovOCzLsp/0p8Z5zMCYPEmlfgucYqNE2XLNEpGs1QlED5oBXBt+hPvYQ1cF/Bzw8YxindhhZz6C3
vQ1ZSxDJnEmkdT2uXUYJzSR/9CdBUlKJBxKlnW/HKO9DUiIIScexGzhmAVlN4rmNpkcbaCMcB1y1
KWbj+81nLhHqWkxk7jrq/duoH9mMpMdIrXo35sQhor3n4HsOZu4IcqKL2sBWPMfGmDyMa1XxHRPP
aYKXaIYumiJIMBWGUAE14Ox6BlOCNbKawDYDVkSi9Wx8t4br1EhlL0RIEfAdtFA7tjHKpz71aT7x
iU+c0rycLpCuqiqyLHPeeefx5S9/GUmSePbZZ/nEJz7B5z//+Vfdx/XXX8/FF1/MgQMHuPDCC7n+
+utfto2qqnzrW99i9+7dbNy4ke9973sv02l4s+wPAnSn2oi8UdCdXqkWjUZfs2x3+nFc1+Wmm25i
/oLFfPF//COW24rnWjiNYRStBVCapHK5uRxVAg/RNdFiM0HIeFYtSDS1BXFBqziA71p0bPg78Dwk
LcLwvX+PY1TwLQN74hCJhRuIzFqLUy+RXPVuYgvOwxo7iKLHwHOP984KQslT1+Ef/89z6gghsIxR
PM9D0dtoVA4SzaynXthMrPVtGNVDSGobkhqjOnY/4dQqapPPYNWH0JKL8RqBbGC4/QKMyadpjD0W
vEhE6Hi8M5Sci1k6jKy3ICthwm2LaYzvBiEYvvOLuLUCyVkXk5pzKdhF9NTs4HlUBgi19CJJElq8
E0kK4RUmGbntcxiHX0CKneBRmuMH0TMLg8agi6+icXAzUqT1+Pe+25RlLJ0o/wzPWIFQdEKtgcZD
cuGlx0MM5pHN4PlUhzYRaVuC7xiYpUHC2eWUDj2K3jIneGZNTx8AKYre9S4QCqHsJait5wM+euu5
4Pt4TgMlNp/K8D340Ey62SRnXInv2UhKjIm+m5HkENH0meA7+F4D37OxzRxTMdRpoxAh6/iOiUAg
1BBaqovogrdh5QepHXgCIQTp9R9HDcep7n+EzNkfp3rgcZx6Abs6iTnRhxxKAYJo92okNUw4Mw9Z
DSNrUWQthpC0pjavzJRmQ9AEMwD/4AWh4ro2jplHUeP4rkV58llcuwa+TXH0AVyrQDS5ANucYOnS
xXz1q1/53SboSfMvFotx9tlnE4lEuPXWW9m+fTs33HDDq/5mur7Ctddey5133vmybTo6Opp0TojF
YixevJjh4eE3fJ6vZX8QoAsv5dCeqr1SpdrrxYg8z2Pz5s189KMfo62tg7/54j+QL8mYZo1a6VAQ
NkDg2lPFD1LTw50Cv+A8reog0dZlIClNGtBOUvPegawnkLUYo499Laiyai6LZ777m0haGCWaCbQW
DjyOUHTqB5+kdvCpwGsKJ5BUHd9uBNl+NcJUS/aTzfcsXKeOj49ROUisZSX13DPEWs+kMv4AiY63
Uxm9Hzk0E7N6mHr+BZTwDPBsZK0TPb0WY/zhAMAlDccYRVJC4DcCD15SUSNZPLdBdtHHcOwSoXQv
xb4HAEj3XI6qRQklgxY9jlVFSwZ0Mc8qoSWCGG5jfDeRzFw6z/oH9HA39UMvoKWbQua+j5HrJ9J1
GgDJ3g0INYwyHZRzh5H1CGZ+AKsQUMXs8lgQIy31B09ICaEns1R3P0R5z6MkezZgjARdOOJdqynu
u5v47HMwJvaSmHMeZuEIciiFrMWD++vVMEfuR1JieGYOc/wRJDmMVdpBY/xRfATlo7fi2UX0ltNQ
orPRIx34vovVGA1ezEJGi86mMv44emwBQtKYWpm8lNcNCCkQsld0hKYTW3g+Qo9S2/cYvm0SW3Qh
qeVvJ//cj9C7VqC29DD51A/wHBPPdVDjWZLzLsC36yQXXERjdAfRrjVYpX60RBeiSRULro+AxigH
YTLfD3RBfM/Gc118z0GSVSRZxXWqzaEmUPQ0spoEBLIasF+6ujq479673nAcdjp7wTAMwuHwiVvy
GvmcsbGx4wUP2Wz2dQVtjh49yrZt2zjzzDNfc7s3am95EfMpe62b7vs+Tz75JNu2beOJJ5+hf6Cf
RsOi0aiTSCTBd5k1axaqIrFkyWJc12XGjBnHW58fPXqUsbFJtmzdxujIMLYTVABFk4toFPdimwNM
xdkUtQXbnMD3JSRZJmDCBFQcIWuBF+MH8dd6fi+yrIMkI6shykcfwbXraJE2XKp0XfhPjDz2JSQt
yvC9XwxUxcJJaoeeIdy+kFD3Corbf0Ns7lmobfMobvo31FQHSjhObWhP4HnK8rTki0TAvZz6W+Da
FcCjmt+O79vU8i/iOVVKI/eD79LIb0GJLcKp9iFpadRoD8bEo2iZcxByGDO/CZBQMmfj5Le85L5X
Rp9HSBKh+Bw8u46Z24eR6yM9650kuzeQP/Ib9MQsHKuCaxtosSAEYBsV9GQAunZlgEj7aUiSRPtp
n6E68knKex4gvvTSJl3KR0+d6CbhOzbVQ0/TsvaDyHoMc2wfaiiNkMNUd/2W9LmfpjH4Imq4hfro
HpxGCSWcJDxjPYXNv0SPtZPuvZyjA49h13NEuteR23EbkTP+NGBUJHtwjALJ3kup9j/dXGYDvoUk
J7GK2wAPJZTBM4JiAD2zHqeyD1nRURPLsPp/giepmIO/Rg13okR6aeSeolHcAciY9cNN50EhKFaY
7kiIoDLRc4kv3oBnN6jsfgChaKjpmSSXv5PcU7egp2fSsvaD5J/7EUgqofYlGBP7SC1+F7Vjz2BO
7Cc6cy3Vo08RnbmW2sBmUEIYhWP4rtmM606xGprgL6RmSFlBIIEARUvj2BUQfgDASpRwYin10l6E
8IllzsSqD5BOCu6/77cvFeb/He21qtEuvvhiRkdHX/abr3zlpV711Kr41axarXL11Vfz7W9/m1gs
9obP9bXsDwJ0T+4KPMXPLRaLfPYvP8cDDzxIw7SwLROQm4M2kBocHQ30PA8c7MP3HH573wPT4p6i
GZMNllZ6uB3H8dAjPTh2iUp+Z0CZAaKp5dRL+3DsPLGW06gVd+G5NrISw/NMfN/E9xy0aDd2fQTP
MYJsevZ0KiPP4poVhKzQtf5vGN9yI5ISZujBvwEhE+teTnVoC9nzPoddHqG09x4yZ32csce+FURq
XZfi8z8NavD1OEZ+CFyb8JwzAw/owFNMZZt9328mugLwlSQdz3cRSgQ8C8+zkNQUnttAjfUivCqe
NUK48zKMsfvx40uQQh2YuafB91CSK5D8OlbuKaYvnHzPBqEQSy+iltsOvkvhwL3IikYoOQ+zchQh
KSihFOXBZ9CirQhJwSoHYQA5lAbAM0toiQBUnfoEkqIRjs1i7J5/JLnmfajhxPHnb5WHkFUdNZSi
vONOWtZ+GHN4J3pyPrHucxje9FWSZ3wY49gmwi3LkKT9VI8+SWrx5SQXXEph5x2EMqchq1GimUUU
9t1J68prcMwadnWcSHYxk5u/D75H6fBDJ7xQP+jG4BgTACjxJUjhGTgTj6KlTsf3PVxjDF9LYh37
MQBqdDZW+QBqdB6N3EYUPYPn1PFcq/mSnCZIE4zuZpm4E3i2vkN5T9ByR2gRWs/9FIXnfkRpyy/I
nPcZJh//HsbkMfTWBcGL3pgke+5fMv70d0gtuYL6wCbqwy/imnUqR55FUkN4Zg091oVdH0ONZnEb
uWbyTuDaNWQ1hmtXUNQEjl1GksLY5sRxpbFQvDfgapd2gW/j+xLV3Eai0QRPPLGZzs7ON2O6Ay+n
iz300EOvum02m2V0dJSOjg5GRkZeprs7ZbZtc9VVV/HhD3+Y97znPW/auZ5sfzDhBXipkPkdd9zB
3N4F3P3Qs7jRWVhGo8kYcII4n+8RbBrIJwZiJlITkETgmUrSNOCVMOpDwZK21h+ED4QgllqOoiWo
l3bhe3V8z6Za3AF4CEnBdRuEY/ODLLDvY9eHSM28DEkOeqJVhp8lMeM89HgXshZj7Plv45pVwi1z
AUHXeX+Da1SQQwnKfY9S2PkbPMdi8Nf/Hac8Rri1F3N4F0JWSS17J251Et9qEJ+7Djt3hPrBABwl
VTuh7QBNSpCE55kIJIQffK5FZuA7NUKplTi1wwgti1Ai2PmnURMrsUs7cBuDSJFZqPFenNIOrPKB
5hMIgFxWU0F4QU8SSi2lOPgwQlLpmPMnuI5BKD6Lem474WY4oZHbS6gZz62NbUePdx1/gdpGGb0Z
ajDLx1D1BNnlf4Hk+kw+cSOSfmLimbk+VD1J64KPUNpzP04tT310P7Guswgle9AiGSp7H6Q+so9k
z4XEui6gfCDg7Jq5PpAU7FIfALGuczAndiLJGvHOlUxsvZXG5EGsyjiptguQhYKixAJhcKE0y2mb
vbsq+7AmHgHfwSpswpp8BqHEkLQM4BPpfAeumQd86pNPBnFTJY3X7A7ycsCVQAgis9YQX3AOlX2P
UTn4DLgOqdVXouhRiptup+2iz4OkMvn4DajxDlJL3old6qdl5fuQwy3kt9xKavlVFHb+CrMwiOdY
KHqcWNdpyIpGcsY6XDNHtHUprpFDjWYJ4rgKshrDscoIIWObhSY/uxIkhuUQ0eRCjMphLCMPQkYL
t6JH2pg1q5dt2154UwD3ZE/3tUqAp9sVV1zBbbfdBsBtt932ioDq+z6f+MQnWLJkycuFqN5k+4MA
3VcSvent7eX9H3g/2ZYI9bFdTaaAghJONhP5gccXtDE3gsywmL4/EXznu3iu2Wz8J6NoKYQARWtH
UVPUijtx7CpCSGh6FtHM+kpqlClaUaN6gHhmNbISAiQK/b9FUuNo4TYkNYxRPIJVGwcfPNei48y/
DDwLPc7klh/SmNiHb5uY4/sJt82j65J/RNbjtK77OC1nfAzXqtF+4ecJ9ZyBXZmg7aL/RmTF5TiN
Ci1nvJ9Zf/ITlFgrkhoivuztyLHWgOPb7Cbs+0F8FxTsWj+hxBLM4jZCmbMwiy/io+KYhWDprMRR
44vwasewq83yVGCKQqRHZuA6NWLps3DtGrYxjlkdobX7vTh2AS2URlJCGOXDaKmgQMKpDaM2Y7tG
/iChluBvq9xP0CEjmFxW6SiSlkaSJLpO+yL4Alk9IXRj5fcjh7sIJecSis1g8snvIoQglAr2l5h1
KYUtv0DWomiRLInu8/AdE3NyP9VDjwRdEkrH8ByTSNtKbKOKWepHb12GVewnmTkPSVIJxWYDgmjL
ac1nLJrjY+peeICMCM9GqHGEEkJNrcYzxhBCwhh7ENecQEssDni4no1dPwoo4BnN5GdzMEoyaksX
0Vmn0ejfijGyF0mW0VtmokQz1PY9Stvbv0hkzhmM3P0lrNIoLSuvxq6MgKyTWf1Bxp/8FqHu1Tj1
EoXtv0Bv6QVJpmXhu4PO0o6BFu+mkd9HuHUxjWIQSjKrwzhmEdso4Jg5gMAJkRT0cCcat44FAAAg
AElEQVRCklG0NEIo1CuHEZKKECp6dCaOVft/uTvv8DjKq+3/pm7vKqtVl417k40LxjZgA6aaHggB
AiSBhM5L6CUQAiGBEEIghVRCDQFC6B0bY2wMNq7gXlRWWrVdaXuZeb4/RhKGAC8Ekrwf57rmWml2
p+zsM/ec5z7n3IfKchcvvvgs4fAHmSNfxPYE3c9TGHHFFVfw0ksvMWrUKF599VWuuOIKAKLRKIcf
fjgAy5Yt4/777+e1116jubmZ5uZmnn/++S/lvD9qXwl6Ycj2BN2JEyfykx/fhGma9Pf388orr3D/
g3/j7ZVvDhYklJAUDWEULO/CLFrTb2mQehiq15J1K/dcUQert3qRUCjmY4CJJGlo9ipKhV4K+V48
ob3JJrdTKibwls0l1bcCYZZI9a0BBJoeoFjoxxlqJtnxOsI0MEtZQnsdTbZvE/lkK70bH6aYiqE5
QxQzcfwjD8JZPZPo6zcR2vvb9K76M8Ioktq5nJ6V9yJJKrEXfmz1ODMKxJ790WBpcIG+5ffTt/Jh
S6REt5HbtRIjPYCkaTgbppNt34AoZCw5Sbk4WDyxFoBstxWgK2XakBQnsnsUZnoLpfR2rCDPB/mi
SDKSpFgJ/rKGyzuGZM/rJNqXDNIv4+hp+wcOv5UxYBb70D0LADD2CJyZ2S7USqsdTia2FruvZvhG
yye2YR/cXlZtSEhkujaSiW3EWTmeTPdmAnVHAFA++nRa3v4huuuDTAZv7Tx6t/wNWbG4OlmWsftG
0v/+k2Q6N1I38Wq6tv+Rvu1PUTb6eDzhZvo2PkK+fzeiVMDmqicgz6M/9gKByvmk4m+j28sxzRKl
fHywx9xgRoMoILItgIykaBR6XgdJRXM3UErvRnM1UkzvsqrLrAuIpKmIkmKlgpXygMAWqqPQ14bq
9OFomkV2x1tIipWvW3X0j0mufZyOxy9HkmV0TwXFdB+lVA9VC66k89VbcI/YDz3YQHz1w2ieMKrd
i5Hpo3L6uXS982tCk04h8f5j2AIjMApZUrH1iFIWCmkU1QVyCYengUK6Dbu7kWxyGw73SNIDW1AU
B8V872DsTEF3RACTXHIrc+ftx4MP3I/dbqdYLCLLMrIsf6ECpj2D5P39/Z8ZdIPB4ActsPawSCTC
M888A8CcOXM+Uynyl2FfCU93yIYSqIfKdnVdx+fzUV9fz5lnnsmrLz/Hu6tXce6538MfCH0g5Dw4
5RZGfjB4IIaTwsVgkrjFtRWQkFBtASQEmh5Elm0Usm2DN49Bsu8di3oQJZI9S5EVB5q93CqJrNyP
Yr4PMEl2LMFdNhl3xVRkxUa6ez2Zvs0Is0Qx3UNgxCH4Rx0DCBzhqXQsuxVJVml77nKynRuw+Wsx
s9Z0r3LuRTjCE9FcIRpPeQDPqAVoriANpz9AYPo3kFWdqkU/xL/3yZRyabwTFuJp2Jv09uWY6TiY
JpLutDz7oSyLISF1UQR7PZqjHGNgPRiFPby6IY0HaTCFKg/IeAITScRetvjo4ExkxYaqhygVOtE9
lndbzCcpZjrp2fAnivkkvevuJbr0BvLpXkrpGEZ+gHzfVmyDHrAQglx/C64yK1OhlOtDmCUC4YV0
Lf8lxVQXxXQf7nJLsER3V6G7wgjzowLV6mD1n7U+OPJY0tF1aDY/uqMSb+V8MrG3AHBXzSbbswVN
dROMHESi8xm8ZXPJZWI4fePJZ3txB/fGNFJWzi4GH84UsdL2LDAWSJqPYnI3wixQTG1DGFYXCklz
gCyjlzXiaJphqc0BimbD0TCD8HE/Jt+9i8y2N7FXjaXmxLtQ7B6if7sIo2TtWxgGjuopVB96I+ld
y0hueQn/5BMY2PQihb5WAmOPppTuwjfqcCTNQf+Wf1A25Zv0rrsf1e4n3fkuhlFE1ZzYXFW4g+OQ
ZfBWTKWQbsMdaiY7sBVVLyM9sNn6vYWBhEDV/Ti9o8mnd2EUOrj33nt58h9PDHe6NgyDfD5POp0m
k8mQy+UoFovDxQ6f9x6H/391F+ArArpD/N+Qypgsy/j9/n/qtgswcuRIbrv1p+zetZ1rr7n6w/v5
J1Fn+QMQxrQ4XiSKuS7rNd9rFUAg0FS7lRYmTGyeUSiqEzHoCRfzvSBK9HcuxunbC5d/PEiqpffb
sw6zlCPXvx1fZDahEcdaU2pnBd1r/wQCoq//CGGWCI77GpqzDE/ddML7XYuR7SU09WQ0Xw3ZjrWE
Zp1FNraJ5LbXcTbNIbH+aeKrH8FZP51sbAvxlffhrJ2Cd+LhlEolVIeXutP/QOUR11qBt9oplpaB
YlUASbpFP5DbSSG1G4SBkDTAzrCHO1T7L2vIsg1FtWMYBrlMG96K+RjFftz+MUiSRDHfD5hE1/4c
YRqk25aS6d6OhIInuB82tQlRypGNrmL3ixeTi29HtlkBNSPXhxCmld8M5Pp3oNu9hGoOwWavoGPJ
zWiDpb5ggXQp20sx20e+fzcAxXQMs5TFKAyQjW8CwOautirlbNYU2B1sppRPk40P8dQCl38m7tBs
8pkYplnC7R9NX+cLeMuaySY3I0k6uqMaWbbxT7eUMAY7OXsQhV4kzQp8odktOU5JxjvxUPzTTqAY
byO3ezXIKtUn3k5o3tmk3nuJjkcvR7F7CB9yFcVEO7Fnric491wUd4jk5ldxN8wlcsiNJLctof/9
Z6haeAPJXSvoW/0Q3pEHASYCQWjCCcRW/JLgpG9QyvXTu9YK6uUG2gjtdTyyJOEMTQZZwSjEsXtH
kom/h+6uY6D7bUyzRCEXQ5Y0nN6RCFHE5qwFSSadWMsB8+ezft0ajjjiCKvzx6DnqGkadrsdh8OB
zWZDluWPBeJCofCpQPxRAXOv1/uxn/u/bsr111//ae9/6pv/V6xYLJJIJJAkCZvN9pl0GFRVZd68
eVxxxRXU1tby2pKlFPOZ4XYmH5K1k6x6dAllOAdV1XzWOklGSBJGKY3LNxFVc5JP7UTVA+jOMIVs
B4HIQSBJlApxZMVJNrUDRIlitgt3+RQ8lbPJJrbgLGumd/tjgCDdsQpFdxJuPpdcfBOBvY7AXjaa
xLbnKJt6Jl0rf0shGcXMdNO3/jEAktteJbXzTWRFo9TfQaZlFardC4UMqW3LkAAj3Uf/u3+nmIha
tMf7L5Pa9BoAeqgOs1TCSHYTmvcdXHvtO1hiLAbTzzTrISSsLhaDF8d6ESbOsrnkU1so5nsAk1Dd
8WR6l+IOzqKQ7yXZ+xa5xFZKxSx2Z5jKkeeRS+/C7ignUHUoxVwMsxQnMvpS3IHp9He9Ri6+BVEY
wBQmxf4d+OsOsr5rx1LMooG3bAbuwN70tT+Pqvvw1exvjYlMJwPtS3F6x5PpfQd39RyS0Tcx013Y
3aPJ9r2LJzKHQrqD/tbXMAr9BKoWWAHOUoJk19ukOlciyy4KmZ34wwdRKnSS7t+Ar2I+ic6XCNV+
jXj0efxVC8n1r0NSdISkg5nf49oIrEBYycp0Uay8bIwCvimL0LxhUu+/Qj62GVHKU37AeSiqSs/S
31uznkQUW7Ce4kAnqruc8nnnke/cSO/yP4FRomz6GSQ2PoHqChKcdgrxdx9iYPPLaE4fCAndVU5o
0sl0r/4TjvBkVLuP3nUPYZYKSJKKMzQGb3hvEruep2Lc6cR3PIW7cib55G4K2W6MwgClfAJND2Ca
BRzuOmyOcrKpndhdjeRS2ygL+bjvvnu56MILsNvtw+A4VNoLDIvXDAGqoihomoaqqsNt1U3TpFQq
DasFGoYxDNySJFEoFIbFpl544QWmTJlCQ0PDv4AY/xG74ZPe+Ep4uqqq4vF4PrUf2adte8YZZ9Cy
awdz5s4dFHJmuKrqA3CREcJKtRKmQanQPxjBTaPbylE0L+nEWnLp6KD6U55cqgVJVumLvkg2uQ3V
5ieftXpHBaoXWnXpspPeXU+AMOjb9hiq7qV66qUoupOysd8gn45SzA2QH4jSvvQmkBTaX/kB+b6t
eKqno/tHg2kQmXcF4dkXIckytUf+nODeZyLJMtWH3Uxon3OQJIgc9iNqj70LxeaifO73qD3uDhS7
D3v5SPzNx1Psj5HvfA9Z1eld8ht6XrkLUciil4/A23wMkmJD9ZThHnMAsisAio6k2Qc5RpN092uD
l8pucZ1Co5BPkOx7i87tf0CzlVMx6n/QVAd2j6UOZhQ60J2WeE1m4H3snpHW+lIKSVIJjzyXTGwd
XWt+h6x+EDTLJjbj9FqNKWVVR7eVkU93kU9ZKWeZvvfR7UHKG06iMNBOtmcD2dgqbO6xlNUdR26g
jVz/DlIdb2JzhlFUnYEei1bwlM8l178TUcpR0fRtioUBMv2b8ZTtTza5Fbu7EVlx0Ndhacj2tj5G
sdBv8bqlBCCQ7J7BYaSDLKM4/LjGLADVjmJzorrLSG54AcVdhlYxEknRkVUbyfVP45/5TYJzvk12
1yowTSoWXEbVwVczsOEpul69nXyiHUV3IYwCmi9C+IDLia97nPi6xweDvwJ7aCzV+11Lqv0dUtHV
VM46j96199O/YzGq3Y+q2YnsfQm5xDZK+QS+mn3p2XQ/nshsErtfoJiLgwBV8xKKHGTFKELTQZTI
pVtRFA2b2sODDz7I9m2bWbhw4XDp/FB3liFvNp/Pf8iDHcoyGgLVIWBVVfVDHrGiKMMNA9JpSyUv
k8lwxx130Nvb+6UKXP0n7SsBukP12V+kFNjtdvPySy+xe/dujj7meIZVuiTZ4jWHOvQOJ6ybSJKC
Zi8nn2nDNKy+WXZ3EzZXI4V8En/FPNyBaYCgvO5EFMWBEAbZ5Hbi0ZdBmKRiy9DtFUQmXmLpw479
JomWlzFLORLbn6Rv0yNIkkw+vg2ESWTGJXhq52DzRiif9j2Kie34GudgD40kvv5BguOORLF5iK/6
I4EJR6HYvfS+eTe+UfPRfdV0v3EneqAa94i5ZDvfp5TqoWz/C/GOO4TSQCfBGadQ/80/4xm9AFmz
E9zndFRXOQNr/oEopDAy/WRa1mBmEiguP+UHXYizaZYlTenwDWqxFikUeul8/0arI2zKmt6XShnS
fW9TyMfRHA0AFPP92F0Wb2sUe7A5rb9T8VU43PXo9grCe12MrOjkkm0kO1cizBK5ZBRP2TQAS08g
04HDM5LYhl9bXWbj69Edjciyjjs0m5737iOb2Im/Yj9kWcfpG0t8xxP0ty/FHZqDOzSbeNszgy1p
ykAIVK0CSZbR7FV07vgTXTsfwDTybF99MSUzQzbznkUVyCpIMlqoAffYBai+CKKYQ9LsOBtnUHva
b/FOPozM5sWQT+EcMZuak+8mNPcs+t99gmLXNsrnX0zNiXeiOny0Pfg9epfeQ2DiIlzVk4g+fjGy
zUX44KvItq+llE5QfcQvCIxfROfLP0JSNLx7LSCz+y1sgZHUzP8h6eg7JHe/TmTOlQzseIXuVb9H
Vh0gyZSNPQVncDSxtXdRNfVikh1vk0vGKBXT9Le9jiswEWmQQnAFxpKILSFUfTgDvcsxir2Ew2Xc
9cvbaG3ZyVFHHfUhMShZlofphCGRf7fbPeyhDgHxnlTCngULHwViRVGw2WzDXSWKxSKtra0sX758
uOvDnoLkH7XPInYzZIZh0NzczJFHHvl5oONzm/S/gNQXl+36D9iQWE2hUCCfz+PxeP73jT7GhnQ9
JUnizTff/Jh8PnlYeESSdSvIJqx8XFUPoulBMgObGeKAQR6sWLICT5Ks4/KOIpPcijs4GU9oFtEt
v6Fy1Jn07HwUoziALGvWNM7XaLWxNtLUzb6J9pU34AxPw9d0OLtfvZjK6RdQyg/Qveq3OCNTKCY7
KWV6UG0eq5WMadEjVlbCoJavwPJKBzVQhRDIqmY1sEz1IkwDX/OxyJqLvrf+TNWRN2CvGEX06esR
xRyRo35ErmsbsWdvxFE9mWJ/lGJ/1CpHlRWcI2ZZXO3WN/BOPNQC6J1vWfqssgqmYWWLSCrIktUo
EQmM0nAw0+aeiGb3k0msxu7eC0/ZLEzDpHvnPfirj2Kg83lc5c1k+zbQ2PwTALID2+jc9nvCoy8j
tu3nuCunkmh9ncio87E5azBNk9b3rkdCon7iDzHNAun+rXTt+D0g4Q7NolgYIJ/cYPHZsqUAh2kM
pheayK4gZm7AopNMA1mzo5U1UujvQCpksVWNIde2DsnuxSxksYXq8I4/hPjbD1HKJcEwcVSPwzv+
MHqW/ApkGcnmgUIGZ81UUltfI7DPGbjqp9H2yIWYxRzBaSfjG3sY/Wv/SuL95y1th1ATRiaOpGqE
D/whyS3P0rfuMQQQHH0U8c3/oGzSKdj89USX3owj3EymYzXCNCgfdwoSJXo2P0rV3t8nsf1xCklL
f8MspdGdEZzeEQx0Lad8xDfo3fUYmi2IYRQpZKLM3ncOZ591Jscdd9y/dH8N2RDNYBjGhxawQHYo
y2EIiIc+WyqVhr3or33tazz00EP09vbS3t7O/PnzP/ZYl112GWVlZVx22WX85Cc/IR6Pf6zgDcDt
t9/OqlWrSCaTPPnkk1/oO/JxtfdDNnQBPmH5/8ZyuZxIJpOiq6tL5HK5z7Wk02nR3d0tOjs7RX9/
v8hmsyKXy4lMJiN+/etff6AUI6sf/I0kACHJukB2CFCEJOtCku1Cs4eFZg8LkIS3fD/hKd9fgCIC
kcOEzdUgQBI2V4OQZJu1PQhJ1kSodpHQHVXCUz5FNM39pVA0p6iacr6onHS2AEk4K5uFrLqEpDiE
JKsCSRGqo0x4q2cKWXUKb/0BIjzjIqHavCI04URRf+idQneVi9DEr4nGY/8o7KERwts0T9Qt+qVw
180WujciKudeInxjjhCSoglv477CUTZCSIpNIElC1l1C0j0CJOEZe5CoOupmofprhLNhpmj4zt9E
7cm/FpJqF8HZZ4rgPmcIxVMpkGQhqTah+qqE6o8IZE2EF10nIifcKvSKEULS7EJxhaxrqdoFkiIU
h1+4xx0kFFdISKrN2ofmEKj6HtcbgSQLZE1ImlNIqn2P9YqQNIeQdKdAswtJs/a757aSqlv71hwC
RbeOL8nWOSuq9Z6sCkl3CMnmFiiaUL2Vwj3uQKF6yoe/l7Nplqg9/fcitP/3Bs9VEVqoUdSedo+o
Pe0eIelOISmaUNxlInLcbaL+2w8L2e4VyIpQ/dWi9tQ/ivozHhC2ytECRRP+KV8TTaf/VVTOv1RI
g+fuDI8TVQuuFpJqF77xi0TdCb8Rsu4SSIoIz7tcNBz9W2HzVQt7aITwjTpIyKpDSKpd1C64RYRn
/Y+QFF1UzrxAuCJThSRrwhOZK6qazxeSoouqqeeLsr2OFormFK6ycUKSNSGrThGZdJk1hipmivLG
Y4Ss2IS3fLoAxLx588WyZctEOp3+ty7JZFIkEgnR29srurq6REdHh4hGo8OvTz75pFixYoW45557
RFVVlRgYGPhfcWH06NGis7NTCCFER0eHGD169Md+rrW1VSxYsEC8+uqr4ogjjvgyIOkTcfUrA7r5
fF6kUikRi8U+M9hmMhnR29srOjo6RDweHwbbjy7RaFTMnLXPhwFXUj8AXRSBpApF9QrVFhagCUXz
CpsjLEAefM+6aSRZF+7ARKGobmFz1ojacVcJVfeI8sYTRM34SwSSIgJ1hwvFFhSSrAtVc1uv9qDw
VEwTkqyLygnfEVVTLxaSrIv6+T8XlVPOEbLmFI2H/laUT/mOUHS3aFr0BxGeeaGQNYdoPOb3oubg
W4Sk6KJu0Z2i4fh7haI7RXi/y0XT1x8U9lCj8I8+WDSd/KAom/Ftodg8ov6E34nIoTcLSXMIV/0s
YSsfZZ2/ognFGRT26olCtnuEc8Qc0XjWo6L2G/cISbWLioMuFTUn/lK4Rs4TkqJbIKQ5hOzwCZBF
+KgbROM5jwnvlEVC0p3CO+FwofqqhoFW9UVE1XE/Fv4ZJwlJ1YVzxD5C9UU+AGJZEb6px4ngnG8J
SbULxRmw1iu6tYDwTlkkArO+IVRvlZAUTSCrQnb4hK16gkBzCL18hPBOGjquBbiuveaI2jPvFcH9
zhaSahOSahey3SO8k48Uvr1PsACw+Tgh29xCdviF7C4Tmr9GVB//M+Fs2kcgawLVLmxVE0X9qfcK
78RF1jrNJfSykaL+pN8JZ+00IWlO4Zt8jJBUXQSbTxayahfe0QeJxtMeEPaKvYSk6MJZNUk0nfyg
qD7kJiEPPmCclRNExbRvCVm1icj+V4uGo35jPXgkTdQedJsIjjpcKDa3qF94hyifcroFpppblI09
xQLb5vNF5cRvCVmxicDIo6yHkqSJqgkXCldgjNAdIVEz+Uqh6F7h8DQJTXOISZObxapVq/7tYPtJ
S39/v4hGoyIWi4ne3l5xxhlniEgkIjRNE7NnzxYXXXSR6Ovr+1Rc8Pv9w3+bpvmh//e0448/Xqxe
vVosXrz43w66X9niiE8zMShUnsvlhnN5P615ZTAYZMni11izZg2zZs0CBvtSwR7J7aqlsmTkBgVC
DIqFBGDi9IwFWSeTWIO3fB7F4gBGKY3TO4bo1rsxSlkS0ZcpFa1gQTL2JmYxRajuKEr5PpI9K6mb
fgNdm/6MMzACT9VM2lfeiL9+P1Sbj8S2RwnudQSYBonNj+IMTyHZtoL4e4+gBxrp3/YyA9tfQvdG
yHSuJ7lrObLuQvfXkom9Tz7RTuV+l2GaJon1jxJoPgnF5ia+/glUu5+KuRcgDJPdj55FaNopyLqT
+Lq/YxayZHYuZ/df1mOW8ui+MI6aKWAaZFreIbjvmXhGzSe94016lvwKPVhH51M3IusuzNwA5Qdf
grtpH+y7J9H90s8ITP86uehGOp64DklSUD0VBPY+ARSd6N8uxTt+IUZ2gIENz1ui20hUHHIptvBo
oo9egZkbQHH4GVj/HLLmwMynqDjkUuzh0aS2LSO+/H4wDcxSHnvNJIQwSW9Zim/y0QxseJa2+89B
lAq4Ru1P+bzvkNm5kt5lf8QspHE17UNw+tcJTD2e9ieupNi7C9lbhWzzUHngJbT//UoKvTsoxlso
pXoIzTiFQryFXNtazFwSIclUzr+UvtUP0b/+KZyRyfjHH4mzegodL99EevdbSLJK7cJb6FjyYzpe
uZHK/S5H94bJxVtRHGV4GvdHmEU63/gZjsoJyIqGpLnoW38flTMuxigkaV/yA1DsKLoHo5jG7muk
YtypxNbdQ+WUc9Cc5cS3P4uvan8URaVr0z2Ex53PQPQFYpt+hdPpweMyePiZF5g2bdoXvCP/NRu6
P4vFIk6nE1VVeeaZZ1i/fj1/+tOfmDZtGu+++y6rVq3C6XR+YbGbp59+moqKCpqbm1m8ePG/62t9
YJ+GyF8G3P+nrFAoiEwmIzo6Oj7Rs81ms6K/v190dnaK7u5ukU6nPzcVkc1mxc9+9rMPT3utOK/l
1SILWbELkIXurBHe8pkW7SBpQrOFhKTYhCRpwu6qFeqgNxuqOVrYXY1Cs5eJEdPvEA53nfCHZ4sR
+9wtVN0jKsacLmr2vkEgq8IdnikcwbECSRG6s0womsvytoem05IiVHtAKJpbSLIqHIEmobvDAlkV
dn+90N1hISm6kDWXRVHImpAUm9AcfqHaPAJJFu7GuSIw9TQhqQ4RXnCVaDr1YeEesb/QA/Wi8ZSH
RMM37hey5hKV8y4WDSf+SXhHHSwk1S5Ud4WQZE2g6EK2eUTNSXeLxu/8TSjucuGbcKRoOvMRUXfi
PULSHEIPNghkTchOi2oI7HOGaDzrUVF/+n1CtrmFd+Ii4WzYx6IBFF2owXpRf9ZfReN3HxN6qFHY
qsYJ96gDLNpAcwoUTdScco9o/O5jovKwq4Wk6EJxBoVscwvPxMOE4qkQjrppovYb9wh/83ECRReS
oovg4HEbvvOIUJxByyu3eUTZ/PNF9Ul3CUm1Cf/k44Ri9wnVUyH8U78mJNUuqo+4Wbib5gpJtQt7
zRQh6y5Rd+xdwjfuSCEpNuFsmCUk1SaqD71ZOCPNQtbdourQG4TiDApH1RQhaw7hHX2waDrlIRFs
/rqQFF3YAg2i8fi/iPpFdwvdUyVk3SU0V5moOeBGIWtO4dtroRhx/H3CUTFOIKsiPONiUb/gdqHY
fMJTO1vULfjp4GzKJhr3u0uU7XWsUDSHqNv3RyLQdLiQZF1o9pAoqz9KyIpNVI07V5Q1HC1kxS4C
4enC7nCL2267TaRSqf+qdzt0f6ZSKRGNRsUpp5wiTjvttP/Vq/04Gz16tOjo6BBCCBGNRj+WXrjy
yitFTU2NaGhoEOFwWDidTnHqqad+UUj6RFz9SgTSgOEKl3g8TiAQ+KcnWqlUIpPJIITA6XR+od5K
iUQCWZY55JDDWL36HWCw0kmUQNKRMNHs5RSynYNCKJYEnqL5ySW34AnNQHc10tv6KIHKA5BVN71t
/8BTNoNSoY/swGZsrgilfGJQmMewgjeqHYenhsxAC87AGNxl0+jd8Te81fvhqzuQ9rdvxFu7AH/D
wbS9eQ2uqpn4Rywi+tYt6J4wZRPPoGfjA+TjW4nMu4F8fDvRN39C9bzrMAppYit/gatqGpIokIy+
izAKyKod2eamlInjbtyXwOQTSGx4klzX+9Qc8VMkSWLXo98lMPE4fKMPItO+ltjrP8NWthe57i1W
4NEsUXPMrej+GmKv/IxiqpvqI27GLKRpf+oqzEIKYRTRgrUYxRyaI0D40GuRJInOF2+hNBADIShl
48h2H0Y+Td1Jd6LY3GTa1tL14k+RbW6EUcQzfiEDG1/EN/4Q/FOOJdOymu7X7wazhHfC4QSnf51S
qpe2v12Eu3E2qZ3L0PzVqJ4w+a4t1B5923B5NcLA3TSXin3Pxizl6VnxR9I738QemUjVgssASG59
je5lv0UL1FF9+I+RZZnUrhV0vX4HeqCJmkN/hBCC+LpH6N/0LIrDT90Rd1BItNDx6k1o/lryfdup
mPZdEu8/hqTaqJp/Pf3vPUZ88/PYfDVUzbmGYrKN6NKb0X01FAfa8UT2IRldTh0f++oAACAASURB
VGTOdUhA2xs3Yhp53OXNCCNDMdtFzfQbSOx+ikTrYkyjhN1dSyHTTuXob2OWUnRtewhfZD6p2BJm
zpjOI4889JlFZL5sE3t4tw6HA1VVWbx4Mddffz1XXXUVRx999L+UInbZZZcRCoW4/PLLueWWW0gk
Ep8YSANYsmQJt912G0899dQX+TrwKYG0r0TK2JB93I+yZ1nwZxUq/yzHcTqdvP76YtavX8/xJ5xk
AS4A1tOskOsdVN7XcQWmUiomyKe2ozsqSCfW0tf6KLKskOh6nb72p1F1L4XMbnKpnXhC07G7x2Ca
RSoaTyY88ltIskLd5CvxhRcgIagYdRoAplnCX7+QTO9GSoUM3tr9yfRuIp/pw1N3IMVsL7nETnxN
h1udjdtX4B99LJIk0bvhfvyNB2Dz1VIYaEFWbZRP/RahqWcjyQqROVdSc8CNKJoHzVVGKd5K6xMX
kdrxOmYpT9+av9K7+kEkSca71wEA9L77IO6m/YksuIb6Y39lFawEm2h74jJ2PngW6dZ3KNvn21ay
e7wVIxun5shbqT7iFhTVjZGIUky007/habKxzeSiG6ic/31qjrmd8jnnYKZ7kYw83a/cQTHdR8/i
u/BPOoa64++mbNa3GFj/NBgFFIcfSZJR7F4wioSmnUJq82u03H8W7f+4Clf9DMr3PZva4+5EVh1k
W97BEZmIrDnwjpqPs2YqkqSS3vkmye1LkVUb+a4t2MvHkO/aQvsz12CWCiS3L0UP1INRou2Jiyjl
UqR2vYnqDmPkErS/cJ3F4zkCSLJKKZMguesNdH8dlftdRq7rfRTdj7t6OlXzrkUYRdqeu4S+Tc8S
3vtCjHyS2Ipbsfnq8O91KPn4bpwV0wiN+TremjlEl/2IYrZvaGSi2gJUTjgXVQ/Q/s4PkVW3pZgn
yZQ3nkh504nENv0O0zRx+prI9S7j0b89xIsvPvdfA9xSqUQqlcI0TdxuN4VCgUsuuYQ///nPPPvs
sxxzzDH/ck7uZxG7+aj9u/N/vzKe7lAFSzweHxbCyOVy5PN57Hb7x5YE/6s21CG4VCrhcDjQdZ0X
X3yRU089jWRyYI9PDir+S+pgLrEDZBfFXAyHZwSByCK6d/4eu6eJsrpT6Nh8K7qjioqGM2h7/2Yc
3pGU1Z9Ey/obcAWb8UUOom3dTdh9Y3AGJ9C7/WE0VwSbp4GBjjdQbT50Ty2ZnvXIqhObr4lcfLMl
QVk1nXxiN4VUKxXNZyEkidjbd1F/8M9Q7X5aXrwY/+ij8TbsT8/a+8j3bSGy/w8RRp7dz11A1exL
sYf2omv178knduGunkEquopiMoqkaNjKRuKoGEt8/WPUHXUnit1L98o/ku/ZQvXCmzGLGdqeu9zS
PTBK6MEGiqkuvCPnE5xyAgC7HzsP74gDkO1eEhufwMwn0XzVRI74EbKs0v701aiuMgITj6VvzSNk
omsAifoTf4tic5Hr3kbH8zcQmHQ8iY3/QLZ7MfJpfKMOIjjlBIRRouO1n5LrXI+9chzhA68CWab1
0fNwlI8h07kexe4jOONUul69jeqDbyTf30rPyt+hOIOUskkajvoFwijSufR2Cv1tCNOk4ei7QZLp
Wn4X2a73EIZB/eF3IEkS0SU3I4w8xUyc8MwLwSwSe+fXBKecTLZtJWY+Synfj81XQ3j2peT6ttG+
5EY0R5Ca/X+CWUwSfeNGZLuXwkA7gfpDSex+nsDIo/E3HETXuntIxdbgKptCoHYh7WtvwxuZS7Dx
SHa9eQVmKU9kzDkUM7vobXuB8OjvUMzG6N71GAcccCB/ufcPBIPBL+W++LwmBgsfCoUCdrsdVVV5
6623uPLKK7nwwgs5+eST/78tgOBTPN2vJOjabDby+Ty6ruNwOD41SPZ5bGgKlM1m0TQNp9MJ8CF1
oq1bt3LuueezfPmy4XWSZEPWnFbfKMDhqqaQ68E0cghRsqgJBJKkIMsKpmkp9kuSZHWRlaRh0RQk
BUV1YhpWqanDXUsxn6BUSuENTaKQ6yOXasFXOROjmCbVtwFP2SQrN7VvC6rdhzCLlPIDIExkxYYk
y5hGCVugAdVdTSa6grIpZ+CpmUXXu3+ilGwlMu86TLNEy7PnUTHjfJwV44lveYb+HS9RPvmbpNpX
km5fCbKKLdiAd/ShdC//FeG5/4Ojcjz5+C6iL99A3WG3Y+STdK/6I/nebSjOEIGJRyPMEvF1j1N/
lNWld2DbK/StfdgKCOWT2KunkGl5m7qj70B1BijlkrT+/Xw0b4RisgP/hCNJbluCu24WwSknYRaz
RF+5iUJ8N6666ZTPuQDMAi2PnkNwwvEkdy+jmIphD48l37ODuiNuRxhFulbeQ6b9XRzhSVTtZzU7
LCRaaXvucmSbl5rDb0O1uSlleml56iJAITzvEpzhCZRy/bQ+eQECiao5l+CsnIBRzLD7yXORZIXa
hbej6m4ysfV0vvULJEmi/qA7MUsZ2t+4Ed1bRTHVhc3TQDHdjqzaCe9zNfm+LURX/BTNFaZ+9o1k
+zYTXXMn/oaFDLS+hqw4EEaW6qlXYRbTtK+5zeowbRawOasoZDupHncZ2YH36N75N3Sbje9fchFX
XHH5fw3UDMMgk8kgyzIOh4NCocBNN93Eli1b+M1vfkN1dfV/5by+RPvEC/uV0F4AC/iGnppCCNxu
95fm3QohKBaLpFIpgOGqmz2zJYY440AgwBlnnM73vvc9fD4/q1atIZ9PI4wcsmJDmAWEmccwsqia
j4qG0zCK/QgjS2XTt1A0H7n0diobT8Ppn0Smfz3hEd8iFFlEsnc5VSO+Q3nt8fR3Laai6VSCtUfT
3/kSZQ3HEKw7ikTHS/iq5hJqPIGB2Js4vDVUjDubYjZOMdtB3T434SprZqB9CXWzbsBXu4Bkx5u4
K6dhc1WT7lyFUcyQjr5D/7YXKCR2ItsDSJqD5O4liGKK4PiTkCSJ7rfvJjj2eNzVM1BsPlKtywjP
OB8jN0B8/SNIsoJRSKH76+le8StckWl4ameh2n30bXiMwOhFOMpGE9/wOJn2d7FXjMFVv6/F5S6+
leDEr1Ex/Sx0b4TEe09a1WHucmyhJmKLb0d1lVF9wDXY/HX0rXkYM5/GP/5oNE8FwjDoW/swZZNO
ItOxjsT6x0m3rUK1+Sibdgbepv0swfkdr6MHGvGO2A9J0Sj2Ryn07aSU6qCUjeOKNBN/7ymMXD82
fyN9ax7AXjmRvjX3I6suAiMPpfud36HYvPRvegZZsRPc63C6Vv0e1V1BNrqaUqoTR3AUifcfxVUz
G4RBsmUpQoAsq7gqJ+OOzKB3w8MIo0jt7B/grpxBf+trpKMrGGhbhtM/mlKuh1x8M4HGw9DsIXq2
PIJqC1I37TqMfA+92x/BHZ5NPrmdQrYbh7uJ8KhzKBV66N71VzTdgyon+NXdd3L22Wf9VwB3yLvN
5XLDM9B169bxzW9+kwMPPJBbb731M0s2/h+3T9Re+MqkjOVyOTKZDIqiDE9Vvgz7uABcOp0mm80O
V88MlTMOpbcAhEIhLr30+1x44QW89NJL3H//wzz/wvMUTAnDyOHyjaeQixLb8QcEoCg6Pbvvp1hI
oepe+nveIZ/ajG6vpFiI09v2ODZHFYrmpmPbPWj2Mly+8fS2PoWk2PBUzCbZ8y7FXAJf5ECKuT6y
/Vup3ftaS1M4+jKhkScgSTI9m+/DUzkV3RUm1fUuplGgbPRJIGkMtL9O5YQzcZU30/Xen8n3b8du
D9G79n7MUhZFtRNbeSeyzY9hlHDXzAKgb8N9+JoOwFkxEXvZWFLtKwjutYhs31banr0cJHBF9rZ4
5ZZlCKOAf+RCS9O4lKN/+0sUE220PH42mr8OAXgb5g4KoRRBkghNOIm+1Q/Rt+7vmLkEtQt/jCRJ
OMKTAQlHxXhir9+GIzwJgcDmq8M38mC8TQvoXvsAyZ2LcYQnWpV4sky2axO6v4HSQJTWpy+hcv8r
SGx6msrp56A6gnQsu5XW2HsUkzFqDrge3VtLfNMTdLxyA0II6g+5A1V3ozrLiL19N0IY1C/8Baru
RtY9dL39O4RpUL3vNdi8dfSs/wPtr16NKcl4q+fiDk+nY9XPEcJAtbmRFR1JsRN951bCUy8hsvdl
7FpyKZKsUTn+u5iFftpW30LH6p9TzPVgc1VTzMbo3f0PQk0ngyTTvvoWVM1D/YQr6dj6G9o33kzV
6AvJDmxGZztL3lhCKBRiYGAARVE+tHxZM8JPsiEVQLDK7g3D4JZbbmHFihU88MADNDU1/VuP/3/F
vjL0gmEYFItF0uk0mqZhs9m+0P5M0ySbzVIoFIZ5WyEEpmkO15DncjkMw0CW5eH1qqp+aCDv6U0k
Egn++te/8tripbzy8ktkMmlkRccfPphscju55Fa85bMRQpDsWW4FsHQPuUwUhEBWHRil7ODexKDi
mW4F8YSMJFvHszqz5pEkFd3hxyhmKeYTuMOzUHQf/a0vE5l6Mc7AaFpXXIMnvA/+xsNJ7H6ZRMsL
1M/5CUJAy9JLKBt7Ku6KqfTteIZkdCnBkceR69vAQMfbIEnYPGG04BiSu16h/iCLH+7Z8BC57g1U
z/0hkiTRsuQHKKqdYrYbYeQRpklg9JEExizCNE12P3seZRO/gbt6JumO1XStvgdJUvCPXURgzBHs
evoCfCMOJrDXYZilPC0vX4GRS2AvH0vV7AtJbH2O5I4l1B18G8V0F7G3f0UhGSU06UT8IxcC0Pry
tag2P4WBNpAkyqZ+k9ibv6B2wc0oNh9dq39HunMNmruSugU3W2OqkGL3C/8DpqDmwJvQXRWYRoHd
z1+EWcziH3UEobHHYhaztLz0fUyjgDsyjYqp30WYJVpeuZxSNo5/xBGERh+NECZtS6+jmIpRO/t6
dHcVucR2ou/cjmkWqJp8ETZ3NdHVP0G1+9FdEdJda5BUJ7IkEZl2NaVcHy1vXYuk6DROv5ViNkr7
xl/gDIynmIliFvOUSkkCkYUEwvvTufUesqldHH/8cfzm13dhs9mGx/FHy3AlSUJRlA+N4S9rpjhU
om+z2dB1nU2bNnHxxRdzzDHHcMEFFwz3Nfy8duaZZ/LMM89QUVHB+vXrAUtv4cQTT2T37t00NDTw
yCOP/DeChF99egEsoCwWi8Pg96/YEG+bTqdRVRWXy4WiKMPSdACFQoFcLoemabhcLmw2GzabbZhy
GDqPoRSYoW3tdjt77703Jxx/HP/zPxcze/Y+jBo1knjPJlp3rUVRVVwuN6nEFpBkKhpOQ5Id5FLb
qBp1Hr7K+aR7V1BWcyRVI79DdmA9Tk8T1aMuplRMYBppqkedj6IFySbfp6Lx6+iOWlLxdXhCzSjC
YCC2AlmWGYguo2/H05ilAka2i1T3GtKdK3FXzcIRHE9i9wsUUq2UjzkFSZLo2nAPwZHH4qmaiWma
ZHrWUz3tUiRJpX/niyAE+a61lAopkrtfIzTuZHRPFYVUjMS2J6medQWBkYswixly8a3kejeT6dpA
MdlBMdlGRfO3kCSZdOcaCgMtlI8/hfimf9C78e9gFgnPOA9JViikYgxse57IrEvJ9rxPz7oHyHVv
obz5DGzeahTdTbJtOYqik25fSS6+E0X3MrD9RSL7XIZ/xCEUk+30bXwUe9ko/CMWIskquqea5K7F
mIUMplnAWT6OTGwdmY7VuKtm0Lv+PnR/A5m25RipGFVTL6Bn44MUk23k+7YgCikie19GfOs/yHav
p5iOURpoJTz5Ano3PUApFwcg2bYUX2Q2PZsfwhEag+aqYqD9dYRRQpYlPOGZuCtnEN/1LJn4Vqon
X0kgMp907yoSrS+ST263ZJc0L8nOV/FVHYQrMI6enY9iGgVqx1+DyzeG3tZHyfS/B0YfZ5x+Kr+6
+5fD98SQMM2QvKKu6586fj8qsfh5gNg0TTKZjJUt4XQiyzJ33XUXd999N7/97W858sgjv5CHHQwG
OfPMM/n73//OOeecA8APfvADJk6cyMMPP0w0GuXll1/mwAMP/JeP8S/aJ9ILXxlPd2igDAnWOByO
z7X9EG87RFE4HI7hAThkpVKJXC43TGH8b09n8TGiHkPdivf0KIa44V27drFmzRoeeOAhcvkS27Zt
Ixpts0TZg/UM9McwSiUCkUPIp9tJx1dTM/ZSANre/ymRUefjcDeye8MP8JbvQyByKLHt91HItVMz
/grymXbaNt5K/eTrUG0hWtZeh9M3EZurloGuN8il25BlDaOUs5oR2jx4wjMRSKSiS6mf81MkWaF1
+TV4qvbFX38ohWwPrcuvJdJ8MfmBnfTtehZhFLB5a/A2HUqq5VU0RxllE860znPplXiq5+Esm0Ri
17MkO1Yh27yEp5+PPdDAzufOo2zsSXhqZiPMErteugjTyKE6y6mccS7d7/4Bm6eOislnIISg8507
ycTWoLnChGd/H4wibYuvo3a/mxDCILbqbgqpGO7qWVQ2fwuAVMcqut69BwBHxQQqp59H22vX4vA1
WWlYq36BzVdHPtlOoOFgAo2HMtC6mO5Nf7XogplX4PA3UUjHiL59K6X8ALWzr8fmjlDK9xN9+ycU
sn1Epl6C0z+SfKqd6KqfYpRylI04Hn/tAhKtz9O381l0TwTJKFE+6kza1/0Mh78RX90hRN+9A91e
hhB5IpMuR1bs7H7nGoxihpoxF2Jz19K98y+kEpuQZA3dVoaiOMimdlBedyJmKUVP29/59a/v5pRT
Tvlc98Ke4/fjPOIhwP6kGd2e91Mulxv2bnfu3MkFF1zA/Pnzufzyy79w6uaQ7dq1iyOPPHLY0x0z
ZgxLliwZ7gK8//77s2nTpi/lWJ/DPvHJ9JXhdD+uOeVntY/ytqqqDsvLDQFvNpv9J972s5zTkEjz
kO05iIfk7cBSV4pEItTV1X0oL7FUKhGNRtm1axeLFy9GCEFrawcrV/aRsYXp2/1LUql+JFkhH3+a
ZKxEIdeLEDL93StI9q2maq9vA9C9814C4blo9jL6Y8sxillCdUeDpNLb+gQVI07CW7EPPbueINn9
Fr7ymeTim8kMtCBJCtG3b0Z2VFLI9OGt3h+Ank1/wVM5FYd/L2zeESRansdXdxQYGXrW3YtpFnEG
NUq5BPmBFoq5frw1+yOrdnRvI3L3Rrzlk4m+cROK7kKSJNyRmQCkOt4GBA3zbiW+81naX7seMKmc
/B3AaoOT691MePJ3SfdspO3Vq0C24Y7MQnOWA+AfcTjd6/5IOvoWPbqLsvEn0bvhfkIjj8ZVMYWO
d++k5YWLMQppaqZ/H0X3ULfvD2lZdj3CLOCpss7FU7MfA+3LyPXvYqDlFRz+JjRHCFnRkRUbsTV3
EplxDYrmsjp/yDa6N95D9bSr0V0R7N560vGtpLvfxlu9H/7aQ8gn20h2v0uobhG6M0xt81W0r7uN
9tW3E4gcRKj6ULp33kfb6htwBCciCZNg5Tyim+8iWHsk3or5JPs2IIwCqmck5XXfIB1fRefOv+D1
eFi6dAlTpkz5XPfCR8fvEKgO2UeBeMgT3hOIhwTHAVwu6zf9wx/+wMMPP8zdd99Nc3Pzv3xOn8Vi
sRiVlZWA1X49Fov9W4/3ee0rA7pD9lHv9NNsaOozVAUzxNsO8VsA2WyWUqmE3W4fnn59ERtq0Df0
lB8qDRxKeduTJx4axNXV1dTW1jJv3ryP3Wc6nSYWi9HZ2cnGjRtpaWlhYCDNho3vYSZDJNrup3tn
gWIhh9MZIN72JInYMrwV+wDQ1/Y0smLDUz4T0yyR7FpGWdPX8ZRNJd5uJ5/ppmrU2WQHttDb9hzC
LNG64loUZ4RcfCt1M68DoL/lRSRJw197IJIkkx3YhTBLyEDLksuRkHBVTh1uqdO/8zmCTUfhq56H
r+4wWpZfjWkW6Vh+E6FJ3yKx9XFCIxah6l7KR59ELv4+pXyS9mU/wtd4MEa+H91Zjqtyb9zh6di9
9XS//yD5vvfJJ9uxeapJbH6Usr2Ow+ZtonP9r0m1L0eYJr66A5BkjZpZP2DXkkuQZJlMz0Y8kVlW
/zUjh6d8Ci1vXEflpLMQokQx3Unt1Kvo3Pgr2pffiLNiCsLIUz/rp/Ru+RNty67BVTkVUcpRP+PH
9O64n9a3rsNbPZfcwG4amn9AbMvvaXv7OspGnkyqew3ByCHEW5+mmO2kbMQJVtqgYifV/Sae4FTK
m04nu/YGUl2r8IRmEKo5FrtnDB3bf48wDYLhBTgDk+lpeYiWDdfh8tYzcuQoHnzgXsaPH/+FxurH
2acBcalUGgZhgBtvvJHu7m62b9/OhAkTePbZZ//j3OrnpUP+E/aVAd3P4+kO8bZDUx+fzzcMtkM2
lH6maRoej+ff9sMNDYo9u17s6U0MtS/Zk5bYM9osSRIul4umpiaampqYPXv2P33XYrFILBZj69at
9PT0sHXrNp54Iko6s5uWdy/FMMDhCZOIvkwu2YKieXCHmi0BnPYXCdUfj93TSDHfhyTJNEy7mVy6
ha5tf+H/tXfm4VEVVv//3Fkzk0z2fSELBEIgrFnQX9FiCRVFfFGrgta9tb5aRagKLy+LWgSLYjWt
1YfaV6zVqijiCghVcSEkBAlohLCGZLIvk2UymfX+/hjuOAkDYcnO/TwPf8wMmXtmO/fcs3wPohNj
0Wq0AXFY24yEDb8RQVBg72jAYjpEwuSlaPRRtFTtpO7wvzDXFlP25R9Q+cfjdNoJjHHb21qdj0Ll
x7CJj9Nc8SkVO5YDIn5hYwGwNB/FZq4lccpTWNvKqT3wGk57G+Ejr/9pb5bxC0ISfo4gqDB+8wRq
wzAcDhuBcZcjKNQk5Kzg+NePIgCtlfkExk/FdHwLCoWa0OG/ovaH12iv34+1+RghCdMJTZ6DX9VX
VH33IoIAoUnXojUMI37yMir3PUfD4Y+IHDkPpUpDxOjfUlPyMi3GnQTHudf+hI+4A5fr/zCVbccQ
eSlqvzBixy6g5uA6Kve/SEDIeMLiZ2IIm0BFyfO01RWh9gshedxKTNWfUPHDM6h1UTidFiKT5tJQ
8T7lJUcwhLlPvlr/eJpqv8BmrSc88ddUH8ojMV7L9m1bPD3kfYH0HXY4HJ52TYCUlBSOHz9OQkIC
P/zwA7GxsXz++efk5OT0qj1SWiE6OpqqqioiIyN79XjnypBxuhJninSlKqrU7iU5U29nK7W1KJVK
TxGtr/GOJiRn7J0flnJlwBnbfrxbdGJiYkhISPA8tmTJ/wBuzYri4mJKS0spKCzik0++o7alkYbS
p7HZFbhEJzqDu5Wnsfw9wobNQqUJQm0PxeWykjhhGU57G3XH/o3Tbqbh8Fu01ezEYTdjiJiARu++
zGuu+ITQhJkEx+XSWldE3ZE33QW6H9cTOuJmWsq3Epp8HSq/EMJORoEKdRAV+U+gD0vDYWkgJGEa
Km0QKm0Q+pBULKYjNBzaiKV+PwFxU7GZ64jJWIhS7Y8udCKV+55DodRiNVfhZxhGw+F30eoiCI6f
Se2Bf9JWvYuO5uNEjrqDgPAJ+BmSMRavxWk3ExDpboULjJlKs/ELrG0VtDcUERR7OYLSD5fNhF9A
AvWH3wIEAiImYmk6gCE8E5PxPzhtTYSm3Eh74w8YwjJpq8tHdLYSMeI2rOYT6AISMZv2U3d8A+GJ
16PWBmFrr8Nha6atcQ+hsddgaTtBe8sB1H5hqLQRJIxZQtWhv1Jv3IRSZSA84VeIooO6stcx/riG
pUuX8Oijj/R5ZGe327FYLGg0GvR6PXV1dSxYsID4+Hg2bNjgOQFI9ZDeZvbs2axfv57HHnuM9evX
+1hG0L8MmUIauLsKpLaxrg3W3nlbSVBD6iromreVHh/oeOfWpPSE5LAlJ+3n5+dZlXK22O129u/f
z7vvvsuugu/4/vt9OJwiFnMzUSNuQx88huoDeegMwwlLvBGXw8bxvYuJTLkNpSoAU/VntDX9gEql
wy94NFpDMk0nPiQpaxUKpR+N5Z/SWr2DyJRfY6raitl0CASBYZnL0fhH0VS+jebyzSRmPoW9o47a
Q69iNVfhH55BZNqduBwWTuxaQmzGQpQqAw3H3sTceABtYBLxE92FxdrSN7CaDhIQNp5G438IiJxI
W+13xGbMRxeYgsPaRPl3q3A5rUSPuRf/0DG4HB2U7VqE1j+BjrYyQlNuQKnSUVf6OvFjH6Wh7G2s
5grU/vG4bC0kZCzG3LSfmiPrQVChC0gkZtT92DuqqTz4Ig5bK3rDcGJS78duraP68EvYrE1odTHE
py3A2l5B1ZF1uJxWBIWWhPRHaW8uob58AwqFFoejg5gRv6Gj9XtMtd+gVAXgsLUSnjAHm+UYrQ3F
qLWB+GlFXvrbX7j22mt766vmE5fL5UmH6XQ6lEolH3zwAWvXrmX16tVcccUVvX4CmDt3Ll9++SX1
9fVERUXxxBNPcO2113LjjTdy4sSJAdkyNuScrsPhoLW11fMme+dtpeEG735bKdUgrQI5Vwc1kHC5
XJ5+SO8trAqFolPvpZSWOFtEUWTv3r18/PHH7MwvYufOr7F2WAiJuRz/0CxM1dtw2VuITXsYQRAo
3/9HdIEj0RnSaan/GrPpIAqVH0Gx0wiKuYITRf9DZPKtBIRNwOWycaxoEX76BCxtx9AGxGFrryUi
5SYMke7L0BNFS9AZRmGzVGKz1IJSi96QRFSaezdWU8VnmCo2IyjUKBRKQlJuoO7gq8SmP4AucATW
tnIqvn8ORJGo9N/iH5JOR+sJjPueISRmGk1Vn7udrrMDQRSJGfV7zE37qD68HnAQkXQDQVGXI4ou
ao/+i9a6QvTBo4lO/S0KhYK64+9iqt6OWhNEVOo96AzDqTn6T1rrdyMICoKjcwmLnUn10f+jrWk/
IBIQMoHIxHnUHn+dNtM+QERvGEl40jzqT7xFu+lHQESrjyUo+iqaqz/BaqkB0YVKrUPtF4tSaCc8
VMumTe8yfPjwnv0ydYMU3Ur70EwmE4888gh+fn4899xzQ2Wq7EIY+t0LRBfsNgAAGx9JREFU8FNu
SSpOdZe3lRxUb+dt+wKpnQ3c0z7SZZx3WsLhcGC1Wj354a6O+HQIgsDEiRM9VWe73c7WrVv56qtv
+ODDjZgbj2MIHYm5qRi7rQm7rZnY2GtQKnWYm0tQawMJivg5LbVf01j2IYJCjVLtzvvVHl6Pnz6G
2LQHcdhMVB78Cy6HBZPxU1BocHTU4XLYCU+6CUFQ0WTcSkPFh7S7Smks30xQ7DRMFZ8SmXIL+uCx
NFd/Tu2P//DsrQOwW5sQRSehMblUl7yEPigFu6We0JifExo/G0P4FKpKX8be0UBYoltCMCB0PLqA
eDraymk48QEiCgLDcmhv2kdQxKW0t/zIieKlhMReTXPtV8Sm3oe1/QTGH/PQ6GKxmiuIT1+I02ai
tuxNWmq/xOGwEj96IaLLRkP5vzm691FEl4PYtIUIgoCp8gPK9i0H0Ulo7Cx0QWMxVX9M7dFX3Isv
NYGodQk4bXVYzUf43X33snrVql6fJPNGFEVPcVmv16NUKtm+fTtPPvkky5YtY9asWYP6d9QXDKlI
126343A4PHq30krnrnleqUtAoVCcVb/tQEbSnLDb7WfdYeGr9xJ+yg979w+fDaWlpWzbto13Nmyi
sDAfP10Ehogr0OjjqDzwZ2JT78cvIJkOcznG0j9jCJ1Aa2MxSpUfDlsb8ekPozOkYLPUcOL71USn
3I3dUk5D1TZE0Yl/6Hiih98BQHnxMgzhl6DWRtJQsRGHox2Vyp/EiX9EEARaG/ZQc+SfGELG0Nr0
Pf4hY7G0HCI09kqCI3+O3dqI8eDzOOwtBEZcSviw68HloGzfUvwCUmlvLkHrH4UueAKmyq0MS1+C
pe0IdSfeAlFEo4shbtRDgEhT1cc0VX+JUuVPfNoCVJpgmuvzqT/xNoJChSHsEkLjrsZU8zmmqq0A
aHXhBEVfjdm0m/bmUlRqfxz2VjS6OBy2egSFFr1hOK2NxYii3T14CKg1ITidbbgc7WSMm8i7G97q
c1EYKUWnUqnQ6XS0tbWxZMkSzGYzeXl5hIeH96k9A5yLI71gsVhobW3F6XQSEBBwxryt5KAGK96j
ldIl3vlGGF3b1nw1watUqrNKS9TV1bF9+3beevs9tm/bgqDQEBx9JfrADKoOv0BgWDbBMTNxOq2U
f/8EgqDC6WzHTx+D3dZCQHAG4QluqcfK0udxOq24nO24XFYUqkBcjg6SM5YjKFS0mfZTffQfKJQ6
FAIYIi+nuXo7YXGzCQy/FGu7EeOhvyC67ASETiYy8UZslioqDvyZ0NiraK3/FpfLgqDQodEEEz3i
fre494k3aW8uRe0XSezI+1Gp/Kkt+zetjbtBFNEFJBI2bC41R15CpQ1DqdTSZirBzz8ZS9txwuJn
olKH01T1MQ5rIy6XnfCEG9AHjaGl7ktMNTvcU3DaCALCcrBaqjA3FoKgQHTZUar8cDrtIDpxb5V2
ExoWzicff0RGRsZ5fc7niy+B8W+++Yb//d//ZcGCBdx0001ydHsqF4fTbW1tRRRFzGazZw27lG6Q
osHBnrcFd8RhsVg8k3e9Eal79176mqaTHPGZ+iBbWlrYsWMHGza8z0cffYDFYiYs7pfoAsfTVPUJ
DlsjsSdHmKuP/B17Rw1KlT9+ASmoNZG0NHxLQvpiFCp/TNXbaKr+DEEQ8PNPICRqJjXHXyU0diaG
8Etoa/zOHY2iwBA6mfC4/6LV9B0N5e8RPuxGWut30NFeDbgIjrqM0NhrEEUXVYdewtJaikoTSGDY
VIIiplJ+YCU6Qxqisw1zyxHU2nBsllpiRz2EQqmluXozrU37AIgYdhMBoZNord9FQ8VGRFyo1MEo
NWHYO6pxOVpw//7O/6c0depU1q9f72n470uk75o0pdnR0cETTzxBWVkZf/vb34iJielzmwYJF4fT
lQppZrMZh8PhicycTqdHBGewpxKkol9PDWucC13zw13TEmfKD9tsNnbu3Mn773/Ie+9tpL6+hqCw
8eiCs7Fb62is/ITY1PtxOsyYajZjba9CodCgC0zDEP7/qD26juCYXHQBo2mt/4rm+l0IghJDaCYh
MVdiqt5CW9NeQuP/i7aGb7C0VYDoJDj6F4TGXoXL5cL440qcTiuiy4afPg6NPoWW+q+JHv4b7NYG
TNVbcdpbQVAQk/rfaPXxNFRsoqXOrY2s0hhQKAOxd1Qhiq6TvtSJoFAjIoDLhnBy8APRieh04Psn
JDlhBe5I9ienrFarmTlzJsuWLSMpKemcRm97kq7RrVqtpqioiEceeYTf/va33HHHHT2WS05KSiIw
MNCjBVFQUNAjz9vPXBxO96677qKqqopJkyYREBDA/v37WbVqFXq93iO/2FUFrC+LEOdLT6YSehpf
bWvdOQiXy0VhYSFbt37GRx9v4Ycf9uGnC0UfnA0KPU3G9wmNvQqFykBrw9d0mI2AAp1hOAFhl9JS
uwXRaScw4nJ3brTlKAhK9IFphMVfi8PeRs2Rv6HVD8PafsLtFEUXSoUfsaMW4HS0Unv8dewdNQgK
DX76eHTBE2iq/MS93sbZhtNpQVCoEE+KxXeP23EKSg0q/0jsLRUISu3Jv1cBDkAJ/FTIHT16NHPm
zOHWW28lMTHxtM/cnYbH+XalnA4pupUExh0OB08//TR79uzh5ZdfJikp6YKP4U1ycjJFRUX9tsGi
l7g4nK4oinz77bf8/ve/p6Kigssuuwyj0UhqaipZWVlMmTLF01rjy0Gcbd6yL+mLVEJP0nU23+Fw
dGpbA3fUKxVjFAoFDQ0NfP3112ze8hnvv7+J1tZmwiPTsTmDaW0sRB+Yij54Iq3139LRVgaC4K7k
+w3DYW/AZqkmKOrn2MyHaW856t5NJ6gwRFyKRhdHw4m33RKYrg53fh8FLpcFtV80KnUwHebjiK6O
07wi79SAAAo1uGwnb6pBtPv4ExWc3JkXGhrKr371K+666y7S09N7dItJd464u/SPr+f0Xp+jVqsp
KSnh4Ycf5qabbuL+++/vlSAlOTmZ3bt3ExYW1uPP3Y9cHE4XYMuWLRw8eJD77rsPtVqN0+nk4MGD
7Ny5k/z8fEpKStBqtUyaNImsrCyys7MJDg4+owpYf0TD/Z1K6EmkIl1HR0en/ujTta3V1NRQUFDA
O++8y57v9lFXW43D4aTD2o6AAj/DSDrajvpwlCcv1wUliCLeRaifLuXPgHDyhCZK0ahXZCqokDSM
JQwGA+Hh4aSkpHD99ddzyy239OtQTXddKWe6uuu6PsflcpGXl8e2bdt46aWXGDVqVK/ZnZKSQlBQ
EEqlknvvvZff/OY3vXasPuTicbrdIYoibW1t7N69m507d7Jr1y5qamoYNmwYmZmZ5OTkMGbMGM9G
CO8vbk+LO5/OPimVIOmcDlZnC6d/PWdyEF3fZ1EUqaqq4ttvv8VsNnPs2HFeXb8ei8VCSsooDh7Y
j9V6ukjVB4LS4zyltkIAnU5HXFwcs2fPJjg4GEEQuPbaazsVsHwJcg/kz+dsHLEkVCOd3A8fPsz8
+fP55S9/yR/+8IdeP5FUVVURExNDXV0dubm55OXlMXXq1F49Zh8gO90z4XK5KCsr80TDxcXFiKLI
uHHjyMzMZMqUKURFRXX6Al/olJcvvHNpg71/GM7t9ZyNdmt/p38kLQsp1TMY6gFd6SqmZLe70yNf
f/01//73v9Hr9RQXF7Nu3bpeF6bxxeOPP05AQAALFy7s82P3MLLTPRek3NZ3331Hfn4++fn5lJWV
ER4eTlZWFjk5OUyYMAGNRuNpqwJ85tPOBu9UgtQHOZCjp+7wrnxfSGqkJ9rWegJfuc7B/vl4R+tq
tZq9e/fy7LPPUl9fj8VioaSkhPvuu49nn322V21pb2/H6XRiMBgwm83MmDGD5cuXM2PGjF49bh8g
O90LRRRFampqPE549+7dWCwW0tLSPGmJ5OTkTkMG3UVpQzGVICmg9VaXhVRA8nbEcHZ5y/OhayV/
MEa33khaJIBnO8q//vUvXn31Vf785z97olur1Upzc3OvyyIeO3aMOXPmAO73+pZbbmHx4sW9esw+
Qna6vYHD4eCHH37wpCVKS0vx9/dn8uTJZGdnk5mZicFg8BmlgXts+WxX/wx0pNFql8vV5ypt59O2
1h2++lQHM77W59TU1PDwww+TkpLCU089dc4rrmTOiOx0+wJRFGlubqagoMBTpGtsbCQ5OdnTshYS
EkJJSYlHbLy7DcIDHe9L74FSWDpd29rZ9rVKClpSkW0oRLfesqUKhYKNGzfywgsv8Kc//YnLL7+8
3z+zIYjsdPsLl8vFkSNH+PLLL1m3bh379u1j2rRpjBw50pOWCA8P7+QkeqvpvacZTJfeXftapS0H
XQV+pKnGoRbdSumrpqYmFi5cSFBQEM888wyBgYH9beZQRXa6/c3TTz9Nfn4+a9euJTIykqKiIvLz
8ykoKMBoNBIdHe3pGx43bhwqleq0Ocv+LrQNlcJf1wWLkhKdtEx0MF55SEjRrffq8y1btrBq1Soe
f/xxZs6cOShf1yBiaDrdd955hxUrVnDgwAEKCwuZNGmS57FVq1bxj3/8A6VSyQsvvNDv1VApgvWF
KIpUVFR4inR79uzBZrMxduxYT8tafHz8KS1rXQc4evtH1BeFsr7G2zlJqYTTta315Xt9IXivz9Fq
tbS2trJ48WLsdjsvvPDCUBu3HagMTad74MABFAoF9957L88++6zH6ZaUlDBv3jwKCwsxGo1Mnz6d
0tLSAX352xWbzca+ffs8jvjIkSMEBwczefJkcnJymDx5Mjqd7pQi3dkKk58r3vvWBsM4cnf4uvT2
5Uh7Y9y2t/C1Puerr75i6dKlPProo9xwww39buNFxNDcHJGWlubz/k2bNjF37lzUajVJSUmMGDGC
goICpkyZ0scWnj8ajYbMzEwyMzN54IEHEEWRhoYGdu3axc6dO/nLX/5CS0uLR1ciJyeHESNGAG6H
LaUlLrRINxALZReKd3Tb3fJRqdDp3Y3h3bZ2uiWhfZ1y8V6fExAQgMViYcWKFVRWVvLRRx/1mCzk
5s2bmT9/Pk6nk3vuuYfHHnusR573YmJQO93TUVlZ2cnBxsfHYzQa+9GiC0cQBMLDw7n66qu5+uqr
ATrpSqxbt+60uhLS7rRzjdAkh6JQKAgICBhUVwq+6KkR3q6OWBKB916JJOkY9LYcY9f1OSqVioKC
Ah577DHuv/9+br311h773JxOJw888ADbtm0jLi6OrKwsZs+ezejRo3vk+S8WBrzTzc3Npbq6+pT7
n3rqKa655pqzfp7BHp35QqlUkp6eTnp6OnffffcpuhJvvPEGNTU1JCQkeJzw2LFjEQTBZ4QmRcXe
yzqHQhUfOqdHuotuzxXpxKVQKDzvVddxW18nvQvND3uvzzEYDNhsNv74xz/y/fff88477zBs2LAe
e40ABQUFjBgxwiPtePPNN7Np0ybZ6Z4jA97pfvbZZ+f8N3FxcZSXl3tuV1RU9Pk+qf5AEAQMBgPT
pk1j2rRpQGddiffee4/ly5d7dCUmT57MlClTiI6O9lxyS2vcFQoFWq0WhULhWXc0GOmv9IggCB7H
qtFoPLZ4t6x1dHScl8azr8GNffv2sWDBAm655RZWr17dK1clRqORhIQEz+34+Hh27drV48cZ6gx4
p3u2eBcEZ8+ezbx581iwYAFGo5FDhw6RnZ3dj9b1HwqFguTkZJKTk5k3b94puhIrVqygrKwMjUZD
Q0MD48aNY+3atWg0GpxOZ6cIrbeKdL2Fdx/xQEiP+MoPe3ekSD3CZxqY8V6fYzAYcDgcrFmzhh07
drB+/XpSU1N71X6ZC2dQO92NGzfy4IMPUl9fz9VXX83EiRP59NNPSU9P58YbbyQ9PR2VSsWLL74o
f2FOIggCfn5+XHLJJVxyySWAW9kpLy+PuXPnotfr+fWvf017eztpaWmeIp2kK3E2jqG/6SnBnb5A
oVCcNi0h9Q9LbWvgdtKNjY0kJCRQWlrK/PnzmTVrFlu3bu31jpKuV5Dl5eXEx8f36jGHIoO6ZWww
sGLFCv7+978TEREBuPuHr7zyyn62qjOfffYZ48aN61ThPpOuRFZWFllZWRgMBo8K2EBpo/KOBIfC
CC/81JkgpX3mzp1Lfn4+arWaOXPmcNVVVzF9+nSCg4N71Q6Hw8GoUaPYvn07sbGxZGdn8+abb8o5
Xd8MzT7dwcDjjz+OwWBgwYIF/W3KBdGdrkROTg5paWkoFAqfSyu9R217y76hJFADviUly8rKePDB
B7nkkku49NJL2bNnDwUFBTz55JOMGzeu12369NNPPS1jd9999xkVwZYvX05oaCgPPfQQAEuWLCEq
KooHH3yw1+0cAMhOt78YQqLMpyDpSkjR8P79+1EqlYwfP97jiCMiInp9usu7R3UoTMnBqetzAF57
7TVef/11nn/+ebKysvrZwu4pKyvjuuuuo6ioCJfLxciRIyksLCQkJKS/TesLhuZwxGAhLy+P1157
jczMTJ599tlevwzsKxQKBampqaSmpnLbbbchiiLt7e0eXYlFixZRWVlJdHQ0mZmZZGdnM378eM+K
GKvVisvlOu8Nzd4TWFKP6mDHV3RbXV3NQw89xOjRo/nPf/7jWS800ElMTCQsLIy9e/dSXV3NpEmT
LhaHe0bkSLcHOF0v8cqVK5kyZYonn7t06VKqqqp45ZVX+trEfqM7XYns7GwSExM7bYjobqhgKGpA
QOdeYr1ejyAIbNiwgRdffJFnnnmGn/3sZ4Pudb799tt888031NTUcMcddwy4ekYvIqcXBgLHjx/n
mmuuYf/+/f1tSr9is9koLi5m165dHl2JoKAgjxPOzMz0qSshRcGSIthQim67Tso1NDSwYMECIiMj
efrppzEYDP1t5nlht9sZO3YsTqeTQ4cODbqTxgUgpxf6C2nTKbhb3DIyMvrZov5Ho9F4OiB86Ur8
9a9/9ehKSJrDw4cPZ/fu3YwaNcojTmO1WjvpDw/GH7T3+hx/f38UCgUff/wxa9asYeXKleTm5g7K
1yWhVqu54oorCAkJGdSvoyeRI91e5rbbbmPv3r0IgkBycjIvv/xyj4mPDGW8dSW2bNnC9u3biYiI
YNasWZ6R5pCQkFOKdD29obm38LU+p6WlxSMg8/zzzw+J/KfL5WLy5Mls2LCB4cOH97c5fYmcXpAZ
nNTX1zNmzBgWLVrEHXfc4Zmk27VrF9XV1QwbNqyTroRCofDkh89nxLYv8LU+54svvmDFihUsXryY
OXPmDNiTxblQUlLCNddcw3XXXceaNWv625y+Rna6Mm4GozSfyWTy2fHhrSuRn59PcXExoiiSkZHh
SUvExsaetkjna0Nzb+JLw7e9vZ2lS5fS0NDAiy++6Cm69iSDYUBnCCI7XRn3JfuoUaM6SfMNpYmi
rroS+fn5lJWVER4e7skhT5o0Ca1W67NI59073NP4Wp+Tn5/P4sWLeeihh5g3b16vOf+hMqAzyJAL
aTJDX5rPl66EKIpUV1eTn5/Pjh07WLt2bSddiezsbFJSUjwdBN6TdD21J817fY5er8dqtbJy5UpK
S0vZuHFjnyjgdRNcyfQhstO9iLgYpfkEQSAmJoY5c+YwZ84coLOuRF5eHqWlpej1eiZPnkx2djZZ
WVkEBgaeIjhzrkU6X8Mbe/fuZeHChdx5552sWbOmz3LMQ3VAZzAiO92LiKFQnOkJVCoV48ePZ/z4
8fzud787RVfilVde6aQrkZ2dzejRoz26Er7W83RNS3Rdn+NwOFi1ahX5+fm8/vrrPV7JP9OAzn33
3ceyZcsA94DOwoULL6oBnYGG7HQvImRpPt8IgkBwcDAzZszwbI12uVwcPnzYs4Fj3759KJVKJkyY
0ElXwuVyefqFpSKdlCvWaDTodDp+/PFH5s+fz3XXXcfmzZt7RYLxbMX+77nnnnPauCLT88iFtIsI
WZrv/OmqK7Fr1y6MRiPR0dGeIp3T6aSmpoYrr7wSk8lEZmYmqamp1NfX88gjj3DDDTcQGxvb57Z7
D+g899xzFBYW8sYbb/S5HRcZcveCjJtzkeaTOTOSrsQXX3zB2rVrOXLkCJdddhlxcXEkJiaybds2
0tPTiYiIoLCwkKKiIo4ePepRDesr5AGdfkF2ujIyvcXy5cs5duwYzz//PP7+/hQXF/PPf/6T3Nzc
Tpfyg3nXnMw5Izvdi4XCwkLuueceCgoKcDgc5OTk8Pbbb5Oent7fpp0VSUlJBAYGolQqUavVFBQU
9LdJ3SLpP8jIeCE73YuJpUuX0tHRgcViISEhYVBMnUkkJydTVFREaGhof5siI3MhyE73YsJut3vk
EXfu3DmoLmmTk5PZvXs3YWFh/W2KjMyFcNofXf+rf8j0OPX19ZjNZtra2jyi2IMFQRCYPn06mZmZ
rFu3rr/NkZHpceRIdwgye/Zs5s2bx9GjR6mqqiIvL6+/TTprpPamuro6cnNzycvLY+rUqf1tlozM
uSJHuhcLr732GlqtlptvvplFixZRWFjIF1980d9mnTVSP2lERARz5swZFIU0GZlzQY50ZQYM7e3t
OJ1ODAYDZrOZGTNmsHz5cs+UmIzMIEKOdGUGPjU1NUydOpUJEyaQk5PDrFmzhrzDfeeddxgzZgxK
pZI9e/Z0emzVqlWkpqaSlpbG1q1b+8lCmZ5G1l6QGTAkJyezd+/e/jajT8nIyGDjxo3ce++9ne4v
KSnhrbfeoqSkBKPRyPTp0yktLR0Qmy9kLgz5E5SR6Ya77rqLqKioTktFGxsbyc3NZeTIkcyYMQOT
yXRez52WlsbIkSNPuX/Tpk3MnTsXtVpNUlISI0aMkPPbQwTZ6crIdMOdd97J5s2bO923evVqcnNz
KS0t5Re/+AWrV6/u0WNWVlZ2UoCLj4/HaDT26DFk+gfZ6crIdMPUqVNP2cz7wQcfcPvttwNw++23
8/7775/273Nzc8nIyDjl34cffnhOdgymIReZ0yPndGVkzoOamhqPUldUVBQ1NTWn/b9nq3XrTVft
44qKij5Z6yPT+3TXMiYjIwMIgpAEfCiKYsbJ202iKIZ4Pd4oiuJ5C0YIgvA58AdRFItO3k4H3gCy
gThgGzBClH+wgx45vSAjc37UCIIQDSAIQgxQez5PIgjCHEEQyoEpwMeCIHwKIIpiCfA2UAJ8Cvy3
7HCHBnKkKyNzFviIdP8ENIii+LQgCIuAYFEUF/WjiTKDBNnpysh0gyAIbwKXA+FADbAM2IQ7Eh0G
HAduFEXx/PrGZC4qZKcrIyMj04fIOV0ZGRmZPkR2ujIyMjJ9yP8HJDrcHDa8ujsAAAAASUVORK5C
YII=
)

`meshgrid` 可以设置轴排列的先后顺序：

*   默认为 `indexing='xy'` 即笛卡尔坐标，对于2维数组，返回行向量 `x` 和列向量 `y`
*   或者使用 `indexing='ij'` 即矩阵坐标，对于2维数组，返回列向量 `x` 和行向量 `y`。

## ogrid , mgrid

**Matlab**中有 `meshgrid` 的用法：

```py
meshgrid(-1:.5:1, -1:.5:1) 
```

**Numpy**的 `meshgrid` 并不支持这样的用法，但我们可以使用 `ogrid / mgrid` 来实现类似这样的用法。

`ogrid` 与 `mgrid` 的区别在于：

*   `ogrid` 相当于 `meshgrid(indexing='ij', sparse=True)`
*   `mgrid` 相当于 `meshgrid(indexing='ij', sparse=False)`

In [15]:

```py
x, y = np.ogrid[-1:1:.5, -1:1:.5]

```

In [16]:

```py
x

```

Out[16]:

```py
array([[-1\. ],
       [-0.5],
       [ 0\. ],
       [ 0.5]])
```

In [17]:

```py
y

```

Out[17]:

```py
array([[-1\. , -0.5,  0\. ,  0.5]])
```

注意：

*   这里使用的是中括号
*   **Matlab** 使用的是 `start:step:end` 的表示，**Numpy** 使用的是 `start:end:step` 的表示
*   这里的结果不包括 `end` 的值

为了包含 `end` 的值，我们可以使用这样的技巧：

In [18]:

```py
x, y = np.ogrid[-1:1:5j, -1:1:5j]

```

In [19]:

```py
x, y

```

Out[19]:

```py
(array([[-1\. ],
        [-0.5],
        [ 0\. ],
        [ 0.5],
        [ 1\. ]]), array([[-1\. , -0.5,  0\. ,  0.5,  1\. ]]))
```

我们在 `step` 的位置传入一个复数 `5j` ，表示我们需要一个 `5` 个值的数组，此时返回值就会包含 `end` 的值。

重复之前的画图：

In [20]:

```py
# exchange here
y, x = np.ogrid[-10:10:51j, -10:10:51j]

z = f(x, y)

fig = plt.figure()
ax = fig.add_subplot(111, projection='3d')
ax.plot_surface(x, y, z,
                rstride=1, cstride=1,
                cmap=cm.YlGnBu_r)
ax.set_xlabel('x')
ax.set_ylabel('y')
ax.set_zlabel('z')

```

```py
c:\Miniconda\lib\site-packages\IPython\kernel\__main__.py:9: RuntimeWarning: invalid value encountered in divide

```

Out[20]:

```py
<matplotlib.text.Text at 0x9e34278>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAV0AAADtCAYAAAAcNaZ2AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

这里，我们交换了 `x, y` 输出值的顺序。

## r`_` , c`_`

我们可以使用 `r_ / c_` 来产生行向量或者列向量。

使用切片产生：

In [21]:

```py
np.r_[0:1:.1]

```

Out[21]:

```py
array([ 0\. ,  0.1,  0.2,  0.3,  0.4,  0.5,  0.6,  0.7,  0.8,  0.9])
```

复数步长制定数组长度：

In [22]:

```py
np.r_[0:1:5j]

```

Out[22]:

```py
array([ 0\.  ,  0.25,  0.5 ,  0.75,  1\.  ])
```

连接多个序列，产生数组：

In [23]:

```py
np.r_[(3,22,11), 4.0, [15, 6]]

```

Out[23]:

```py
array([  3.,  22.,  11.,   4.,  15.,   6.])
```

列向量：

In [24]:

```py
np.c_[1:3:5j]

```

Out[24]:

```py
array([[ 1\. ],
       [ 1.5],
       [ 2\. ],
       [ 2.5],
       [ 3\. ]])
```

## ones , zeros

```py
ones(shape, dtype=float64)
zeros(shape, dtype=float64)

```

产生一个制定形状的全 `0` 或全 `1` 的数组，还可以制定数组类型：

In [25]:

```py
np.zeros(3)

```

Out[25]:

```py
array([ 0.,  0.,  0.])
```

In [26]:

```py
np.ones([2,3], dtype=np.float32)

```

Out[26]:

```py
array([[ 1.,  1.,  1.],
       [ 1.,  1.,  1.]], dtype=float32)
```

产生一个全是 `5` 的数组：

In [27]:

```py
np.ones([2,3]) * 5

```

Out[27]:

```py
array([[ 5.,  5.,  5.],
       [ 5.,  5.,  5.]])
```

## empty

```py
empty(shape, dtype=float64, order='C') 
```

也可以使用 `empty` 方法产生一个制定大小的数组（数组所指向的内存未被初始化，所以值随机），再用 `fill` 方法填充：

In [28]:

```py
a = np.empty(2)
a

```

Out[28]:

```py
array([-0.03412165,  0.05516321])
```

In [29]:

```py
a.fill(5)
a

```

Out[29]:

```py
array([ 5.,  5.])
```

另一种替代方法使用索引，不过速度会稍微慢一些：

In [30]:

```py
a[:] = 5
a

```

Out[30]:

```py
array([ 5.,  5.])
```

## empty`_`like, ones`_`like, zeros`_`like

```py
empty_like(a)
ones_like(a)
zeros_like(a) 
```

产生一个跟 `a` 大小一样，类型一样的对应数组。

In [31]:

```py
a = np.arange(0, 10, 2.5)
a

```

Out[31]:

```py
array([ 0\. ,  2.5,  5\. ,  7.5])
```

In [32]:

```py
np.empty_like(a)

```

Out[32]:

```py
array([ 0.,  0.,  0.,  0.])
```

In [33]:

```py
np.zeros_like(a)

```

Out[33]:

```py
array([ 0.,  0.,  0.,  0.])
```

In [34]:

```py
np.ones_like(a)

```

Out[34]:

```py
array([ 1.,  1.,  1.,  1.])
```

## identity

```py
indentity(n, dtype=float64) 
```

产生一个 `n` 乘 `n` 的单位矩阵：

In [35]:

```py
np.identity(3)

```

Out[35]:

```py
array([[ 1.,  0.,  0.],
       [ 0.,  1.,  0.],
       [ 0.,  0.,  1.]])
```