# 概率统计方法

## 简介

**`Python`** 中常用的统计工具有 **`Numpy, Pandas, PyMC, StatsModels`** 等。

**`Scipy`** 中的子库 `scipy.stats` 中包含很多统计上的方法。

导入 `numpy` 和 `matplotlib`：

In [1]:

```py
%pylab inline

```

```py
Populating the interactive namespace from numpy and matplotlib

```

In [2]:

```py
heights = array([1.46, 1.79, 2.01, 1.75, 1.56, 1.69, 1.88, 1.76, 1.88, 1.78])

```

`Numpy` 自带简单的统计方法：

In [3]:

```py
print 'mean, ', heights.mean()
print 'min, ', heights.min()
print 'max, ', heights.max()
print 'standard deviation, ', heights.std()

```

```py
mean,  1.756
min,  1.46
max,  2.01
standard deviation,  0.150811140172

```

导入 **`Scipy`** 的统计模块：

In [4]:

```py
import scipy.stats.stats as st

```

其他统计量：

In [5]:

```py
print 'median, ', st.nanmedian(heights)    # 忽略nan值之后的中位数
print 'mode, ', st.mode(heights)           # 众数及其出现次数
print 'skewness, ', st.skew(heights)       # 偏度
print 'kurtosis, ', st.kurtosis(heights)   # 峰度
print 'and so many more...'

```

```py
median,  1.77
mode,  (array([ 1.88]), array([ 2.]))
skewness,  -0.393524456473
kurtosis,  -0.330672097724
and so many more...

```

## 概率分布

常见的[连续概率分布](https://zh.wikipedia.org/wiki/Category:%E8%BF%9E%E7%BB%AD%E5%88%86%E5%B8%83)有：

*   均匀分布
*   正态分布
*   学生`t`分布
*   `F`分布
*   `Gamma`分布
*   ...

[离散概率分布](https://zh.wikipedia.org/wiki/Category:%E7%A6%BB%E6%95%A3%E5%88%86%E5%B8%83)：

*   伯努利分布
*   几何分布
*   ...

这些都可以在 `scipy.stats` 中找到。

## 连续分布

### 正态分布

以[正态分布](https://zh.wikipedia.org/wiki/%E6%AD%A3%E6%80%81%E5%88%86%E5%B8%83)为例，先导入正态分布：

In [6]:

```py
from scipy.stats import norm

```

它包含四类常用的函数：

*   `norm.cdf` 返回对应的[累计分布函数](https://zh.wikipedia.org/wiki/%E7%B4%AF%E7%A7%AF%E5%88%86%E5%B8%83%E5%87%BD%E6%95%B0)值
*   `norm.pdf` 返回对应的[概率密度函数](https://zh.wikipedia.org/wiki/%E6%A9%9F%E7%8E%87%E5%AF%86%E5%BA%A6%E5%87%BD%E6%95%B8)值
*   `norm.rvs` 产生指定参数的随机变量
*   `norm.fit` 返回给定数据下，各参数的[最大似然估计](https://zh.wikipedia.org/wiki/%E6%9C%80%E5%A4%A7%E4%BC%BC%E7%84%B6%E4%BC%B0%E8%AE%A1)（MLE）值

从正态分布产生500个随机点：

In [7]:

```py
x_norm = norm.rvs(size=500)
type(x_norm)

```

Out[7]:

```py
numpy.ndarray
```

直方图：

In [8]:

```py
h = hist(x_norm)
print 'counts, ', h[0]
print 'bin centers', h[1]

```

```py
counts,  [   7\.   21\.   42\.   97\.  120\.   91\.   64\.   38\.   17\.    3.]
bin centers [-2.68067801 -2.13266147 -1.58464494 -1.0366284  -0.48861186  0.05940467
  0.60742121  1.15543774  1.70345428  2.25147082  2.79948735]

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXQAAAEACAYAAACj0I2EAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

归一化直方图（用出现频率代替次数），将划分区间变为 `20`（默认 `10`）：

In [9]:

```py
h = hist(x_norm, normed=True, bins=20)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEACAYAAACuzv3DAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

在这组数据下，正态分布参数的最大似然估计值为：

In [10]:

```py
x_mean, x_std = norm.fit(x_norm)

print 'mean, ', x_mean
print 'x_std, ', x_std

```

```py
mean,  -0.0426135499965
x_std,  0.950754110144

```

将真实的概率密度函数与直方图进行比较：

In [11]:

```py
h = hist(x_norm, normed=True, bins=20)

x = linspace(-3,3,50)
p = plot(x, norm.pdf(x), 'r-')

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEACAYAAACuzv3DAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

导入积分函数：

In [12]:

```py
from scipy.integrate import trapz 

```

通过积分，计算落在某个区间的概率大小：

In [13]:

```py
x1 = linspace(-2,2,108)
p = trapz(norm.pdf(x1), x1) 
print '{:.2%} of the values lie between -2 and 2'.format(p)

fill_between(x1, norm.pdf(x1), color = 'red')
plot(x, norm.pdf(x), 'k-')

```

```py
95.45% of the values lie between -2 and 2

```

Out[13]:

```py
[<matplotlib.lines.Line2D at 0x15cbb8d0>]
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXgAAAEACAYAAAC57G0KAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

默认情况，正态分布的参数为均值0，标准差1，即标准正态分布。

可以通过 `loc` 和 `scale` 来调整这些参数，一种方法是调用相关函数时进行输入：

In [14]:

```py
p = plot(x, norm.pdf(x, loc=0, scale=1))
p = plot(x, norm.pdf(x, loc=0.5, scale=2))
p = plot(x, norm.pdf(x, loc=-0.5, scale=.5))

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEACAYAAACuzv3DAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

另一种则是将 `loc, scale` 作为参数直接输给 `norm` 生成相应的分布：

In [15]:

```py
p = plot(x, norm(loc=0, scale=1).pdf(x))
p = plot(x, norm(loc=0.5, scale=2).pdf(x))
p = plot(x, norm(loc=-0.5, scale=.5).pdf(x))

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEACAYAAACuzv3DAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

### 其他连续分布

In [16]:

```py
from scipy.stats import lognorm, t, dweibull

```

支持与 `norm` 类似的操作，如概率密度函数等。

不同参数的[对数正态分布](https://zh.wikipedia.org/wiki/%E5%AF%B9%E6%95%B0%E6%AD%A3%E6%80%81%E5%88%86%E5%B8%83)：

In [17]:

```py
x = linspace(0.01, 3, 100)

plot(x, lognorm.pdf(x, 1), label='s=1')
plot(x, lognorm.pdf(x, 2), label='s=2')
plot(x, lognorm.pdf(x, .1), label='s=0.1')

legend()

```

Out[17]:

```py
<matplotlib.legend.Legend at 0x15781c88>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXcAAAEACAYAAABI5zaHAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

不同的[韦氏分布](https://zh.wikipedia.org/wiki/%E9%9F%A6%E4%BC%AF%E5%88%86%E5%B8%83)：

In [18]:

```py
x = linspace(0.01, 3, 100)

plot(x, dweibull.pdf(x, 1), label='s=1, constant failure rate')
plot(x, dweibull.pdf(x, 2), label='s>1, increasing failure rate')
plot(x, dweibull.pdf(x, .1), label='0<s<1, decreasing failure rate')

legend()

```

Out[18]:

```py
<matplotlib.legend.Legend at 0xaa9bc50>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXcAAAEACAYAAABI5zaHAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

不同自由度的[学生 `t` 分布](https://zh.wikipedia.org/wiki/%E5%AD%A6%E7%94%9Ft-%E5%88%86%E5%B8%83)：

In [19]:

```py
x = linspace(-3, 3, 100)

plot(x, t.pdf(x, 1), label='df=1')
plot(x, t.pdf(x, 2), label='df=2')
plot(x, t.pdf(x, 100), label='df=100')
plot(x[::5], norm.pdf(x[::5]), 'kx', label='normal')

legend()

```

Out[19]:

```py
<matplotlib.legend.Legend at 0x164582e8>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXgAAAEACAYAAAC57G0KAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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==
)

## 离散分布

导入离散分布：

In [20]:

```py
from scipy.stats import binom, poisson, randint

```

离散分布没有概率密度函数，但是有[概率质量函数](https://zh.wikipedia.org/wiki/%E6%A6%82%E7%8E%87%E8%B4%A8%E9%87%8F%E5%87%BD%E6%95%B0)。

[离散均匀分布](https://zh.wikipedia.org/wiki/%E9%9B%A2%E6%95%A3%E5%9E%8B%E5%9D%87%E5%8B%BB%E5%88%86%E4%BD%88)的概率质量函数（PMF）：

In [21]:

```py
high = 10
low = -10

x = arange(low, high+1, 0.5)
p = stem(x, randint(low, high).pmf(x))  # 杆状图

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXsAAAEACAYAAABS29YJAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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==
)

[二项分布](https://zh.wikipedia.org/wiki/%E4%BA%8C%E9%A0%85%E5%88%86%E4%BD%88)：

In [22]:

```py
num_trials = 60
x = arange(num_trials)

plot(x, binom(num_trials, 0.5).pmf(x), 'o-', label='p=0.5')
plot(x, binom(num_trials, 0.2).pmf(x), 'o-', label='p=0.2')

legend()

```

Out[22]:

```py
<matplotlib.legend.Legend at 0x1738a198>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXsAAAEACAYAAABS29YJAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

[泊松分布](https://zh.wikipedia.org/wiki/%E6%B3%8A%E6%9D%BE%E5%88%86%E4%BD%88)：

In [23]:

```py
x = arange(0,21)

plot(x, poisson(1).pmf(x), 'o-', label=r'$\lambda$=1')
plot(x, poisson(4).pmf(x), 'o-', label=r'$\lambda$=4')
plot(x, poisson(9).pmf(x), 'o-', label=r'$\lambda$=9')

legend()

```

Out[23]:

```py
<matplotlib.legend.Legend at 0x1763e320>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXsAAAEACAYAAABS29YJAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

## 自定义离散分布

导入要用的函数：

In [24]:

```py
from scipy.stats import rv_discrete

```

一个不均匀的骰子对应的离散值及其概率：

In [25]:

```py
xk = [1, 2, 3, 4, 5, 6]
pk = [.3, .35, .25, .05, .025, .025]

```

定义离散分布：

In [26]:

```py
loaded = rv_discrete(values=(xk, pk))

```

此时， `loaded` 可以当作一个离散分布的模块来使用。

产生两个服从该分布的随机变量：

In [27]:

```py
loaded.rvs(size=2)

```

Out[27]:

```py
array([3, 1])
```

产生100个随机变量，将直方图与概率质量函数进行比较：

In [28]:

```py
samples = loaded.rvs(size=100)
bins = linspace(.5,6.5,7)

hist(samples, bins=bins, normed=True)
stem(xk, loaded.pmf(xk), markerfmt='ro', linefmt='r-')

```

Out[28]:

```py
<Container object of 3 artists>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXgAAAEACAYAAAC57G0KAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz
AAALEgAACxIB0t1+/AAAFktJREFUeJzt3X9sXWd9x/H3B7tJl7SsDBhlqVGR2y2tBGqBhmpdy4WF
xG2gqUAiRCAkfi1/EDvb2BRGV7CFKkAaGnOqVaEEVFhHKkpTZXOD027ctTDWxl2b8sNGiSFSEkoX
WgZLq4Sk/e6Pe+Jeu/Y999o+PrlPPi/JyjnPOc+5X6fpx4+f80sRgZmZpeclZRdgZmbFcMCbmSXK
AW9mligHvJlZohzwZmaJcsCbmSUqN+Al9Ugak7RP0uYG+10h6aSkd7fa18zM5l/DgJfUAdwC9ACX
AuslXTLDfp8Hvt1qXzMzK0beCH4FsD8iDkTECWA7sHaa/XqBu4Ajs+hrZmYFyAv4ZcDBuvVDWdsE
ScuoBfetWdOpW2Nz+5qZWXHyAr6Z5xh8EfhE1J55oOyr2b5mZlaQzpzth4GuuvUuaiPxem8EtksC
eAVwraQTTfZFkn8QmJnNQkQob4cZv6j9ABgHLgQWAY8BlzTY/6vAu1rpWyuhfX36058uu4Q5cf3l
auf627n2iPavP8vOhhnecAQfESclbQSGgQ5gW0SMStqQbd/aat+GP23MzGze5E3REBG7gF1T2qYN
9oj4YF5fMzNbGL6TdY4qlUrZJcyJ6y9XO9ffzrVD+9ffDEXJL/yQFGXXYGbWbiTlnmT1CN7MLFEO
eDOzRDngzcwS5YA3M0uUA97MLFEOeDOzRDngzcwS5YA3M0uUA97MLFEOeDOzROU+bMzKlT1nv635
URRm5XDAt4V2Dsj2/wFl1q48RWNmligHvJlZohzwZmaJcsCbmSXKAW9mlqjcgJfUI2lM0j5Jm6fZ
vlbSXkmPSnpE0tvqth2Q9Hi27eH5Lt7MzGbW8JV9kjqAnwArgcPAHmB9RIzW7bM0Ip7Jll8H7IiI
i7L1nwFvjIinG3yGX9nXQO06+Hb++5GvgzcrQDOv7Mu7Dn4FsD8iDmQH3A6sBSYC/lS4Z84Bfjm1
jmYLtoVzDkMsZ5ClHOcZFjNGH0dZU3ZZZjaP8gJ+GXCwbv0Q8OapO0m6Afgs8GpgVd2mAO6X9Byw
NSJum1u5Nh/OYYjr2MSdjE+0rWOce8Ehb5aQvDn4pn63joh7IuIS4J3A1+s2XRURlwPXAh+TdPXs
yrT5tJzBSeEOcCfjLGdLSRWZWRHyRvCHga669S5qo/hpRcSDkjolvTwinoqIJ7L2I5J2UJvyeXBq
v/7+/onlSqVCpVJp+huw1i3l+Aztxxa4EjNrVrVapVqtttQn7yRrJ7WTrH8K/Bx4mBefZO0GfhoR
IekNwDcjolvSEqAjIv5P0lJgNzAQEbunfIZPsjZQxEnWN7GaPex+UfsVrGaEb8/rZ/kkq1kx5nyS
NSJOStoIDAMdwLaIGJW0Idu+FXg38AFJJ4CjwHuz7ucDd2dPQ+wE7pga7laOMfpYx/ikaZr30M0Y
vSVWZWbzreEIfkEK8Ai+oaIuk6xdRbOFPQxzBasZo7egE6wewZsVoZkRvAP+NFf0dfCBUKHX2Tvg
zYrQTMD7UQVmZolywJuZJcoBb2aWKAe8mVmiHPBmZolywJuZJcoBb2aWKAe8mVmiHPBmZolywJuZ
JcoBb2aWKAe8mVmiHPBmZolywJuZJcoBb2aWKAe8mVmiHPBmZolywJuZJSo34CX1SBqTtE/S5mm2
r5W0V9Kjkh6R9LZm+5qZWXEavpNVUgfwE2AlcBjYA6yPiNG6fZZGxDPZ8uuAHRFxUTN9sz5t+U7W
B4aG2D04SOfx45xcvJhVfX1cs2b+X1rtd7Ka2XSaeSdrZ84xVgD7I+JAdsDtwFpgIqRPhXvmHOCX
zfZtVw8MDTG8aRM3j49PtN2YLRcR8mZms5E3RbMMOFi3fihrm0TSDZJGgV1AXyt929HuwcFJ4Q5w
8/g4923ZUlJFZmYvljeCb+p364i4B7hH0tXA1yUtb6WI/v7+ieVKpUKlUmml+4LrPH582vaOY8cW
uBIzO1NUq1Wq1WpLffIC/jDQVbfeRW0kPq2IeFBSJ/B72X5N9a0P+HZwcvHiadufO/vsBa7EzM4U
Uwe/AwMDuX3ypmhGgIslXShpEbAO2Fm/g6Ru1c4EIukNABHxVDN929Wqvj5u7O6e1PbJ7m7e3ttb
UkVmZi/WcAQfESclbQSGgQ5gW0SMStqQbd8KvBv4gKQTwFHgvY36FvetLJxTJ1Jv2rKFzwwPc9Pq
1fT09voEq5mdVhpeJrkgBbTpZZITJCiwfl8maWbTmY/LJNvayMgI3/rWjiLzl88Bn/jEjYUcWw3/
05mZNZZ0wO/du5cvfOHbnDjxrsI+43PA5z+/pJBjd3QMFXJcMzszJB3wAGeddRknThQzwq75W6CY
43d0/JLnnvt+Icc2s/T5YWNmZolywJuZJcoBb2aWKAe8mVmiHPBmZolywJuZJcoBb2aWKAe8mVmi
HPBmZolywJuZJcoBb2aWKAe8mVmiHPBmZolywJuZJcoBb2aWKAe8mVmicgNeUo+kMUn7JG2eZvv7
JO2V9Lik70l6fd22A1n7o5Ienu/izcxsZg3f6CSpA7gFWAkcBvZI2hkRo3W7/RS4JiJ+LakH+BJw
ZbYtgEpEPD3/pduZ7IGhIXYPDtJ5/DgnFy9mVV8f16xZU3ZZZqeVvFf2rQD2R8QBAEnbgbXARMBH
RP075R4CLphyDL862ubVA0NDDG/axM3j4xNtN2bLDnmzF+RN0SwDDtatH8raZvJh4N669QDulzQi
6aOzK9Fsst2Dg5PCHeDm8XHu27KlpIrMTk95I/ho9kCS3gp8CLiqrvmqiHhC0iuB+ySNRcSDU/v2
9/dPLFcqFSqVSrMfa2egzuPHp23vOHZsgSsxWzjVapVqtdpSn7yAPwx01a13URvFT5KdWL0N6ImI
X51qj4gnsj+PSNpBbcqnYcCb5Tm5ePG07c+dffYCV2K2cKYOfgcGBnL75E3RjAAXS7pQ0iJgHbCz
fgdJrwHuBt4fEfvr2pdIOjdbXgqsAn7Q1Hdi1sCqvj5u7O6e1PbJ7m7e3ttbUkVmp6eGI/iIOClp
IzAMdADbImJU0oZs+1bgU8DLgFslAZyIiBXA+cDdWVsncEdE7C7sO7EzxqkTqTdt2cJnhoe5afVq
enp7fYLVbApFND3NXkwBUhRVw7Zt2+jr+0+efXZbIccHCISaP1XRkkWL/oLf/vaLtHAqpGVF1l8j
Cv03JkHJ/4bNyiCJiGh4laLvZDUzS1TeSVazOcum6QoRBR8fKPY3ELMCOeBtARQ7BVT88c3ak6do
zMwS5YA3M0uUA97MLFEOeDOzRDngzcwS5YA3M0uUA97MLFEOeDOzRDngzcwS5YA3M0uUA97MLFEO
eDOzRDngzcwS5YA3M0uUA97MLFEOeDOzROUGvKQeSWOS9knaPM3290naK+lxSd+T9Ppm+5qZWXEa
BrykDuAWoAe4FFgv6ZIpu/0UuCYiXg98BvhSC33NzKwgeSP4FcD+iDgQESeA7cDa+h0i4vsR8ets
9SHggmb7mplZcfICfhlwsG79UNY2kw8D986yr5mZzaO8l243/TZjSW8FPgRc1Wrf/v7+ieVKpUKl
Umm2q5nZGaFarVKtVlvqkxfwh4GuuvUuaiPxSbITq7cBPRHxq1b6wuSANzOzF5s6+B0YGMjtkzdF
MwJcLOlCSYuAdcDO+h0kvQa4G3h/ROxvpa+ZmRWn4Qg+Ik5K2ggMAx3AtogYlbQh274V+BTwMuBW
SQAnImLFTH0L/F7MzKxO3hQNEbEL2DWlbWvd8keAjzTb18zMFobvZDUzS5QD3swsUQ54M7NEOeDN
zBLlgDczS5QD3swsUQ54M7NEOeDNzBLlgDczS5QD3swsUQ54M7NEOeDNzBLlgDczS5QD3swsUQ54
M7NEOeDNzBLlgDczS5QD3swsUQ54M7NE5Qa8pB5JY5L2Sdo8zfblkr4v6Zikj0/ZdkDS45IelfTw
fBZuZmaNNXzptqQO4BZgJXAY2CNpZ0SM1u32FNAL3DDNIQKoRMTT81SvmZk1KW8EvwLYHxEHIuIE
sB1YW79DRByJiBHgxAzH0NzLNDOzVuUF/DLgYN36oaytWQHcL2lE0kdbLc7MzGav4RQNtYCei6si
4glJrwTukzQWEQ9O3am/v39iuVKpUKlU5vixZmZpqVarVKvVlvrkBfxhoKtuvYvaKL4pEfFE9ucR
STuoTfk0DHgzM3uxqYPfgYGB3D55UzQjwMWSLpS0CFgH7Jxh30lz7ZKWSDo3W14KrAJ+kFuRmZnN
i4Yj+Ig4KWkjMAx0ANsiYlTShmz7VknnA3uAlwLPS9oEXAr8PnC3pFOfc0dE7C7uWzEzs3p5UzRE
xC5g15S2rXXLv2DyNM4pR4HL5lqgmZnNju9kNTNLlAPezCxRDngzs0Q54M3MEuWANzNLlAPezCxR
Dngzs0Q54M3MEuWANzNLlAPezCxRDngzs0Q54M3MEuWANzNLlAPezCxRDngzs0Q54M3MEuWANzNL
lAPezCxRDngzs0TlBrykHkljkvZJ2jzN9uWSvi/pmKSPt9LXzMyK0zDgJXUAtwA9wKXAekmXTNnt
KaAX+LtZ9DUzs4LkjeBXAPsj4kBEnAC2A2vrd4iIIxExApxota+ZmRUnL+CXAQfr1g9lbc2YS18z
M5ujzpztMYdjN923v79/YrlSqVCpVObwsWZm6alWq1Sr1Zb65AX8YaCrbr2L2ki8GU33rQ94MzN7
samD34GBgdw+eVM0I8DFki6UtAhYB+ycYV/Noa+Zmc2zhiP4iDgpaSMwDHQA2yJiVNKGbPtWSecD
e4CXAs9L2gRcGhFHp+tb5DdjZmYvyJuiISJ2AbumtG2tW/4Fk6diGvY1M7OF4TtZzcwS5YA3M0uU
A97MLFEOeDOzRDngzcwS5YA3M0uUA97MLFEOeDOzRDngzcwS5YA3M0uUA97MLFEOeDOzRDngzcwS
5YA3M0uUA97MLFEOeDOzRDngzcwS5YA3M0tUbsBL6pE0JmmfpM0z7DOYbd8r6fK69gOSHpf0qKSH
57NwMzNrrOE7WSV1ALcAK4HDwB5JO+tfni3pOuCiiLhY0puBW4Ers80BVCLi6UKqNzOzGeW9dHsF
sD8iDgBI2g6sBUbr9rkeuB0gIh6SdJ6kV0XEk9l2zW/JZu3vgaEhdg8O0nn8OCcXL2ZVXx/XrFlT
dlmWmLyAXwYcrFs/BLy5iX2WAU9SG8HfL+k5YGtE3Da3cs3a3wNDQwxv2sTN4+MTbTdmyw55m095
c/DR5HFmGqX/SURcDlwLfEzS1U1XZpao3YODk8Id4Obxce7bsqWkiixVeSP4w0BX3XoXtRF6o30u
yNqIiJ9nfx6RtIPalM+DUz+kv79/YrlSqVCpVJoq3mwhSPM7y/iWGdofHB6e98+KaHaMZqe7arVK
tVptrVNEzPhF7QfAOHAhsAh4DLhkyj7XAfdmy1cC/5UtLwHOzZaXAt8DVk3zGVGUL3/5y7FkyYcC
orCvgMKOvWjRnwcFHr/o+mtfrn/q15tYNe2GN7F63mu3dGX/fWn01XAEHxEnJW0EhoEOYFtEjEra
kG3fGhH3SrpO0n7gGeCDWffzgbuzEUkncEdE7G7tx49ZesboYx3j3MkL0zTvoZsxekusylKUN0VD
ROwCdk1p2zplfeM0/X4KXDbXAs1Sc5Q13AtcwRb2MMwVrGaMXo7iE6w2v3ID3szm31HWMMIaQIzw
7bLLsUT5UQVmZolywJuZJcoBb2aWKAe8mVmiHPBmZolywJuZJcqXSZpZSxbqSZjz/diGU84BllO7
vf4ZYAw4WsgnZfdal8gBb2ZNW/gnYc5vQJ7DENexadJdxOvo5l7+oYAbzcp/UrqnaMysae3+JMzl
DE4Kd4A7GWc57VF/qxzwZta0zuPHp23vOHZsgSuZnaVMX/9S2qP+VjngzaxpJxcvnrb9ubPPXuBK
ZucZpq//Gdqj/lY54M2saav6+rixu3tS2ye7u3l7b3s8CbP2JM/J9af8JE+fZDVLWBFXopwD7Ab2
AFcAY+PjfPYd75j3zynCmfYkTwe8WdLm/zK9o8AIUHsSZpGXARZzFcqZ9CRPT9GYmSXKAW9mligH
vJlZohzwZmaJyg14ST2SxiTtk7R5hn0Gs+17JV3eSl8zMytGw4CX1AHcAvQAlwLrJV0yZZ/rgIsi
4mLgz4Bbm+2bgmrZBcxRtewC5qhadgFzVC27gDmoll3AHFXLLmAB5I3gVwD7I+JARJwAtgNrp+xz
PXA7QEQ8BJwn6fwm+7a9atkFzFG17ALmqFp2AXNULbuAOaiWXcAcVcsuYAHkBfwy4GDd+qGsrZl9
/qCJvmZmVpC8G52avYuh/OdizuD553fz0pe+s7gP+A2FHf+3v/1hIcc1szNDXsAfBrrq1ruojcQb
7XNBts9ZTfQFinuw/ynHjk37sfNiAOA3/1rY8WuK+/sZKPj4FHx815+nnWsv9vgLUX/R2ZYnL+BH
gIslXQj8HFgHrJ+yz05gI7Bd0pXA/0bEk5KeaqIvEXHajv7NzNpZw4CPiJOSNgLDQAewLSJGJW3I
tm+NiHslXSdpP7U3YH2wUd8ivxkzM3uByn5noJmZFaPUO1nb+UYoSV+R9KSkH5Rdy2xI6pL0HUk/
kvRDSX1l19QsSWdLekjSY5J+LOmzZdc0G5I6JD0q6V/KrqVVkg5Iejyr/+Gy62mVpPMk3SVpNPs3
dGXZNTVL0h9lf++nvn490/+/pY3gsxuhfgKspHaidg+wvl2mcSRdTe3JqV+LiNeVXU+rsnsVzo+I
xySdAzwC3NBGf/9LIuJZSZ3Ad4G/iojvll1XKyT9JfBG4NyIuL7seloh6WfAGyPi6bJrmQ1JtwP/
ERFfyf4NLY2IX5ddV6skvYRafq6IiINTt5c5gm/rG6Ei4kHgV2XXMVsR8YuIeCxbPgqMUrt3oS1E
xLPZ4iJq53jaKmgkXQBcB3yZ0/gy4xxtWbek3wWujoivQO18YTuGe2YlMD5duEO5Ad/MTVS2ALIr
nS4HHiq3kuZJeomkx4Ange9ExI/LrqlFfw/8NfB82YXMUgD3SxqR9NGyi2nRa4Ejkr4q6b8l3SZp
SdlFzdJ7gX+eaWOZAe+zu6eBbHrmLmBTNpJvCxHxfERcRu2+i2skVUouqWmS3gH8T0Q8SpuOgoGr
IuJy4FrgY9mUZbvoBN4A/GNEvIHa1X+fKLek1klaBLwT+OZM+5QZ8M3cRGUFknQW8C3gnyLinrLr
mY3sV+sh4E1l19KCPwauz+axvwG8TdLXSq6pJRHxRPbnEWAHtSnXdnEIOBQRe7L1u6gFfru5Fngk
+28wrTIDfuImquwn0TpqN03ZAlDtFrttwI8j4otl19MKSa+QdF62/DvA24FHy62qeRHxyYjoiojX
UvsV+98j4gNl19UsSUsknZstLwVWAW1zNVlE/AI4KOkPs6aVwI9KLGm21lMbIMyotJdut/uNUJK+
AbwFeLmkg8CnIuKrJZfViquA9wOPSzoVjn8TEe3wFuJXA7dnVxC8BPh6RPxbyTXNRbtNV74K2JHd
ht8J3BERu8stqWW9wB3Z4HKc7AbNdpH9YF0JNDz/4RudzMwS5Vf2mZklygFvZpYoB7yZWaIc8GZm
iXLAm5klygFvZpYoB7yZWaIc8GZmifp/J4pqDI9mKMcAAAAASUVORK5CYII=
)

## 假设检验

导入相关的函数：

*   正态分布
*   独立双样本 `t` 检验，配对样本 `t` 检验，单样本 `t` 检验
*   学生 `t` 分布

`t` 检验的相关内容请参考：

*   百度百科-`t` 检验：[http://baike.baidu.com/view/557340.htm](http://baike.baidu.com/view/557340.htm)
*   维基百科-学生 `t` 检验：[https://en.wikipedia.org/wiki/Student%27s_t-test](https://en.wikipedia.org/wiki/Student%27s_t-test)

In [29]:

```py
from scipy.stats import norm
from scipy.stats import ttest_ind, ttest_rel, ttest_1samp
from scipy.stats import t

```

### 独立样本 t 检验

两组参数不同的正态分布：

In [30]:

```py
n1 = norm(loc=0.3, scale=1.0)
n2 = norm(loc=0, scale=1.0)

```

从分布中产生两组随机样本：

In [31]:

```py
n1_samples = n1.rvs(size=100)
n2_samples = n2.rvs(size=100)

```

将两组样本混合在一起：

In [32]:

```py
samples = hstack((n1_samples, n2_samples)) 

```

最大似然参数估计：

In [33]:

```py
loc, scale = norm.fit(samples)
n = norm(loc=loc, scale=scale)

```

比较：

In [34]:

```py
x = linspace(-3,3,100)

hist([samples, n1_samples, n2_samples], normed=True)
plot(x, n.pdf(x), 'b-')
plot(x, n1.pdf(x), 'g-')
plot(x, n2.pdf(x), 'r-')

```

Out[34]:

```py
[<matplotlib.lines.Line2D at 0x17ca7278>]
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEACAYAAACuzv3DAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

独立双样本 `t` 检验的目的在于判断两组样本之间是否有显著差异：

In [35]:

```py
t_val, p = ttest_ind(n1_samples, n2_samples)

print 't = {}'.format(t_val)
print 'p-value = {}'.format(p)

```

```py
t = 0.868384594123
p-value = 0.386235148899

```

`p` 值小，说明这两个样本有显著性差异。

### 配对样本 t 检验

配对样本指的是两组样本之间的元素一一对应，例如，假设我们有一组病人的数据：

In [36]:

```py
pop_size = 35

pre_treat = norm(loc=0, scale=1)
n0 = pre_treat.rvs(size=pop_size)

```

经过某种治疗后，对这组病人得到一组新的数据：

In [37]:

```py
effect = norm(loc=0.05, scale=0.2)
eff = effect.rvs(size=pop_size)

n1 = n0 + eff

```

新数据的最大似然估计：

In [38]:

```py
loc, scale = norm.fit(n1)
post_treat = norm(loc=loc, scale=scale)

```

画图：

In [39]:

```py
fig = figure(figsize=(10,4))

ax1 = fig.add_subplot(1,2,1)
h = ax1.hist([n0, n1], normed=True)
p = ax1.plot(x, pre_treat.pdf(x), 'b-')
p = ax1.plot(x, post_treat.pdf(x), 'g-')

ax2 = fig.add_subplot(1,2,2)
h = ax2.hist(eff, normed=True)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAlYAAAEACAYAAABxmjhoAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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=
)

独立 `t` 检验：

In [40]:

```py
t_val, p = ttest_ind(n0, n1)

print 't = {}'.format(t_val)
print 'p-value = {}'.format(p)

```

```py
t = -0.347904839913
p-value = 0.728986322039

```

高 `p` 值说明两组样本之间没有显著性差异。

配对 `t` 检验：

In [41]:

```py
t_val, p = ttest_rel(n0, n1)

print 't = {}'.format(t_val)
print 'p-value = {}'.format(p)

```

```py
t = -1.89564459709
p-value = 0.0665336223673

```

配对 `t` 检验的结果说明，配对样本之间存在显著性差异，说明治疗时有效的，符合我们的预期。

### `p` 值计算原理

`p` 值对应的部分是下图中的红色区域，边界范围由 `t` 值决定。

In [42]:

```py
my_t = t(pop_size) # 传入参数为自由度，这里自由度为50

p = plot(x, my_t.pdf(x), 'b-')
lower_x = x[x<= -abs(t_val)]
upper_x = x[x>= abs(t_val)]

p = fill_between(lower_x, my_t.pdf(lower_x), color='red')
p = fill_between(upper_x, my_t.pdf(upper_x), color='red')

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXgAAAEACAYAAAC57G0KAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz
AAALEgAACxIB0t1+/AAAIABJREFUeJzt3Xmc1XP7x/HX1SQpRdbcLUpooSiV7CfKPeVOdduyxi13
Ibntuj1+mttti6S7BaG7EJU2N5JEHSXaVNpmEO0lKe2qac71++NzYoxpzpnmnPmc5Xo+HufhLN/v
nPfRzDWf+WxfUVWMMcaknjK+AxhjjIkPK/DGGJOirMAbY0yKsgJvjDEpygq8McakKCvwxhiToiIW
eBHJFJEcEflWRB4q4rhmIrJPRK4o7rnGGGNir8gCLyIZwEAgE2gAXCsi9Q9wXG/gw+Kea4wxJj4i
teCbA8tUdYWq5gIjgfaFHHcXMAbYeBDnGmOMiYNIBb4asDrf4zXh534lItVwhfvF8FP7l8ZGPNcY
Y0z8RCrw0exj0A94WN2eBxK+RXuuMcaYOCkb4fW1QI18j2vgWuL5nQWMFBGAY4A2IpIb5bmIiP0i
MMaYg6CqEumAA95wvwC+A2oB5YAFQP0ijh8K/LU457oIqatXr16+I8RVKn2+LVtU339f9cEHVW++
2d3OOKOX3nWX6siRquvX+04YW6n0b1eYVP984dpZZA0vsotGVfcB3YFJwFJglKpmi0hXEel6MOcW
+dvGmFKWlwcjRsDZZ0P16tC3L1SoABde6G4nngg1a8Jbb0GDBlCvnjtm507fyY2JLFIXDao6EZhY
4LnBBzj2lkjnGpMI9u1zRfuJJ+CYY+DRR6F1ayhX7vfHrVwJ99/vbqEQzJkDzz4LzzwD99wDd94J
hx/u5zMYE0nEAm9KJhAI+I4QV8n4+VauhOuuAxF48UVo2dLdL0z+z1emjGvpjxkDixfDv/8NjRq5
XxQtWpRO9lhKxn+74kj1zxcNUc8X/BAR9Z3BpI/Ro12r+8EH4d57XdEuiXfega5d4R//cF8zIyM2
OY2JREQiDrJagTdpIS8PevSASZNcn3uzZrH72qtXww03uO6dMWPgiCNi97WNOZBoCrxtNmZSXm6u
K8A5OTBvXmyLO0CNGjBlCpx6KrRqBZs2xfbrG3OwrMCblLZnD1x1FWzbBu+/D5Urx+d9MjJg4EDX
nx8IwIYN8XkfY4rDCrxJWbt3w+WXQ9myMH48HHZYfN9PBHr3hiuvdFMs162L7/sZE4n1wZuUpOpm
yuzb5/rcy5byfLHHH4dx42DaNJtGaeLDBllN2urVyw2oTp0a/5Z7YVShSxf46SdX6G12jYk1G2Q1
aWn4cHj9dfjf//wUd/htjv327W76pDE+WIE3KWXGDDe//f334fjj/WYpVw7GjoUJE2BwoWu/jYkv
66IxKWPTJjjzTHjpJbjsMt9pfrNsGZxzDkye7PIZEwvWRWPShirceitcfXViFXeAk0+Gfv2gUyfb
pMyULmvBm5Twwgvw6qvwxRdw6KG+0xSuc2c45BCX05iSslk0Ji0sWgQXX+z630891XeaA9u+HZo0
cTtYXn217zQm2VmBNylvzx5o2tQNrN5yS+TjfZs7F9q2dVsmVK/uO41JZtYHb1Le009D7dpw882+
k0SnaVO44w63o6W1a0y8WQveJK3sbLjgApg/3234lSz27IHGjeGxx9y2BsYcDOuiMSkrFHL7vXTq
BN27+05TfJ99Btdc4y4cUqWK7zQmGVkXjUlZL7/sivztt/tOcnDOPx/at4eHHvKdxKSyiC14EckE
+gEZwKuq2rvA6+2Bx4BQ+PaAqk4Jv7YC2AbkAbmq2ryQr28teFMs69bBGWdAMAinneY7zcHbuhVO
P91trXDRRb7TmGRT4i4aEckAvgZaAWuBOcC1qpqd75iKqrozfL8hMF5VTw4/Xg6cpaqbi3gPK/Cm
WG680c1Aeeop30lKbswY1xc/b17p73hpklssumiaA8tUdYWq5gIjgfb5D9hf3MMOB34qmCPKvMZE
NHOmu3rSP//pO0lsXHEFHHWULX4y8RGpwFcDVud7vCb83O+ISAcRyQYmAj3yvaTAxyIyV0RuK2lY
k95CIXdx6yefhEqVfKeJDRG3jUGvXvDzz77TmFQTqcBH1Xeiqu+oan2gHfBGvpfOU9XGQBvgThG5
4OBiGgNvveWK/I03+k4SW2ee6QZcH3vMdxKTaiL1+q0F8s8wroFrxRdKVaeLSFkROVpVN6nq+vDz
G0VkPK7LZ3rB87Kysn69HwgECAQCUX8Akx527oSePeHtt6FMCs79evxxN2DctSvUq+c7jUlEwWCQ
YDBYrHMiDbKWxQ2yXgKsA2bzx0HWOsD3qqoi0gQYrap1RKQCkKGq20WkIvAR8C9V/ajAe9ggq4mo
Vy+37e6bb/pOEj/PPefGFyZM8J3EJIOYLHQSkTb8Nk1yiKo+JSJdAVR1sIg8CNwE5AI7gHtVdY6I
nASMC3+ZssCbqvqHeQ9W4E0kGzZAgwZuxWrNmr7TxM/eva71PmyYW8RlTFFsJatJCXfd5aYQPv+8
7yTx98Yb7oIln33mBmCNORAr8CbpLV/uNujKyYFjj/WdJv7y8twirqeegnbtfKcxicy2KjBJLyvL
teDTobgDZGS4aaCPPOJmDBlTElbgTcJavBg+/NDt9Z5O2rWDww+HESN8JzHJzrpoTMLq0MENNqZb
gQe3z86tt7otkcuV853GJCLrojFJa+5cd7vjDt9J/AgE3MW6hw3zncQkM2vBm4R0+eVw6aXJudd7
rHz+OVx3HXz7rbtYtzH5WQveJKX58+HLL6FLF99J/Dr3XDjlFDd10piDYS14k3A6dnRdFHff7TuJ
f9Onu+vN5uRYK978nrXgTdL56iu3JfDf/+47SWK44AI48US30ZoxxWUteJNQrrzSdU2k48yZAwkG
4bbb3IwauyiI2c9a8CapLF7sluh37eo7SWIJBOBPf7J58ab4rAVvEsb110OjRnYh6sJ8/DH06OF+
Cabidsmm+KwFb5LG8uVu1Wq3br6TJKZLLoEKFeC993wnMcnECrxJCM895wZWjzjCd5LEJAIPPwxP
Pw32B6+JlnXRGO9+/NHtg750KVSt6jtN4srLg/r13QW6bb94Y100Jin07w/XXGPFPZKMDHjwQdeK
NyYa1oI3Xm3bBiedBLNmQZ06vtMkvj173P+vDz5w+8ab9GUteJPwXn4ZWre24h6tQw+Ff/wDevf2
ncQkA2vBG2/27nWt0ffeg8aNfadJHtu2Qe3abrfN2rV9pzG+xKQFLyKZIpIjIt+KyB9mKItIexH5
SkTmi8iXInJxtOea9DZqlBtcteJePJUru73i+/f3ncQkuiJb8CKSAXwNtALWAnOAa1U1O98xFVV1
Z/h+Q2C8qp4czbnhc6wFn4ZUXWF/8klo29Z3muSzerXrg//+ezjySN9pjA+xaME3B5ap6gpVzQVG
Au3zH7C/uIcdDvwU7bkmfU2Z4rpoMjN9J0lONWpAmzbwyiu+k5hEFqnAVwNW53u8Jvzc74hIBxHJ
BiYCPYpzrklPzz3nNhSzZfcH7777XDdNbq7vJCZRRdqbLqq+E1V9B3hHRC4A3hCResUJkZWV9ev9
QCBAIBAozukmySxdCvPmwbhxvpMktyZN3GX93n7b7eNjUlswGCQYDBbrnEh98C2ALFXNDD/uCYRU
9YCTtETkO1z3zCnRnGt98OmnSxeoWRMefdR3kuT3/vvu/+OXX7rtDEz6iEUf/FzgFBGpJSLlgGuA
dwu8SR0R960lIk0AVHVTNOea9LNhA4wdC7ff7jtJamjbFnbtcnvGG1NQkV00qrpPRLoDk4AMYIiq
ZotI1/Drg4ErgJtEJBfYAXQq6tz4fRSTDF56Ca66Co491neS1FCmDNxzD/TrBy1b+k5jEo0tdDKl
Zs8eqFXL7W1+2mm+06SOXbvcZf1mzrQVwenEtiowCeXtt+H00624x1qFCm7h08CBvpOYRGMteFMq
VKFpU3jsMbjsMt9pUs/+hU8rVriVrib1WQveJIwZM2D7drc4x8RejRpu07Zhw3wnMYnECrwpFf36
uWuK2sKm+Ln7brfwKS/PdxKTKOzHzcTdypUwdSp07uw7SWo75xw46ii3V7wxYAXelIKBA11xr1TJ
d5LUJuJa8f36+U5iEoUNspq42rXLrVqdPdvt/W7ia+9eN2XSpqKmPhtkNd69+abrOrDiXjrKlYOu
XW3KpHGsBW/iRtVN3evTBy691Hea9LF+PTRoAMuX217xqcxa8MaradPcVratW/tOkl5OOMFNRx06
1HcS45sVeBM3AwZA9+62y6EPd93lumlsymR6swJv4mLVKnfVpptu8p0kPbVoAVWqwMSJvpMYn6zA
m7h48UW48UabGumLiGvFDxjgO4nxyQZZTczt3u2mRn72GZx6qu806Wv3bjdlcto0qFvXdxoTazbI
arwYNQrOOsuKu2/ly7urZ73wgu8kxhdrwZuYa9YMevWCv/zFdxKzahWceab77+GH+05jYsla8KbU
zZ4NmzbZrpGJomZNCARg+HDfSYwPVuBNTA0c6K63mpHhO4nZr3t39+9ifyinHyvwJmY2boT33oO/
/c13EpNfy5YQCsGnn/pOYkpbxAIvIpkikiMi34rIQ4W8fr2IfCUiC0Vkhog0yvfaivDz80VkdqzD
m8Ty6qvw17/C0Uf7TmLyE/mtFW/SS5GDrCKSAXwNtALWAnOAa1U1O98x5wBLVXWriGQCWaraIvza
cuAsVd1cxHvYIGsK2LfPbSj2zjvQpInvNKag7dvdlMmFC6F6dd9pTCzEYpC1ObBMVVeoai4wEmif
/wBV/UJVt4YfzgIKfvvYQvU08P77UK2aFfdEVakSXH89DB7sO4kpTZEKfDVgdb7Ha8LPHcitQP7r
ySjwsYjMFZHbDi6iSQYDB7puAJO47rgDXnkF9uzxncSUlrIRXo+670REWgJ/A87L9/R5qrpeRI4F
JotIjqpOL3huVlbWr/cDgQCBQCDatzUJICcHFi+GK6/0ncQUpX59dxGQsWPhuut8pzHFFQwGCQaD
xTonUh98C1yfemb4cU8gpKq9CxzXCBgHZKrqsgN8rV7ADlV9rsDz1gef5Hr0gMqV4fHHfScxkYwf
7/bnnzHDdxJTUrHog58LnCIitUSkHHAN8G6BN6mJK+435C/uIlJBRCqF71cELgUWFf9jmES2fbtb
RNO1q+8kJhrt2sHq1bBgge8kpjQUWeBVdR/QHZgELAVGqWq2iHQVkf0/0o8CVYAXC0yHrApMF5EF
uMHX91X1o7h8CuPN8OFunnWNGr6TmGiULet+GQ8a5DuJKQ22F405aKrQsCH07w8XX+w7jYnWhg1Q
rx58/73bM94kJ9uLxsTVtGluhWTLlr6TmOI4/nho29Yu6ZcOrMCbgzZwoJt6Z5fkSz7du7tthEMh
30lMPFmBNwdl7Vr45BO7JF+yatHCzXz6yEbFUpoVeHNQBg92c6krV/adxBwM258mPdggqym2vXvd
viaffAINGvhOYw7Wrl1uv/jZs90+Qia52CCriYuxY11ht+Ke3CpUgFtucRdIN6nJWvCm2M47D+6/
Hzp29J3ElNT330Pz5u6SfhUq+E5jisNa8Cbm5s93KyHbtfOdxMTCSSe5AdcRI3wnMfFgBd4Uy6BB
0K2bWxFpUoNd0i91WReNidrmzVCnDnz9NRx3nO80JlZCIahbF4YNc91vJjlYF42JqSFDXNeMFffU
UqYM3HmnTZlMRdaCN1HJy4OTT4ZRo9ygnEktW7ZA7dqwZAn86U++05hoWAvexMyECa7lbsU9NR15
JHTqBC+/7DuJiSVrwZuotG4NnTvDDTf4TmLiZckSaNUKVq6EcuV8pzGRWAvexER2NixaBFdd5TuJ
iafTTnOL18aM8Z3ExIoVeBPRoEFw221w6KG+k5h4694dBgzwncLEinXRmCJt2wa1arkWfLVqvtOY
eNu3z02FHTsWmjb1ncYUxbpoTIm99prrf7finh7KlnV7/FsrPjVYC94cUCjkLu02dKgtgEknmza5
KbE5Oe7qTyYxxaQFLyKZIpIjIt+KyEOFvH69iHwlIgtFZIaINIr2XJPYJk50+72fe67vJKY0HX20
G1C3KZPJr8gWvIhkAF8DrYC1wBzgWlXNznfMOcBSVd0qIplAlqq2iObc8PnWgk9Ql17qpkXaVZvS
z6JF8Oc/w4oVNmUyUcWiBd8cWKaqK1Q1FxgJtM9/gKp+oapbww9nAdWjPdckrqVLYeFCuOYa30mM
Dw0bQv36MHq07ySmJCIV+GrA6nyP14SfO5BbgQ8O8lyTQAYMgK5dbWpkOuvRA/r3953ClESkTV+j
7jsRkZbA34D9w3FRn5uVlfXr/UAgQCAQiPZUEwc//wwjR7pWvElff/kL3HMPzJzp9ow3fgWDQYLB
YLHOidQH3wLXp54ZftwTCKlq7wLHNQLGAZmquqyY51offILp0wcWLIDhw30nMb717Qtz5tgFQRJR
NH3wkQp8WdxA6SXAOmA2fxxkrQlMAW5Q1ZnFOTd8nBX4BLJvn5siN3o0NGvmO43xbf8uk4sWQfXq
kY83pafEg6yqug/oDkwClgKjVDVbRLqKSNfwYY8CVYAXRWS+iMwu6twSfSITd+PHux9kK+4G3C6T
N97otqswyccWOpnfOfdcuO8+uOIK30lMovjuO9cHv2IFVKzoO43Zz7YqMMUycyasXw8dOvhOYhJJ
nTpuJfPrr/tOYorLCrz51fPPu6lxGRm+k5hEc++97vsjFPKdxBSHFXgDwKpVMHky3Hqr7yQmEV1w
AVSqBB98EPlYkziswBvALWy6+Wa394wxBYn81oo3ycMGWQ07dsCJJ8KXX7q9340pzN69cNJJ7vq8
Z5zhO42xQVYTlSFDoGVLK+6maOXKuSs+9e3rO4mJlrXg09z+hU2jRsHZZ/tOYxLdzz+7WTULF9rC
J9+sBW8iGj0aata04m6iU6UKdO4M//mP7yQmGtaCT2Oq7rqbWVnQrp3vNCZZrFwJTZrA99/DEUf4
TpO+rAVvijR1KuzaBZdd5juJSSYnnuguBvLKK76TmEisBZ/G2rRxWxJ06eI7iUk28+ZB+/ZuGwO7
4pMf1oI3B7R4sdsS+IYbfCcxyahJEzj1VDc4bxKXFfg01acP3HUXlC/vO4lJVg88AM8+68ZyTGKy
Ap+GVq2C996D22/3ncQksz//GcqUse0LEpkV+DTUp4/bc6ZKFd9JTDITgYcfhqee8p3EHIgNsqaZ
jRuhbl1YsgROOMF3GpPs9u2DevVg6FC3IZkpPTbIav7gP/+Bq6+24m5io2xZePBBa8UnKmvBp5Ft
29xmUbNmueXmxsTCnj2/bUJ25pm+06QPa8Gb3xk8GFq3tuJuYuvQQ+Gee6B3b99JTEERW/Aikgn0
AzKAV1W1d4HX6wFDgcbAI6r6XL7XVgDbgDwgV1WbF/L1rQVfCnbvdq2siRNtq1cTe9u3u++vzz+H
U07xnSY9lLgFLyIZwEAgE2gAXCsi9Qsctgm4C+hTyJdQIKCqjQsr7qb0vPqq23fGiruJh0qV3FbC
1hefWMpGeL05sExVVwCIyEigPZC9/wBV3QhsFJED7WhS5G8YE3979rg/n8eN853EpLIePVzrffly
qF3bdxoDkfvgqwGr8z1eE34uWgp8LCJzReS24oYzsTFsGDRsCM2a+U5iUlmVKtCtGzz9tO8kZr9I
LfiSdo6fp6rrReRYYLKI5Kjq9IIHZWVl/Xo/EAgQCARK+LZmv7173Z/NI0b4TmLSwT33uD1qHnnE
XWfAxE4wGCQYDBbrnCIHWUWkBZClqpnhxz2BUMGB1vBrvYAd+QdZo3ndBlnja8gQGDkSJk/2ncSk
i4cfdoOugwb5TpLaYjFNci5wiojUEpFywDXAuwd6vwJvXkFEKoXvVwQuBRZFldzERG4uPPEEPPqo
7yQmndx7r/uLce1a30lMNNMk2/DbNMkhqvqUiHQFUNXBIlIVmANUBkLAdtyMm+OA/cN6ZYE3VfUP
Y+zWgo+fYcPcrZh/1RlTYvfd57oHBwzwnSR1RdOCt5WsKWrvXrdHyLBhcOGFvtOYdLNhAzRo4K45
UKOG7zSpyVayprGhQ92UNSvuxofjj4e//x0ef9x3kvRmLfgUtHu3K+5jx0JzW15mPNm0yc2omT3b
tseIB2vBp6mXX4bGja24G7+OPtpdNeyxx3wnSV/Wgk8xu3a51tLEibazn/Fv61Y4+WSYPt2NCZnY
sRZ8Gho0yF14wYq7SQRHHOFm1PTq5TtJerIWfArZssX1eX76KdQvuCWcMZ7s3Ola8RMmQJMmvtOk
DmvBp5mnn4b27a24m8RSsaJbbPfQQ76TpB9rwaeI1atdt8zChVCtONvBGVMKcnPhtNNcF2Lr1r7T
pAZrwaeRrCzo2tWKu0lMhxwCTz7pWvGhkO806cMKfApYsgTef99d/NiYRHXFFa7QjxzpO0n6sC6a
FNCuHVx8sduq1ZhE9umncPPNkJPjruVqDp510aSBYBAWL4Y77vCdxJjILrrI9cUPHOg7SXqwFnwS
y8uDs85yF1e46irfaYyJTk6OW6uxdCkce6zvNMnLWvAp7r//hcqV4corfScxJnr16sH119t1CkqD
teCT1Nat7gfFFo+YZLR5s1uvMXkyNGrkO01ysv3gU9gDD7gfkiFDfCcx5uAMGgTjxsHHH4MUWaZM
YazAp6hly6BFCze4WrWq7zTGHJx9+9zivCeecCuwTfFYgU9Bqm5a5Pnnu4sbG5PMPv7YXRhkyRI4
7DDfaZKLDbKmoHffhe++cxc2NibZtWoFTZu6fZRM7EUs8CKSKSI5IvKtiPxhuyARqSciX4jIbhG5
rzjnmuLZuRN69HB9l+XK+U5jTGz07eu+p7/91neS1FNkF42IZABfA62AtcAc4FpVzc53zLHAiUAH
4GdVfS7ac8PHWRdNlHr2hFWr4M03fScxJraeew4++gg+/NAGXKMViy6a5sAyVV2hqrnASOB3wyGq
ulFV5wK5xT3XRG/pUnjlFejTx3cSY2KvRw9Ytw7GjPGdJLVEKvDVgNX5Hq8JPxeNkpxr8lGFO+90
C0NOOMF3GmNi75BD4IUX3H5K27b5TpM6ykZ4vSR9J1Gfm5WV9ev9QCBAIBAowdumniFDYPt222/G
pLYLLoDMTDc77IUXfKdJPMFgkGAwWKxzIvXBtwCyVDUz/LgnEFLV3oUc2wvYka8PPqpzrQ++aGvX
urnCn3xiK/5M6tuyxW1GNmIEXHih7zSJLRZ98HOBU0SkloiUA64B3j3Q+5XgXFMIVddqv/12K+4m
PRx5pJtR06UL/PKL7zTJL+JCJxFpA/QDMoAhqvqUiHQFUNXBIlIVN0OmMhACtgMNVHVHYecW8vWt
BX8Ab78N//oXzJtne2eb9HLNNVCrFvT+Q1+B2c9Wsiaxn36Chg1h/Hi3LYEx6WTDBvdX64QJbiGU
+SNbyZqkVKFbN7juOivuJj0dfzw8/zzcdJN11ZSEteAT0Ouvw7PPwpw5UL687zTG+KEKnTq5qcH9
+vlOk3isiyYJrVgBzZq5TZjOOMN3GmP82rzZ/RwMHer2rTG/sS6aJJOXB507u73erbgbA0cd5a5c
dsst8PPPvtMkHyvwCaRvX/dn6X33RT7WmHTRujV07OimC9sf+8VjXTQJYuZMuPxymD3bTQ8zxvzm
l1+geXO4+243R95YH3zS2LzZXVf1P/+xK9sYcyA5OW47A1vV7VgffBJQhZtvhr/+1Yq7MUWpV89N
nbz6arc3k4nMWvCe9e0Lo0bB9Ol2EQ9jorF/G4Phw9N773jroklw06fDlVfCrFnW725MtHbtcgsA
u3VL7x1WoynwkbYLNnGyapX7U/ONN6y4G1McFSq4LTzOPdftPHnRRb4TJS7rg/dg1y7o0AHuvx8u
vdR3GmOST506roumUydYudJ3msRlXTSlTBWuvx4yMtyWBOnch2hMSfXt6/4KnjHDtezTifXBJ6An
205n3JK6TM85jsMO853GmOSmCp3b/Mgv36xi1DdNKFM2fTolbJpkghne7TNenliDd897xoq7MTEg
Ai9fMYkNy3fxQNOpvuMkHCvwpWRKn3ncN/gUJnAZf6q41XccY1JG+XIh3il/LR8srEb/jlbk87MC
XwoWjf2GTg/WYBTXcBpLfccxJuUclbGViZpJ73fqMu6BL3zHSRhW4ONs+bTVtL26Iv30bgJ86juO
MSmrFit5j7/Qtc/JTHluvu84CSFigReRTBHJEZFvReShAxzTP/z6VyLSON/zK0RkoYjMF5HZsQye
DNbMWc8lF4foqU9yHSN8xzEm5TVhPqO5ik73V+fzwYt8x/GuyAIvIhnAQCATaABcKyL1CxzTFjhZ
VU8B/g68mO9lBQKq2lhVm8c0eYLbsHgjl5y7iztDA7lDX/Adx5i0EeBTXudGOtxelS+HZ/uO41Wk
FnxzYJmqrlDVXGAkUHBLrMuB1wBUdRZwpIgcn+/1tJvpvTH7J1o12cz1oTe4T/v4jmNM2slkEi/r
bVx201EsGvuN7zjeRCrw1YDV+R6vCT8X7TEKfCwic0XktpIETRbr5v3ARY1+pn3eOP4v9C/fcYxJ
Wx34H/31LlpfdQRzX0/PyQ2R9qKJdgXSgVrp56vqOhE5FpgsIjmqOj36eMllxWdraBXI5dbQMHrq
k77jGJP2rmY05XU3bTsPYdyOhZx/R3ptJB+pwK8FauR7XAPXQi/qmOrh51DVdeH/bhSR8bgunz8U
+KysrF/vBwIBAoFAVOETyTeTltO6bVnu03700P6+4xhjwi7nPd7iWv565wiGb5nLpf9s6jvSQQkG
gwSDweKdpKoHvOF+AXwH1ALKAQuA+gWOaQt8EL7fApgZvl8BqBS+XxGYAVxayHtospvx0kI9Xn7Q
IfxN1a2eLvrWpYvvyMakjmHDVCtWjPhzN53z9Dh+0Ne6TPOdOCbCtbPIGl5kC15V94lId2ASkAEM
UdVsEekafn2wqn4gIm1FZBmwE7glfHpVYJy43bTKAm+q6kfF+/WT+EbfM4M7+p3K69xEGz70HccY
cwDnM4OjiBdNAAAJyklEQVSptOSyIR+w4ptP+L+pFyNlUnsOSMT94FV1IjCxwHODCzzuXsh53wNn
ljRgotKQ0ueyKfSfVJfJtOZMvvIdyRgTQQOy+UJb0O6zCXxf51MGf3UOh1Y+1HesuLGVrAdh5487
ueHE6bw16Rg+13OsuBuTRKqygWDoQrat2kqgag5r5673HSlurMAX03dTVnJujVVkrFvNDD2HGn8Y
czbGJLqK7GJMqCPtdo+mWXOYNiA1G2lW4Ivhfz1ncm6rw7gt9wVeC91ABX7xHckYc5DKoPxTn2Co
3sxVParSp+0UQvtCvmPFlBX4KOz6aRfd6k7lnt7HM1470F0Hpt/yXGNS1J/5iFmczbhJFcg8Zi7r
5v3gO1LMWIGPYN6b2TQ5YR07l61nvp7JudhWpMakmlqsZFrofM7bPpEmTYV3Hp7pO1JMWIE/gF82
/0LP5p+QecPRPLrvUd4IXc8RbPMdyxgTJ2XJo1coi3HakfueOY5rq0/jxyUbfccqESvwhZg24CvO
OG49y77cykIa2Va/xqSRc/mCRXo61dfPoWFD5fXbpqOh5LxutBX4fNbOXc+NNT/luh7H8EzevYwO
XUFVNviOZYwpZRX4hWdD9/OBtuH5/1am5RHzWDDqa9+xis0KPK475vGWn9CoWTlqrvmcHOrSgf/5
jmWM8ews5jEndBaddrzKnzsdSddTp7Ax+yffsaKW1gV+7469DL7uU049djPzp29nDs14Qv/J4ez0
Hc0YkyDKkkc3XiKHehz23RLqNRB6nf8JW1dt9R0torQs8Lm7cnmty3TqHbGecW/nMjbUkbF5HTmJ
5b6jGWMSVBW20C/Ug7k0ZeUX6zj5xFyeaj2FbWsSd/JFWhX4HT/soF/7qdSptIHXhoUYFrqRSXmt
ac4c39GMMUmiNisYFrqJ6ZzPoqkbOalGLj2bf8L6BYk3XpcWBf67KSt5oMkn1D5hN59P2MzYUEem
5AW48I9b0xtjTFTq8TVv5XViDk3Z8eXXnNb4EG6pHWT20CUJM+smZQv8nm17GP/QTDKrzKTFJRWQ
rxYwi+a8nXclzZjrO54xJkXUZgUDQnfyDafSYMUHdLq1Ak0rLOGVG6d576dPqQKvIWXmq4u5s/4U
qh2xg37P7eO6LS+wmho8E7rf+tiNMXFzDJt4gGdZpnV4fM8DfDBiKzVPhE7VpjEhaw65u3JLPVPS
F/i8vXlMH/gV/2g0hRMPWcstfz+EE76eylzO4tO8C7iJNyjPHt8xjTFpogxKGz5kfN7lfM9JXLRu
BE/8O0TVitvoXCvIu4/MYveW3aWSJeIFPxLRj0s2MmnA10x8P4+P1p5O9TLCFRrkQ+1OA7J9xzPG
GACOZjO38xK3h15iDdV4Z2UHnu99NTc8uZcLqsynbau9ZHarxUmBmnG5ulRSFPgfFv7IjDe+Y+qE
Xwh+W401+47n4ozNtM17l2f4kOqhtb4jGmNMkaqzlu4MonveIH7mSCb/3JqJ49rx+Oi6lCuzhpY1
viPQqiznX1uDOi1jU/ATrsBvWbmVBeOXM2/KFmbPLcPMDbXYFjqcczK2Ecj7mGFM5UwWUDYvz3dU
Y4w5KFXYwtWM5uq80SjwTehUpq5sycRhrfm//9Zit26ixVHfcPaZe2hy4eE06XgiVRsdV+z3iVjg
RSQT6Ie76Parqtq7kGP6A22AXcDNqjo/2nMB/tliCou/PZTFW6rzY+hozsjYTWPNJjM0i3/xBafy
DWL13BiTggSoyzfU5Ru65bnLXa+hGjM3t2D21BY8P+0s5mVlUE5+oGGllZxWayenNz4kqq9dZIEX
kQxgINAKWAvMEZF3VTU73zFtgZNV9RQRORt4EWgRzbn7lZ/1KZ1ZzOks5mSWkZGXOldVCQIBzxni
KRgMEggEfMeIm1T+fKn82SC5f/aqs5YrGcuVOhb2gQKrtQaLt53O4oWnM21xw6i+TqRZNM2BZaq6
QlVzgZFA+wLHXA68BqCqs4AjRaRqlOcC8CiPcQXjqMs3ZJA6xR3cN1kqCwaDviPEVSp/vlT+bJBa
P3sC1GQ1bZnIgzzLa6GbojovUoGvBqzO93hN+LlojvlTFOcaY4yJk0h98NGuty3ZcG/lyiU6PaHt
3g3ly//2eO9eyMjwl8eYVCMCeXl/rCMFf/ZSyZ497haBqB64hotICyBLVTPDj3sCofyDpSLyEhBU
1ZHhxznARUDtSOeGn0+MTRuMMSbJqGqRjetILfi5wCkiUgtYB1wDXFvgmHeB7sDI8C+ELaq6QUQ2
RXFuxIDGGGMOTpEFXlX3iUh3YBJuquMQVc0Wka7h1wer6gci0lZElgE7gVuKOjeeH8YYY8xviuyi
McYYk7wSYrMxEfm3iHwlIgtE5BMRqeE7UyyJyLMikh3+jONE5AjfmWJFRK4SkSUikiciTXzniRUR
yRSRHBH5VkQe8p0nlkTkvyKyQUQW+c4SDyJSQ0Smhr8vF4tID9+ZYklEyovIrHC9XCoiTx3w2ERo
wYtIJVXdHr5/F3CGqnbxHCtmRKQ18ImqhkTkaQBVfdhzrJgQkXpACBgM3Keq8zxHKrHwIr2vybdI
D7g2VboYReQCYAfwuqpGt2ImiYTX4VRV1QUicjjwJdAhVf79AESkgqruEpGywGfA/ar6WcHjEqIF
v7+4hx0OJM9ly6OgqpNVdf8KrllAdZ95YklVc1T1G985YizqRXrJSFWnAz/7zhEvqvqDqi4I398B
ZOPW5aQMVd0VvlsON8a5ubDjEqLAA4jIEyKyCugMPO07Txz9DfjAdwhTpGgW+JkkEJ7F1xjXsEoZ
IlJGRBYAG4Cpqrq0sONKbTdJEZkMVC3kpX+q6nuq+gjwiIg8DDxPeDZOsoj0+cLHPALsVdW3SjVc
CUXz2VKM/35LU2Lh7pkxwN3hlnzKCPcInBkez5skIgFVDRY8rtQKvKq2jvLQt0jCFm6kzyciNwNt
gUtKJVAMFePfLlWsBfIP9NfAteJNkhCRQ4CxwHBVfcd3nnhR1a0iMgFoSiHb7yREF42InJLvYXtg
vq8s8RDeNvkBoL2qls61uvxIlUVrvy7wE5FyuEV673rOZKIkIgIMAZaqaj/feWJNRI4RkSPD9w8D
WnOAmpkos2jGAHWBPOA74HZV/dFvqtgRkW9xgyH7B0K+UNU7PEaKGRHpCPQHjgG2AvNVtY3fVCUn
Im347VoGQ1T1gFPRko2IjMBtJ3I08CPwqKoO9ZsqdkTkfGAasJDfutt6quqH/lLFjog0xO3gWyZ8
e0NVny302EQo8MYYY2IvIbpojDHGxJ4VeGOMSVFW4I0xJkVZgTfGmBRlBd4YY1KUFXhjjElRVuCN
MSZFWYE3xpgU9f8B8tTCMYTHdwAAAABJRU5ErkJggg==
)